(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8880,        268]*)
(*NotebookOutlinePosition[      9787,        300]*)
(*  CellTagsIndexPosition[      9700,        294]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Exchanging Data", "Title"],

Cell[CellGroupData[{

Cell["Using The Clipboard", "Section"],

Cell[TextData[{
  "You can easily move data back and forth between Excel ranges and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " lists by using special",
  " Copy and Paste commands",
  " within Microsoft Excel. "
}], "Text"],

Cell[BoxData[
    \(data = {{"\<Alloy\>", "\<Density\>", "\<Modulus\>"}, {"\<Ingot iron\>", 
          7.86, 30. }, {"\<Plain carbon steel\>", 7.86, 
          30. }, {"\<Stainless steel (304)\>", 8.02, 
          28. }, {"\<Cast gray iron\>", 7.2, 13. }, {"\<Malleable iron\>", 
          7.32, 25. }, {"\<Ductile cast iron\>", 7.2, 
          25. }, {"\<Ni-resist cast iron (2)\>", 7.3, 
          15.6}, {"\<Cast 28-7 (HD)\>", 7.6, 27. }, {"\<Hastelloy C\>", 3.94, 
          30. }}\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using The ExcelLink` Package", "Section"],

Cell[TextData[{
  "The new ExcelLink` package provides two way interactivity with Microsoft \
Excel using a powerful and easy-to-use ",
  StyleBox["Excel", "InlineInput"],
  " function. You can use the ",
  StyleBox["Excel", "InlineInput"],
  " function to specify a location in Excel and then use it as you would a \
normal variable in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", reading and writing directly to that location."
}], "Text"],

Cell["This loads the required package.", "Text"],

Cell[BoxData[
    \(<< ExcelLink`\)], "Input"],

Cell["This reads data from the specified location in Excel.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(data = Excel["\<A1:C10\>"]\)], "Input"],

Cell[BoxData[
    \({{"Alloy", "Density", "Modulus"}, {"Ingot iron", 7.86`, 
        30.`}, {"Plain carbon steel", 7.86`, 30.`}, {"Stainless steel (304)", 
        8.02`, 28.`}, {"Cast gray iron", 7.2`, 13.`}, {"Malleable iron", 
        7.32`, 25.`}, {"Ductile cast iron", 7.2`, 
        25.`}, {"Ni-resist cast iron (2)", 7.3`, 15.6`}, {"Cast 28-7 (HD)", 
        7.6`, 27.`}, {"Hastelloy C", 3.94`, 30.`}}\)], "Output"]
}, Closed]],

Cell["This writes data to the specified location in Excel.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Excel["\<A1:C10\>"]\  = \ data\)], "Input"],

Cell[BoxData[
    \({{"Alloy", "Density", "Modulus"}, {"Ingot iron", 7.86`, 
        30.`}, {"Plain carbon steel", 7.86`, 30.`}, {"Stainless steel (304)", 
        8.02`, 28.`}, {"Cast gray iron", 7.2`, 13.`}, {"Malleable iron", 
        7.32`, 25.`}, {"Ductile cast iron", 7.2`, 
        25.`}, {"Ni-resist cast iron (2)", 7.3`, 15.6`}, {"Cast 28-7 (HD)", 
        7.6`, 27.`}, {"Hastelloy C", 3.94`, 30.`}}\)], "Output"]
}, Closed]],

Cell["Here is the usage information for the Excel function.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Excel\)\)], "Input"],

Cell[BoxData[
    \("Excel[book, sheet, where] represents a location in Excel. Excel[sheet, \
where] assumes the location is in the active workbook. Excel[where] assumes \
the location is on the active sheet. Data can be retrieved from or assigned \
to Excel using the specified location as a variable. Assigning graphics or \
typeset equations to a location will display a graphic. The location can be \
specified by name, A1-style address, or {row, col} index."\)], "Print",
  CellTags->"Info3260701678-7851968"]
}, Open  ]],

Cell[TextData[{
  "You can use the keyword ",
  StyleBox["All", "InlineInput"],
  " to specify all data contained in a spreadsheet."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(data = Excel[All]\)], "Input"],

Cell[BoxData[
    \({{"Alloy", "Density", "Modulus"}, {"Ingot iron", 7.86`, 
        30.`}, {"Plain carbon steel", 7.86`, 30.`}, {"Stainless steel (304)", 
        8.02`, 28.`}, {"Cast gray iron", 7.2`, 13.`}, {"Malleable iron", 
        7.32`, 25.`}, {"Ductile cast iron", 7.2`, 
        25.`}, {"Ni-resist cast iron (2)", 7.3`, 15.6`}, {"Cast 28-7 (HD)", 
        7.6`, 27.`}, {"Hastelloy C", 3.94`, 30.`}, {"Inconel X (annealed)", 
        8.25`, 31.`}, {"Haynes Stellite 25 (L605)", 9.15`, 
        34.`}, {"Aluminum (3003, rolled)", 2.73`, 
        10.`}, {"Aluminum (2017, annealed)", 2.8`, 10.5`}, {"Aluminum (380)", 
        2.7`, 10.3`}, {"Copper", 8.91`, 17.`}, {"Yellow brass (high brass)", 
        8.47`, 15.`}, {"Aluminum bronze", 7.8`, 
        17.`}, {"Beryllium copper 25", 8.25`, 
        19.`}, {"Nickel silver (18%, A, wrought)", 8.8`, 
        18.`}, {"Cupronickel (30%)", 8.95`, 22.`}, {"Red brass (cast)", 8.7`, 
        13.`}, {"Chemical lead", 11.35`, 
        2.`}, {"Antimonial lead (hard lead)", 10.9`, 3.`}, {"Solder 50-50", 
        8.89`, 0.`}, {"Magnesium alloy (AZ31B)", 1.77`, 6.5`}, {"K Monel", 
        8.47`, 26.`}, {"Nickel", 8.89`, 30.`}, {"Cupronickel", 8.9`, 
        24.`}, {"Commercial titanium", 5.`, 16.5`}, {"Zinc", 7.14`, 
        0.`}, {"Commercial zirconium", 6.5`, 12.`}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "You can use the keyword ",
  StyleBox["Active", "InlineInput"],
  " to specify the current selection."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(data = Excel[Active]\)], "Input"],

Cell[BoxData[
    \({{"Alloy", "Density", "Modulus"}, {"Ingot iron", 7.86`, 
        30.`}, {"Plain carbon steel", 7.86`, 30.`}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "If a location is not specified, ",
  StyleBox["Active", "InlineInput"],
  " is assumed."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(data = Excel[]\)], "Input"],

Cell[BoxData[
    \({{"Alloy", "Density", "Modulus"}, {"Ingot iron", 7.86`, 
        30.`}, {"Plain carbon steel", 7.86`, 30.`}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Excel", "InlineInput"],
  " function has many convienient options."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[Excel]\)], "Input"],

Cell[BoxData[
    \({Prompt \[Rule] Automatic, Resize \[Rule] False, Offset \[Rule] False, 
      Format \[Rule] Automatic, Visible \[Rule] Automatic, 
      Dynamic \[Rule] False, Fill \[Rule] False}\)], "Output"]
}, Open  ]],

Cell["\<\
For example, this automatically resizes the specified range to match the \
dimensions of the data being assigned.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Excel["\<A1\>", Resize \[Rule] True] = data\)], "Input"],

Cell[BoxData[
    \({{"Alloy", "Density", "Modulus"}, {"Ingot iron", 7.86`, 
        30.`}, {"Plain carbon steel", 7.86`, 30.`}}\)], "Output"]
}, Open  ]],

Cell["\<\
This option displays a prompt, allowing you to select a range \
interactively.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(data\  = 
      Excel[Prompt \[Rule] "\<Please select data to analyze in \
Mathematica.\>"]\)], "Input"],

Cell[BoxData[
    \({{"Ingot iron", 7.86`, 30.`}, {"Plain carbon steel", 7.86`, 
        30.`}, {"Stainless steel (304)", 8.02`, 28.`}, {"Cast gray iron", 
        7.2`, 13.`}, {"Malleable iron", 7.32`, 25.`}, {"Ductile cast iron", 
        7.2`, 25.`}, {"Ni-resist cast iron (2)", 7.3`, 
        15.6`}, {"Cast 28-7 (HD)", 7.6`, 27.`}, {"Hastelloy C", 3.94`, 
        30.`}}\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->"EditBar",
WindowSize->{707, 629},
WindowMargins->{{Automatic, 35}, {Automatic, 6}},
ShowSelection->True,
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3260701678-7851968"->{
    Cell[4567, 138, 514, 7, 120, "Print",
      CellTags->"Info3260701678-7851968"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3260701678-7851968", 9589, 287}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 32, 0, 67, "Title"],

Cell[CellGroupData[{
Cell[1811, 55, 38, 0, 62, "Section"],
Cell[1852, 57, 239, 7, 48, "Text"],
Cell[2094, 66, 498, 8, 130, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2629, 79, 47, 0, 62, "Section"],
Cell[2679, 81, 456, 11, 69, "Text"],
Cell[3138, 94, 48, 0, 29, "Text"],
Cell[3189, 96, 46, 1, 50, "Input"],
Cell[3238, 99, 69, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[3332, 103, 59, 1, 50, "Input"],
Cell[3394, 106, 422, 6, 163, "Output"]
}, Closed]],
Cell[3831, 115, 68, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[3924, 119, 63, 1, 50, "Input"],
Cell[3990, 122, 422, 6, 163, "Output"]
}, Closed]],
Cell[4427, 131, 69, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[4521, 135, 43, 1, 50, "Input"],
Cell[4567, 138, 514, 7, 120, "Print",
  CellTags->"Info3260701678-7851968"]
}, Open  ]],
Cell[5096, 148, 144, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[5265, 156, 50, 1, 50, "Input"],
Cell[5318, 159, 1335, 20, 315, "Output"]
}, Open  ]],
Cell[6668, 182, 133, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[6826, 190, 53, 1, 50, "Input"],
Cell[6882, 193, 142, 2, 49, "Output"]
}, Open  ]],
Cell[7039, 198, 119, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[7183, 206, 47, 1, 50, "Input"],
Cell[7233, 209, 142, 2, 49, "Output"]
}, Open  ]],
Cell[7390, 214, 117, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[7532, 222, 47, 1, 50, "Input"],
Cell[7582, 225, 214, 3, 68, "Output"]
}, Open  ]],
Cell[7811, 231, 137, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[7973, 238, 76, 1, 50, "Input"],
Cell[8052, 241, 142, 2, 49, "Output"]
}, Open  ]],
Cell[8209, 246, 102, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[8336, 253, 124, 3, 50, "Input"],
Cell[8463, 258, 389, 6, 125, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

