(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    151115,       3352]*)
(*NotebookOutlinePosition[    153965,       3437]*)
(*  CellTagsIndexPosition[    153888,       3431]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Solving a Transportation Problem", "Title"],

Cell[CellGroupData[{

Cell["Overview", "Section",
  CellTags->"Transport"],

Cell[TextData[{
  "In this example, supply and demand data for selected US cities is obtained \
from an Excel spreadsheet using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Link for Excel v 3.0.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is then used to calculate and visualize the optimal shipping strategy. \
The end result for a sample study of ten supply cities and fifty demand \
cities is shown below. "
}], "Text",
  CellTags->"Transport"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setup", "Section",
  CellTags->"Transport"],

Cell[BoxData[
    \(Needs["\<ExcelLink`\>"]\)], "Input"],

Cell[BoxData[
    \(Needs["\<Miscellaneous`WorldPlot`\>"]\)], "Input",
  CellTags->"Transport"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input", "Section",
  CellTags->"Transport"],

Cell[CellGroupData[{

Cell[BoxData[
    \(citytable\  = 
      Excel["\<Transport.xls\>", "\<Locations\>", All]\)], "Input",
  CellTags->"Transport"],

Cell[BoxData[
    \({{"City", "State", "Lat", "Lon", "Supply", 
        "Demand"}, {"Alexander City", "Alabama ", 32.95`, \(-85.95`\), 0.`, 
        0.`}, {"Anniston", "Alabama ", 33.5833333333333`, \(-85.85`\), 0.`, 
        0.`}, {"Auburn", "Alabama ", 32.6`, \(-85.5`\), 0.`, 
        0.`}, {"Birmingham", "Alabama ", 33.5666666666667`, \(-86.75`\), 0.`, 
        0.`}, {"Decatur", "Alabama ", 
        34.6166666666667`, \(-86.9833333333333`\), 0.`, 0.`}, {"Dothan", 
        "Alabama ", 31.3166666666667`, \(-85.45`\), 0.`, 0.`}, {"Florence", 
        "Alabama ", 34.8`, \(-87.6666666666667`\), 0.`, 0.`}, {"Gadsden", 
        "Alabama ", 34.0166666666667`, \(-86.`\), 0.`, 0.`}, {"Huntsville", 
        "Alabama ", 34.7`, \(-86.5833333333333`\), 0.`, 0.`}, {"Mobile", 
        "Alabama ", 30.6833333333333`, \(-88.25`\), 0.`, 0.`}, {"Montgomery", 
        "Alabama ", 32.3833333333333`, \(-86.3666666666667`\), 0.`, 
        0.`}, {"Selma", "Alabama ", 
        32.3333333333333`, \(-87.9833333333333`\), 0.`, 0.`}, {"Talladega", 
        "Alabama ", 33.45`, \(-86.1`\), 0.`, 0.`}, {"Tuscaloosa", "Alabama ", 
        33.2166666666667`, \(-87.6166666666667`\), 0.`, 0.`}, {"Douglas", 
        "Arizona", 31.45`, \(-109.6`\), 0.`, 0.`}, {"Flagstaff", "Arizona", 
        35.1333333333333`, \(-111.666666666667`\), 0.`, 
        0.`}, {"Fort Huachuca", "Arizona", 
        31.5833333333333`, \(-110.333333333333`\), 199.`, 0.`}, {"Kingman", 
        "Arizona", 35.2`, \(-114.016666666667`\), 0.`, 0.`}, {"Nogales", 
        "Arizona", 31.35`, \(-110.916666666667`\), 0.`, 0.`}, {"Phoenix", 
        "Arizona", 33.4333333333333`, \(-112.016666666667`\), 0.`, 
        0.`}, {"Prescott", "Arizona", 34.65`, \(-112.433333333333`\), 0.`, 
        0.`}, {"Tucson", "Arizona", 
        32.1166666666667`, \(-110.933333333333`\), 0.`, 0.`}, {"Winslow", 
        "Arizona", 35.0166666666667`, \(-110.733333333333`\), 0.`, 
        0.`}, {"Yuma", "Arizona", 32.65`, \(-114.616666666667`\), 0.`, 
        0.`}, {"Camden", "Arkansas", 33.6`, \(-92.8166666666667`\), 0.`, 
        0.`}, {"El Dorado", "Arkansas", 
        33.2166666666667`, \(-92.8166666666667`\), 0.`, 
        0.`}, {"Fayetteville", "Arkansas", 36.`, \(-94.1666666666667`\), 0.`, 
        0.`}, {"Fort Smith", "Arkansas", 
        35.3333333333333`, \(-94.3666666666667`\), 0.`, 0.`}, {"Hot Springs", 
        "Arkansas", 34.4833333333333`, \(-93.1`\), 0.`, 0.`}, {"Jonesboro", 
        "Arkansas", 35.8333333333333`, \(-90.7`\), 0.`, 0.`}, {"Little Rock", 
        "Arkansas", 34.7333333333333`, \(-92.2333333333333`\), 0.`, 
        0.`}, {"Pine Bluff", "Arkansas", 34.3`, \(-92.0833333333333`\), 0.`, 
        0.`}, {"Texarkana", "Arkansas", 33.45`, \(-93.9833333333333`\), 0.`, 
        0.`}, {"Bakersfield", "California", 35.4166666666667`, \(-119.05`\), 
        0.`, 0.`}, {"Barstow", "California", 34.85`, \(-116.783333333333`\), 
        0.`, 0.`}, {"Blythe", "California", 
        33.6166666666667`, \(-114.716666666667`\), 0.`, 0.`}, {"Burbank", 
        "California", 34.2`, \(-118.35`\), 0.`, 0.`}, {"Chico", "California", 
        39.8`, \(-121.85`\), 0.`, 0.`}, {"Concord", "California", 
        37.9666666666667`, \(-121.983333333333`\), 0.`, 0.`}, {"Covina", 
        "California", 34.0833333333333`, \(-117.866666666667`\), 0.`, 
        0.`}, {"Crescent City", "California", 41.7666666666667`, \(-124.2`\), 
        0.`, 0.`}, {"Downey", "California", 
        33.9333333333333`, \(-118.133333333333`\), 0.`, 0.`}, {"El Cajon", 
        "California", 32.8166666666667`, \(-116.966666666667`\), 0.`, 
        0.`}, {"El Cerrito", "California", 
        32.8166666666667`, \(-115.666666666667`\), 0.`, 32.`}, {"Escondido", 
        "California", 33.1166666666667`, \(-117.083333333333`\), 0.`, 
        0.`}, {"Eureka", "California", 40.9833333333333`, \(-124.1`\), 0.`, 
        0.`}, {"Arcata", "California", 40.9833333333333`, \(-124.1`\), 0.`, 
        0.`}, {"Fairfield", "California", 
        38.2666666666667`, \(-121.933333333333`\), 0.`, 0.`}, {"Fresno", 
        "California", 36.7666666666667`, \(-119.716666666667`\), 0.`, 
        0.`}, {"Laguna Beach", "California", 33.55`, \(-117.783333333333`\), 
        0.`, 48.`}, {"Livermore", "California", 37.7`, \(-121.95`\), 0.`, 
        0.`}, {"Lompoc", "California", 
        34.7166666666667`, \(-120.566666666667`\), 0.`, 0.`}, {"Long Beach", 
        "California", 33.8166666666667`, \(-118.15`\), 0.`, 
        0.`}, {"Los Angeles", "California", 33.9333333333333`, \(-118.4`\), 
        0.`, 0.`}, {"Merced", "California", 
        37.3833333333333`, \(-120.566666666667`\), 0.`, 0.`}, {"Modesto", 
        "California", 37.65`, \(-121.`\), 0.`, 73.`}, {"Monterey", 
        "California", 36.6`, \(-121.9`\), 0.`, 0.`}, {"Napa", "California", 
        38.2166666666667`, \(-122.283333333333`\), 0.`, 0.`}, {"Needles", 
        "California", 34.6`, \(-114.616666666667`\), 0.`, 0.`}, {"Oakland", 
        "California", 37.8166666666667`, \(-122.316666666667`\), 0.`, 
        0.`}, {"Oceanside", "California", 
        33.2333333333333`, \(-117.416666666667`\), 0.`, 0.`}, {"Ontario", 
        "California", 34.05`, \(-117.6`\), 0.`, 0.`}, {"Oxnard", 
        "California", 34.2`, \(-119.183333333333`\), 0.`, 0.`}, {"Palmdale", 
        "California", 34.6333333333333`, \(-118.1`\), 0.`, 
        34.`}, {"Palm Springs", "California", 
        33.8166666666667`, \(-116.533333333333`\), 0.`, 0.`}, {"Pasadena", 
        "California", 34.15`, \(-118.15`\), 0.`, 0.`}, {"Petaluma", 
        "California", 38.2333333333333`, \(-122.633333333333`\), 0.`, 
        0.`}, {"Pomona", "California", 34.05`, \(-117.75`\), 0.`, 
        0.`}, {"Redding", "California", 40.5166666666667`, \(-122.3`\), 0.`, 
        0.`}, {"Redlands", "California", 34.05`, \(-117.183333333333`\), 0.`, 
        0.`}, {"Richmond", "California", 37.9333333333333`, \(-122.35`\), 
        0.`, 0.`}, {"Riverside", "California", 33.9`, \(-117.25`\), 0.`, 
        0.`}, {"Sacramento", "California", 38.5166666666667`, \(-121.5`\), 
        0.`, 0.`}, {"Salinas", "California", 36.6666666666667`, \(-121.6`\), 
        0.`, 0.`}, {"San Bernadino", "California", 
        34.1333333333333`, \(-117.266666666667`\), 0.`, 0.`}, {"San Diego", 
        "California", 32.7333333333333`, \(-117.166666666667`\), 0.`, 
        0.`}, {"San Fernando", "California", 
        34.2833333333333`, \(-118.466666666667`\), 0.`, 
        0.`}, {"San Francisco", "California", 
        37.6166666666667`, \(-122.383333333333`\), 0.`, 0.`}, {"San Jose", 
        "California", 37.3666666666667`, \(-121.933333333333`\), 0.`, 
        0.`}, {"San Louis Obispo", "California", 
        35.3333333333333`, \(-120.716666666667`\), 0.`, 0.`}, {"Santa Ana", 
        "California", 33.75`, \(-117.866666666667`\), 0.`, 
        0.`}, {"Santa Barbara", "California", 
        34.4333333333333`, \(-119.833333333333`\), 0.`, 0.`}, {"Santa Cruz", 
        "California", 36.9833333333333`, \(-122.016666666667`\), 0.`, 
        0.`}, {"Santa Maria", "California", 34.9`, \(-120.45`\), 0.`, 
        0.`}, {"Santa Monica", "California", 
        34.0166666666667`, \(-118.483333333333`\), 0.`, 0.`}, {"Santa Paula", 
        "California", 34.35`, \(-119.083333333333`\), 0.`, 
        0.`}, {"Santa Rosa", "California", 
        38.5166666666667`, \(-122.816666666667`\), 0.`, 0.`}, {"Stockton", 
        "California", 37.9`, \(-121.25`\), 0.`, 0.`}, {"Ukiah", "California", 
        39.15`, \(-123.2`\), 0.`, 60.`}, {"Visalia", "California", 
        36.3333333333333`, \(-119.3`\), 0.`, 0.`}, {"Yreka", "California", 
        41.7166666666667`, \(-122.633333333333`\), 0.`, 0.`}, {"Yuba City", 
        "California", 39.1333333333333`, \(-121.6`\), 0.`, 0.`}, {"Alamosa", 
        "Colorado", 37.45`, \(-105.866666666667`\), 0.`, 0.`}, {"Boulder", 
        "Colorado", 40.`, \(-105.266666666667`\), 0.`, 
        0.`}, {"Colorado Springs", "Colorado", 
        38.8166666666667`, \(-104.716666666667`\), 0.`, 0.`}, {"Denver", 
        "Colorado", 39.75`, \(-104.866666666667`\), 0.`, 0.`}, {"Durango", 
        "Colorado", 37.2833333333333`, \(-107.883333333333`\), 0.`, 
        0.`}, {"Fort Collins", "Colorado", 40.75`, \(-105.083333333333`\), 
        0.`, 0.`}, {"Grand Junction", "Colorado", 
        39.1166666666667`, \(-108.533333333333`\), 0.`, 79.`}, {"Greeley", 
        "Colorado", 40.4333333333333`, \(-104.633333333333`\), 0.`, 
        0.`}, {"Lajunta", "Colorado", 38.05`, \(-103.5`\), 0.`, 
        0.`}, {"Leadville", "Colorado", 39.25`, \(-106.3`\), 0.`, 
        0.`}, {"Pueblo", "Colorado", 38.3`, \(-104.483333333333`\), 0.`, 
        0.`}, {"Sterling", "Colorado", 40.6166666666667`, \(-103.2`\), 0.`, 
        0.`}, {"Trinidad", "Colorado", 37.25`, \(-104.333333333333`\), 0.`, 
        0.`}, {"Bridgeport", "Connecticut", 
        41.1833333333333`, \(-73.1833333333333`\), 0.`, 0.`}, {"Hartford", 
        "Connecticut", 41.7333333333333`, \(-72.65`\), 0.`, 
        0.`}, {"Brainard Field", "Connecticut", 
        41.7333333333333`, \(-72.65`\), 0.`, 0.`}, {"New Haven", 
        "Connecticut", 41.3166666666667`, \(-73.9166666666667`\), 0.`, 
        0.`}, {"New London", "Connecticut", 41.35`, \(-72.1`\), 0.`, 
        0.`}, {"Norwalk", "Connecticut", 
        41.1166666666667`, \(-73.4166666666667`\), 0.`, 0.`}, {"Norwick", 
        "Connecticut", 41.5333333333333`, \(-72.0666666666667`\), 0.`, 
        0.`}, {"Waterbury", "Connecticut", 
        41.5833333333333`, \(-73.0666666666667`\), 0.`, 
        0.`}, {"Widsor Locks", "Connecticut", 
        41.9333333333333`, \(-72.6833333333333`\), 0.`, 0.`}, {"Bradley Fld", 
        "Connecticut", 41.9333333333333`, \(-72.6833333333333`\), 0.`, 
        0.`}, {"Wilmington", "Delaware", 39.6666666666667`, \(-75.6`\), 0.`, 
        0.`}, {"Washington", "Dc", 38.85`, \(-77.0333333333333`\), 0.`, 
        0.`}, {"Belle Glade", "Florida", 26.65`, \(-80.65`\), 0.`, 
        0.`}, {"Cape Kennedy", "Florida", 
        28.4833333333333`, \(-80.5666666666667`\), 0.`, 
        0.`}, {"Daytona Beach", "Florida", 29.1833333333333`, \(-81.05`\), 
        0.`, 0.`}, {"East Fort Lauderdale", "Florida", 
        26.0666666666667`, \(-80.15`\), 0.`, 0.`}, {"Fort Myers", "Florida", 
        26.5833333333333`, \(-81.8666666666667`\), 0.`, 0.`}, {"Fort Pierce", 
        "Florida", 27.4666666666667`, \(-80.35`\), 0.`, 0.`}, {"Gainsville", 
        "Florida", 29.6833333333333`, \(-82.2666666666667`\), 0.`, 
        0.`}, {"Jacksonville", "Florida", 30.5`, \(-81.7`\), 0.`, 
        0.`}, {"Key West", "Florida", 24.55`, \(-81.75`\), 0.`, 
        0.`}, {"Lakeland Co", "Florida", 28.0333333333333`, \(-81.95`\), 0.`, 
        0.`}, {"Miami", "Florida", 25.8`, \(-80.2666666666667`\), 0.`, 
        0.`}, {"Miami Beach Co", "Florida", 
        25.7833333333333`, \(-80.2833333333333`\), 0.`, 0.`}, {"Ocala", 
        "Florida", 29.1833333333333`, \(-82.1333333333333`\), 0.`, 
        0.`}, {"Orlando", "Florida", 28.55`, \(-81.3833333333333`\), 0.`, 
        0.`}, {"Panama City", "Florida", 
        30.0666666666667`, \(-85.5833333333333`\), 0.`, 0.`}, {"Pensacola", 
        "Florida", 30.4166666666667`, \(-87.2166666666667`\), 0.`, 
        0.`}, {"St. Augustine", "Florida", 
        29.9666666666667`, \(-81.3333333333333`\), 0.`, 
        0.`}, {"St. Petersburg", "Florida", 
        27.7666666666667`, \(-83.3333333333333`\), 0.`, 0.`}, {"Stanford", 
        "Florida", 28.7666666666667`, \(-81.2833333333333`\), 0.`, 
        42.`}, {"Sarasota", "Florida", 27.3833333333333`, \(-82.55`\), 0.`, 
        0.`}, {"Tallahassee", "Florida", 
        30.3833333333333`, \(-84.3666666666667`\), 0.`, 0.`}, {"Tampa", 
        "Florida", 27.9666666666667`, \(-82.5333333333333`\), 0.`, 
        0.`}, {"West Palm Beach", "Florida", 26.6833333333333`, \(-80.1`\), 
        0.`, 0.`}, {"Albany", "Georgia", 31.6`, \(-84.0833333333333`\), 0.`, 
        13.`}, {"Americus", "Georgia", 32.05`, \(-84.2333333333333`\), 0.`, 
        0.`}, {"Athens", "Georgia", 33.95`, \(-83.3166666666667`\), 0.`, 
        0.`}, {"Atlanta", "Georgia", 33.65`, \(-84.4333333333333`\), 0.`, 
        0.`}, {"Augusta", "Georgia", 
        33.3666666666667`, \(-81.9666666666667`\), 0.`, 74.`}, {"Brunswick", 
        "Georgia", 31.25`, \(-81.4833333333333`\), 0.`, 0.`}, {"Columbus", 
        "Georgia", 32.5166666666667`, \(-84.9333333333333`\), 0.`, 
        0.`}, {"Dalton", "Georgia", 34.5666666666667`, \(-84.95`\), 0.`, 
        0.`}, {"Dublin", "Georgia", 32.3333333333333`, \(-82.9`\), 0.`, 
        0.`}, {"Gainsville", "Georgia", 
        34.1833333333333`, \(-83.6833333333333`\), 0.`, 0.`}, {"Griffin", 
        "Georgia", 33.2166666666667`, \(-84.2666666666667`\), 0.`, 
        0.`}, {"LaGrange", "Georgia", 
        33.0166666666667`, \(-85.0666666666667`\), 0.`, 12.`}, {"Macon", 
        "Georgia", 32.7`, \(-83.65`\), 0.`, 0.`}, {"Marietta", "Georgia", 
        33.9166666666667`, \(-84.5166666666667`\), 0.`, 0.`}, {"Savannah", 
        "Georgia", 32.1333333333333`, \(-81.2`\), 0.`, 11.`}, {"Valdosta", 
        "Georgia", 30.9666666666667`, \(-83.2`\), 0.`, 0.`}, {"Waycross", 
        "Georgia", 31.25`, \(-82.4`\), 0.`, 0.`}, {"Boise", "Idaho", 
        43.5666666666667`, \(-116.216666666667`\), 0.`, 0.`}, {"Burley", 
        "Idaho", 42.5333333333333`, \(-113.766666666667`\), 0.`, 
        0.`}, {"Coeur D'Alene", "Idaho", 
        47.7666666666667`, \(-116.816666666667`\), 0.`, 0.`}, {"Idaho Falls", 
        "Idaho", 43.5166666666667`, \(-112.066666666667`\), 0.`, 
        0.`}, {"Lewiston", "Idaho", 
        46.3833333333333`, \(-117.016666666667`\), 0.`, 0.`}, {"Moscow", 
        "Idaho", 46.7333333333333`, \(-116.966666666667`\), 0.`, 
        0.`}, {"Mountain Home AFB", "Idaho", 43.0333333333333`, \(-115.9`\), 
        0.`, 0.`}, {"Pocatello", "Idaho", 42.9166666666667`, \(-112.6`\), 
        0.`, 0.`}, {"Twin Falls", "Idaho", 
        42.4833333333333`, \(-114.483333333333`\), 0.`, 0.`}, {"Aurora", 
        "Illinois", 41.75`, \(-88.3333333333333`\), 356.`, 
        0.`}, {"Belleville", "Illinois", 38.55`, \(-89.85`\), 0.`, 
        0.`}, {"Bloomington", "Illinois", 40.4833333333333`, \(-88.95`\), 
        0.`, 0.`}, {"Carbondale", "Illinois", 37.7833333333333`, \(-89.25`\), 
        0.`, 0.`}, {"Champaign-Urbana", "Illinois", 
        40.0333333333333`, \(-88.2833333333333`\), 0.`, 0.`}, {"Chicago", 
        "Illinois", 41.8833333333333`, \(-87.6333333333333`\), 0.`, 
        0.`}, {"Danville", "Illinois", 40.2`, \(-87.6`\), 0.`, 
        0.`}, {"Decatur", "Illinois", 
        39.8333333333333`, \(-88.8666666666667`\), 0.`, 0.`}, {"Dixon", 
        "Illinois", 41.8333333333333`, \(-89.4833333333333`\), 0.`, 
        0.`}, {"Elgin", "Illinois", 
        42.0333333333333`, \(-88.2666666666667`\), 0.`, 0.`}, {"Freeport", 
        "Illinois", 42.3`, \(-89.6166666666667`\), 0.`, 0.`}, {"Galesburg", 
        "Illinois", 40.9333333333333`, \(-90.4333333333333`\), 0.`, 
        0.`}, {"Greenville", "Illinois", 38.8833333333333`, \(-89.4`\), 0.`, 
        0.`}, {"Joliet", "Illinois", 
        41.5166666666667`, \(-88.1666666666667`\), 0.`, 0.`}, {"Kankakee", 
        "Illinois", 41.0833333333333`, \(-87.9166666666667`\), 0.`, 
        80.`}, {"La Salle", "Illinois", 41.3166666666667`, \(-89.1`\), 0.`, 
        0.`}, {"Peru", "Illinois", 41.3166666666667`, \(-89.1`\), 0.`, 
        63.`}, {"Macomb", "Illinois", 
        40.4666666666667`, \(-90.6666666666667`\), 0.`, 0.`}, {"Moline", 
        "Illinois", 41.45`, \(-90.5166666666667`\), 0.`, 0.`}, {"Mt Vernon", 
        "Illinois", 38.3166666666667`, \(-88.8666666666667`\), 0.`, 
        0.`}, {"Peoria", "Illinois", 
        40.6666666666667`, \(-89.6833333333333`\), 0.`, 0.`}, {"Quincy", 
        "Illinois", 39.95`, \(-91.2`\), 0.`, 0.`}, {"Rantoul", "Illinois", 
        40.3`, \(-88.1333333333333`\), 0.`, 0.`}, {"Rockford", "Illinois", 
        42.35`, \(-89.05`\), 0.`, 0.`}, {"Springfield", "Illinois", 
        39.8333333333333`, \(-89.6666666666667`\), 0.`, 0.`}, {"Waukegan", 
        "Illinois", 42.35`, \(-87.8833333333333`\), 0.`, 0.`}, {"Anderson", 
        "Indiana", 40.1`, \(-85.6166666666667`\), 0.`, 14.`}, {"Bedford", 
        "Indiana", 38.85`, \(-86.5`\), 0.`, 0.`}, {"Bloomington", "Indiana", 
        39.1333333333333`, \(-86.6166666666667`\), 0.`, 0.`}, {"Columbus", 
        "Indiana", 39.2666666666667`, \(-85.9`\), 0.`, 
        0.`}, {"Crawfordsville", "Indiana", 40.05`, \(-86.9`\), 0.`, 
        44.`}, {"Evansville", "Indiana", 38.05`, \(-87.5333333333333`\), 0.`, 
        37.`}, {"Fort Wayne", "Indiana", 41.`, \(-85.2`\), 0.`, 
        0.`}, {"Goshen", "Indiana", 41.5333333333333`, \(-85.8`\), 0.`, 
        0.`}, {"Hobart", "Indiana", 41.5333333333333`, \(-87.25`\), 0.`, 
        0.`}, {"Huntington", "Indiana", 40.8833333333333`, \(-85.5`\), 0.`, 
        0.`}, {"Indianapolis", "Indiana", 
        39.7333333333333`, \(-86.2833333333333`\), 0.`, 
        0.`}, {"Jeffersonville", "Indiana", 38.2833333333333`, \(-85.75`\), 
        0.`, 0.`}, {"Kokomo", "Indiana", 40.4166666666667`, \(-86.05`\), 0.`, 
        0.`}, {"Lafayette", "Indiana", 
        40.0333333333333`, \(-86.0833333333333`\), 0.`, 0.`}, {"La Porte", 
        "Indiana", 41.6`, \(-86.7166666666667`\), 0.`, 0.`}, {"Marion", 
        "Indiana", 40.4833333333333`, \(-85.6833333333333`\), 0.`, 
        0.`}, {"Muncie", "Indiana", 40.1833333333333`, \(-85.35`\), 0.`, 
        0.`}, {"Peru", "Indiana", 40.65`, \(-86.15`\), 0.`, 
        0.`}, {"Richmond", "Indiana", 
        39.7666666666667`, \(-84.8333333333333`\), 0.`, 0.`}, {"Shelbyville", 
        "Indiana", 39.5166666666667`, \(-85.7833333333333`\), 0.`, 
        0.`}, {"South Bend", "Indiana", 41.7`, \(-86.3166666666667`\), 0.`, 
        0.`}, {"Terre Haute", "Indiana", 39.45`, \(-87.3`\), 0.`, 
        0.`}, {"Valparaiso", "Indiana", 
        41.5166666666667`, \(-87.0333333333333`\), 0.`, 0.`}, {"Vincennes", 
        "Indiana", 38.6833333333333`, \(-87.5333333333333`\), 0.`, 
        0.`}, {"Ames", "Iowa", 42.0333333333333`, \(-93.8`\), 0.`, 
        0.`}, {"Burlington", "Iowa", 
        40.7833333333333`, \(-91.1166666666667`\), 0.`, 
        0.`}, {"Cedar Rapids", "Iowa", 41.8833333333333`, \(-91.7`\), 0.`, 
        0.`}, {"Clinton", "Iowa", 41.8333333333333`, \(-90.2166666666667`\), 
        0.`, 0.`}, {"Council Bluffs", "Iowa", 
        41.3333333333333`, \(-95.8166666666667`\), 0.`, 0.`}, {"Des Moines", 
        "Iowa", 41.5333333333333`, \(-93.65`\), 0.`, 0.`}, {"Dubuque", 
        "Iowa", 42.4`, \(-90.7`\), 0.`, 0.`}, {"Fort Dodge", "Iowa", 
        42.55`, \(-94.1833333333333`\), 0.`, 0.`}, {"Iowa City", "Iowa", 
        41.6333333333333`, \(-91.55`\), 0.`, 0.`}, {"Keokuk", "Iowa", 
        40.4`, \(-91.4`\), 0.`, 0.`}, {"Marshalltown", "Iowa", 
        42.0666666666667`, \(-92.9333333333333`\), 0.`, 0.`}, {"Mason City", 
        "Iowa", 43.15`, \(-93.3333333333333`\), 0.`, 0.`}, {"Newton", "Iowa", 
        41.6833333333333`, \(-93.0333333333333`\), 0.`, 39.`}, {"Ottumwa", 
        "Iowa", 41.1`, \(-92.45`\), 0.`, 53.`}, {"Sioux City", "Iowa", 
        42.4`, \(-96.3833333333333`\), 0.`, 0.`}, {"Waterloo", "Iowa", 
        42.55`, \(-92.4`\), 0.`, 0.`}, {"Atchison", "Kansas", 
        39.5666666666667`, \(-95.1166666666667`\), 0.`, 0.`}, {"Chanute", 
        "Kansas", 37.6666666666667`, \(-95.4833333333333`\), 0.`, 
        0.`}, {"Dodge City", "Kansas", 
        37.7666666666667`, \(-99.9666666666667`\), 0.`, 0.`}, {"El Dorado", 
        "Kansas", 37.8166666666667`, \(-96.8333333333333`\), 0.`, 
        0.`}, {"Emporia", "Kansas", 38.3333333333333`, \(-96.2`\), 0.`, 
        0.`}, {"Garden City", "Kansas", 
        37.9333333333333`, \(-100.733333333333`\), 0.`, 0.`}, {"Goodland", 
        "Kansas", 39.3666666666667`, \(-101.7`\), 0.`, 0.`}, {"Great Bend", 
        "Kansas", 38.35`, \(-98.8666666666667`\), 0.`, 0.`}, {"Hutchinson", 
        "Kansas", 38.0666666666667`, \(-97.8666666666667`\), 0.`, 
        0.`}, {"Liberal", "Kansas", 37.05`, \(-100.966666666667`\), 0.`, 
        0.`}, {"Manhattan", "Kansas", 39.05`, \(-96.7666666666667`\), 0.`, 
        0.`}, {"Ft Riley", "Kansas", 39.05`, \(-96.7666666666667`\), 0.`, 
        0.`}, {"Parsons", "Kansas", 
        37.3333333333333`, \(-95.5166666666667`\), 0.`, 0.`}, {"Russell", 
        "Kansas", 38.8666666666667`, \(-98.8166666666667`\), 0.`, 
        0.`}, {"Salina", "Kansas", 38.8`, \(-97.65`\), 0.`, 0.`}, {"Topeka", 
        "Kansas", 39.0666666666667`, \(-95.6333333333333`\), 478.`, 
        0.`}, {"Wichita", "Kansas", 37.65`, \(-97.4166666666667`\), 0.`, 
        82.`}, {"Ashland", "Kentucky", 38.55`, \(-82.7333333333333`\), 0.`, 
        0.`}, {"Bowling Green", "Kentucky", 
        35.9666666666667`, \(-86.4666666666667`\), 0.`, 0.`}, {"Corbin", 
        "Kentucky", 36.95`, \(-84.1`\), 0.`, 0.`}, {"Covington", "Kentucky", 
        39.05`, \(-84.6666666666667`\), 0.`, 0.`}, {"Hopkinsville", 
        "Kentucky", 36.6666666666667`, \(-87.4833333333333`\), 0.`, 
        46.`}, {"Ft Campbell", "Kentucky", 
        36.6666666666667`, \(-87.4833333333333`\), 0.`, 0.`}, {"Lexington", 
        "Kentucky", 38.0333333333333`, \(-84.6`\), 0.`, 0.`}, {"Louisville", 
        "Kentucky", 38.1833333333333`, \(-85.7333333333333`\), 0.`, 
        0.`}, {"Madisonville", "Kentucky", 
        37.3166666666667`, \(-87.4833333333333`\), 0.`, 0.`}, {"Owensboro", 
        "Kentucky", 37.75`, \(-87.1666666666667`\), 0.`, 0.`}, {"Paducah", 
        "Kentucky", 37.0666666666667`, \(-88.7666666666667`\), 0.`, 
        0.`}, {"Alexandria", "Louisiana", 31.4`, \(-92.3`\), 0.`, 
        0.`}, {"Baton Rouge", "Louisiana", 30.5333333333333`, \(-91.15`\), 
        0.`, 0.`}, {"Bogalusa", "Louisiana", 
        30.7833333333333`, \(-89.8666666666667`\), 0.`, 0.`}, {"Houma", 
        "Louisiana", 29.5166666666667`, \(-90.6666666666667`\), 180.`, 
        0.`}, {"Lafayette", "Louisiana", 30.2`, \(-92.`\), 0.`, 
        0.`}, {"Lake Charles", "Louisiana", 
        30.1166666666667`, \(-93.2166666666667`\), 0.`, 0.`}, {"Minden", 
        "Louisiana", 32.6`, \(-93.3`\), 0.`, 0.`}, {"Monroe", "Louisiana", 
        32.5166666666667`, \(-92.0333333333333`\), 0.`, 
        0.`}, {"Natchitoches", "Louisiana", 
        31.7666666666667`, \(-93.0833333333333`\), 0.`, 0.`}, {"New Orleans", 
        "Louisiana", 29.9833333333333`, \(-90.25`\), 0.`, 
        0.`}, {"Shreveport", "Louisiana", 
        32.4666666666667`, \(-93.8166666666667`\), 0.`, 0.`}, {"Augusta", 
        "Maine", 44.3166666666667`, \(-69.8`\), 0.`, 0.`}, {"Bangor", 
        "Maine", 44.8`, \(-68.8333333333333`\), 0.`, 0.`}, {"Caribou", 
        "Maine", 46.8666666666667`, \(-68.0166666666667`\), 0.`, 
        0.`}, {"Lewiston", "Maine", 44.0333333333333`, \(-70.25`\), 0.`, 
        0.`}, {"Millinocket", "Maine", 45.65`, \(-68.7`\), 0.`, 
        0.`}, {"Portland", "Maine", 43.65`, \(-70.3166666666667`\), 0.`, 
        0.`}, {"Waterville", "Maine", 
        44.5333333333333`, \(-69.6666666666667`\), 0.`, 0.`}, {"Baltimore", 
        "Maryland", 39.1833333333333`, \(-76.6666666666667`\), 0.`, 
        92.`}, {"Baltimore Co", "Maryland", 
        39.3333333333333`, \(-76.4166666666667`\), 0.`, 0.`}, {"Cumberland", 
        "Maryland", 39.6166666666667`, \(-78.7666666666667`\), 0.`, 
        0.`}, {"Frederick", "Maryland", 39.45`, \(-77.4166666666667`\), 0.`, 
        0.`}, {"Hagerstown", "Maryland", 39.7`, \(-77.7333333333333`\), 0.`, 
        0.`}, {"Salisbury", "Maryland", 38.3333333333333`, \(-75.5`\), 0.`, 
        0.`}, {"Boston", "Massachusetts", 
        42.3666666666667`, \(-71.0333333333333`\), 0.`, 0.`}, {"Clinton", 
        "Massachusetts", 42.4`, \(-71.6833333333333`\), 0.`, 
        0.`}, {"Fall River", "Massachusetts", 
        41.7166666666667`, \(-71.1333333333333`\), 0.`, 0.`}, {"Framingham", 
        "Massachusetts", 42.2833333333333`, \(-71.4166666666667`\), 0.`, 
        0.`}, {"Gloucester", "Massachusetts", 
        42.5833333333333`, \(-70.6833333333333`\), 0.`, 0.`}, {"Greenfield", 
        "Massachusetts", 42.05`, \(-72.0666666666667`\), 0.`, 
        0.`}, {"Lawrence", "Massachusetts", 42.7`, \(-71.1666666666667`\), 
        0.`, 0.`}, {"Lowell", "Massachusetts", 
        42.65`, \(-71.3166666666667`\), 0.`, 0.`}, {"New Bedford", 
        "Massachusetts", 41.6833333333333`, \(-70.9666666666667`\), 0.`, 
        0.`}, {"Pittsfield", "Massachusetts", 42.4333333333333`, \(-73.3`\), 
        304.`, 77.`}, {"Springfield", "Massachusetts", 
        42.2`, \(-72.5333333333333`\), 0.`, 0.`}, {"Taunton", 
        "Massachusetts", 41.9`, \(-71.0666666666667`\), 0.`, 
        0.`}, {"Worcester", "Massachusetts", 
        42.2666666666667`, \(-71.8666666666667`\), 0.`, 0.`}, {"Adrian", 
        "Michigan", 41.9166666666667`, \(-84.0166666666667`\), 0.`, 
        0.`}, {"Alpena", "Michigan", 
        45.0666666666667`, \(-83.4333333333333`\), 0.`, 
        0.`}, {"Battle Creek", "Michigan", 42.3166666666667`, \(-85.25`\), 
        0.`, 0.`}, {"Benton Harbor", "Michigan", 
        42.1333333333333`, \(-86.4333333333333`\), 0.`, 0.`}, {"Detroit", 
        "Michigan", 42.4166666666667`, \(-83.0166666666667`\), 0.`, 
        35.`}, {"Escanaba", "Michigan", 
        45.7333333333333`, \(-87.0833333333333`\), 0.`, 0.`}, {"Flint", 
        "Michigan", 42.9666666666667`, \(-83.7333333333333`\), 0.`, 
        0.`}, {"Grand Rapids", "Michigan", 
        42.8833333333333`, \(-85.5166666666667`\), 0.`, 0.`}, {"Holland", 
        "Michigan", 42.7`, \(-86.1`\), 0.`, 0.`}, {"Jackson", "Michigan", 
        42.2666666666667`, \(-84.4666666666667`\), 0.`, 0.`}, {"Kalamazoo", 
        "Michigan", 42.2833333333333`, \(-85.6`\), 0.`, 0.`}, {"Lansing", 
        "Michigan", 42.7833333333333`, \(-84.6`\), 0.`, 0.`}, {"Marquette", 
        "Michigan", 46.5666666666667`, \(-87.4`\), 0.`, 0.`}, {"Mt Pleasant", 
        "Michigan", 43.5833333333333`, \(-84.7666666666667`\), 0.`, 
        0.`}, {"Muskegon", "Michigan", 
        43.1666666666667`, \(-86.2333333333333`\), 0.`, 0.`}, {"Pontiac", 
        "Michigan", 42.6666666666667`, \(-83.4166666666667`\), 0.`, 
        0.`}, {"Port Huron", "Michigan", 
        42.9833333333333`, \(-82.4166666666667`\), 0.`, 0.`}, {"Saginaw", 
        "Michigan", 43.5333333333333`, \(-84.0833333333333`\), 0.`, 
        0.`}, {"Sault Ste. Marie", "Michigan", 
        46.4666666666667`, \(-84.3666666666667`\), 0.`, 
        5.`}, {"Traverse City", "Michigan", 44.75`, \(-85.5833333333333`\), 
        0.`, 0.`}, {"Ypsilanti", "Michigan", 
        42.2333333333333`, \(-83.5333333333333`\), 0.`, 0.`}, {"Albert Lea", 
        "Minnesota", 43.65`, \(-93.35`\), 0.`, 15.`}, {"Alexandria", 
        "Minnesota", 45.8666666666667`, \(-95.3833333333333`\), 0.`, 
        0.`}, {"Bemidji", "Minnesota", 
        47.5166666666667`, \(-94.9333333333333`\), 0.`, 0.`}, {"Brainerd", 
        "Minnesota", 46.4`, \(-94.1333333333333`\), 0.`, 0.`}, {"Duluth", 
        "Minnesota", 46.8333333333333`, \(-92.1833333333333`\), 0.`, 
        0.`}, {"Fairbault", "Minnesota", 44.3`, \(-93.2666666666667`\), 0.`, 
        0.`}, {"Fergus Falls", "Minnesota", 
        46.2666666666667`, \(-96.0666666666667`\), 0.`, 
        0.`}, {"International Falls", "Minnesota", 
        48.5666666666667`, \(-93.3833333333333`\), 0.`, 0.`}, {"Mankato", 
        "Minnesota", 44.15`, \(-93.9833333333333`\), 0.`, 
        0.`}, {"Minneapolis-St. Paul", "Minnesota", 
        44.8833333333333`, \(-93.2166666666667`\), 0.`, 0.`}, {"Rochester", 
        "Minnesota", 43.9166666666667`, \(-92.5`\), 0.`, 0.`}, {"St. Cloud", 
        "Minnesota", 45.5833333333333`, \(-94.1833333333333`\), 0.`, 
        0.`}, {"Virginia", "Minnesota", 47.5`, \(-92.55`\), 0.`, 
        0.`}, {"Willmar", "Minnesota", 
        45.1166666666667`, \(-95.0833333333333`\), 0.`, 0.`}, {"Winona", 
        "Minnesota", 44.05`, \(-91.6333333333333`\), 0.`, 0.`}, {"Biloxi", 
        "Mississippi", 30.4166666666667`, \(-88.9166666666667`\), 0.`, 
        0.`}, {"Clarksdale", "Mississippi", 34.2`, \(-90.5666666666667`\), 
        0.`, 0.`}, {"Greenwood", "Mississippi", 
        33.5`, \(-90.0833333333333`\), 0.`, 0.`}, {"Hattiesburg", 
        "Mississippi", 31.2666666666667`, \(-89.25`\), 0.`, 0.`}, {"Jackson", 
        "Mississippi", 32.3166666666667`, \(-90.0833333333333`\), 0.`, 
        0.`}, {"Laurel", "Mississippi", 
        31.6666666666667`, \(-89.1666666666667`\), 0.`, 0.`}, {"Mccomb", 
        "Mississippi", 31.25`, \(-90.4666666666667`\), 0.`, 
        0.`}, {"Meridian", "Mississippi", 32.3333333333333`, \(-88.75`\), 
        0.`, 28.`}, {"Natchez", "Mississippi", 
        31.55`, \(-91.3833333333333`\), 0.`, 0.`}, {"Tupelo", "Mississippi", 
        34.2666666666667`, \(-88.7666666666667`\), 0.`, 0.`}, {"Vicksburg", 
        "Mississippi", 32.4`, \(-90.7833333333333`\), 0.`, 
        0.`}, {"Cape Girardeau", "Missouri", 
        37.2333333333333`, \(-89.5833333333333`\), 0.`, 0.`}, {"Columbia", 
        "Missouri", 38.9666666666667`, \(-92.3666666666667`\), 0.`, 
        0.`}, {"Farmington", "Missouri", 37.7666666666667`, \(-90.4`\), 0.`, 
        0.`}, {"Hannibal", "Missouri", 39.7`, \(-91.35`\), 0.`, 
        0.`}, {"Jefferson City", "Missouri", 
        38.5666666666667`, \(-92.1833333333333`\), 0.`, 0.`}, {"Joplin", 
        "Missouri", 37.15`, \(-94.5`\), 0.`, 0.`}, {"Kansas City", 
        "Missouri", 39.1166666666667`, \(-94.5833333333333`\), 0.`, 
        0.`}, {"Kirksville", "Missouri", 40.1`, \(-92.55`\), 0.`, 
        0.`}, {"Mexico", "Missouri", 39.1833333333333`, \(-91.9`\), 0.`, 
        0.`}, {"Moberly", "Missouri", 39.4`, \(-92.4333333333333`\), 0.`, 
        0.`}, {"Poplar Bluff", "Missouri", 
        36.7666666666667`, \(-90.4166666666667`\), 0.`, 0.`}, {"Rolla", 
        "Missouri", 37.9833333333333`, \(-91.7166666666667`\), 0.`, 
        0.`}, {"St. Joseph", "Missouri", 
        39.7666666666667`, \(-94.9166666666667`\), 0.`, 0.`}, {"St. Louis", 
        "Missouri", 38.75`, \(-90.3833333333333`\), 0.`, 0.`}, {"Sikeston", 
        "Missouri", 36.8833333333333`, \(-89.6`\), 0.`, 0.`}, {"Sedalia", 
        "Missouri", 38.7166666666667`, \(-93.55`\), 0.`, 0.`}, {"Sikeston", 
        "Missouri", 36.8833333333333`, \(-89.6`\), 0.`, 0.`}, {"Springfield", 
        "Missouri", 37.2333333333333`, \(-93.3833333333333`\), 0.`, 
        0.`}, {"Billings", "Montana", 45.8`, \(-108.533333333333`\), 0.`, 
        0.`}, {"Bozeman", "Montana", 45.7833333333333`, \(-111.15`\), 0.`, 
        0.`}, {"Butte", "Montana", 45.95`, \(-112.5`\), 0.`, 
        0.`}, {"Cut Bank", "Montana", 
        48.6166666666667`, \(-112.366666666667`\), 0.`, 0.`}, {"Glasgow", 
        "Montana", 48.4166666666667`, \(-106.533333333333`\), 0.`, 
        73.`}, {"Glendive", "Montana", 47.1333333333333`, \(-104.8`\), 0.`, 
        0.`}, {"Great Falls", "Montana", 
        47.4833333333333`, \(-111.366666666667`\), 0.`, 0.`}, {"Havre", 
        "Montana", 48.5666666666667`, \(-109.666666666667`\), 0.`, 
        0.`}, {"Helena", "Montana", 46.6`, \(-112.`\), 0.`, 
        0.`}, {"Kalispell", "Montana", 48.3`, \(-114.266666666667`\), 0.`, 
        0.`}, {"Lewiston", "Montana", 47.0666666666667`, \(-109.45`\), 0.`, 
        0.`}, {"Livingstown", "Montana", 45.7`, \(-110.433333333333`\), 0.`, 
        0.`}, {"Miles City", "Montana", 
        46.4333333333333`, \(-105.866666666667`\), 0.`, 0.`}, {"Missoula", 
        "Montana", 46.9166666666667`, \(-114.083333333333`\), 0.`, 
        0.`}, {"Beatrice", "Nebraska", 40.2666666666667`, \(-96.75`\), 0.`, 
        0.`}, {"Chadron", "Nebraska", 
        42.8333333333333`, \(-103.083333333333`\), 0.`, 0.`}, {"Columbus", 
        "Nebraska", 41.4666666666667`, \(-97.3333333333333`\), 0.`, 
        0.`}, {"Fremont", "Nebraska", 
        41.4333333333333`, \(-96.4833333333333`\), 0.`, 
        0.`}, {"Grand Island", "Nebraska", 
        40.9833333333333`, \(-98.3166666666667`\), 0.`, 0.`}, {"Hastings", 
        "Nebraska", 40.6`, \(-98.4333333333333`\), 0.`, 0.`}, {"Kearney", 
        "Nebraska", 40.7333333333333`, \(-99.0166666666667`\), 0.`, 
        0.`}, {"Lincoln", "Nebraska", 40.85`, \(-96.75`\), 0.`, 
        0.`}, {"McCook", "Nebraska", 40.2`, \(-100.633333333333`\), 0.`, 
        0.`}, {"Norfolk", "Nebraska", 
        41.9833333333333`, \(-97.4333333333333`\), 0.`, 
        0.`}, {"North Platte", "Nebraska", 
        41.1333333333333`, \(-100.683333333333`\), 0.`, 0.`}, {"Omaha", 
        "Nebraska", 41.3`, \(-95.9`\), 0.`, 0.`}, {"Scottsbluff", "Nebraska", 
        41.8666666666667`, \(-103.6`\), 0.`, 0.`}, {"Sidney", "Nebraska", 
        41.2166666666667`, \(-103.1`\), 0.`, 0.`}, {"Carson City", "Nevada", 
        39.1666666666667`, \(-119.766666666667`\), 0.`, 0.`}, {"Elko", 
        "Nevada", 40.8333333333333`, \(-115.783333333333`\), 0.`, 
        0.`}, {"Ely", "Nevada", 39.2833333333333`, \(-114.85`\), 0.`, 
        0.`}, {"Las Vegas", "Nevada", 
        36.0833333333333`, \(-115.166666666667`\), 0.`, 0.`}, {"Lovelock", 
        "Nevada", 40.0666666666667`, \(-118.55`\), 0.`, 0.`}, {"Reno", 
        "Nevada", 39.5`, \(-119.783333333333`\), 0.`, 36.`}, {"Tonopah", 
        "Nevada", 38.0666666666667`, \(-117.083333333333`\), 0.`, 
        0.`}, {"Winnemucca", "Nevada", 40.9`, \(-117.8`\), 0.`, 
        0.`}, {"Berlin", "New Hampshire", 44.05`, \(-71.0166666666667`\), 
        0.`, 0.`}, {"Claremont", "New Hampshire", 
        43.0333333333333`, \(-72.0333333333333`\), 0.`, 70.`}, {"Concord", 
        "New Hampshire", 43.2`, \(-71.5`\), 0.`, 0.`}, {"Keene", 
        "New Hampshire", 42.9166666666667`, \(-72.2833333333333`\), 0.`, 
        0.`}, {"Laconia", "New Hampshire", 43.05`, \(-71.05`\), 0.`, 
        0.`}, {"Manchester", "New Hampshire", 
        42.9333333333333`, \(-71.4333333333333`\), 0.`, 0.`}, {"Portsmouth", 
        "New Hampshire", 43.0666666666667`, \(-70.8166666666667`\), 0.`, 
        0.`}, {"Atlantic City", "New Jersey", 
        39.3833333333333`, \(-74.4333333333333`\), 0.`, 0.`}, {"Long Branch", 
        "New Jersey", 40.3166666666667`, \(-74.0166666666667`\), 0.`, 
        0.`}, {"Newark", "New Jersey", 40.7`, \(-74.1666666666667`\), 0.`, 
        0.`}, {"New Brunswick", "New Jersey", 
        40.4833333333333`, \(-74.4333333333333`\), 0.`, 0.`}, {"Paterson", 
        "New Jersey", 40.9`, \(-74.15`\), 0.`, 0.`}, {"Phillipsburg", 
        "New Jersey", 40.6833333333333`, \(-75.1833333333333`\), 0.`, 
        0.`}, {"Trenton", "New Jersey", 
        40.2166666666667`, \(-74.7666666666667`\), 0.`, 0.`}, {"Vineland", 
        "New Jersey", 39.4833333333333`, \(-75.`\), 0.`, 0.`}, {"Alamagordo", 
        "New Mexico", 32.85`, \(-106.1`\), 0.`, 0.`}, {"Albuquerque", 
        "New Mexico", 35.05`, \(-106.616666666667`\), 0.`, 0.`}, {"Artesia", 
        "New Mexico", 32.7666666666667`, \(-104.383333333333`\), 0.`, 
        0.`}, {"Carlsbad", "New Mexico", 
        32.3333333333333`, \(-104.266666666667`\), 0.`, 0.`}, {"Clovis", 
        "New Mexico", 34.3833333333333`, \(-103.316666666667`\), 0.`, 
        0.`}, {"Farmington", "New Mexico", 
        36.7333333333333`, \(-108.233333333333`\), 0.`, 0.`}, {"Gallup", 
        "New Mexico", 35.5166666666667`, \(-108.783333333333`\), 0.`, 
        0.`}, {"Grants", "New Mexico", 35.1666666666667`, \(-107.9`\), 0.`, 
        0.`}, {"Hobbs", "New Mexico", 32.75`, \(-103.216666666667`\), 0.`, 
        0.`}, {"Las Cruces", "New Mexico", 32.3`, \(-106.916666666667`\), 
        0.`, 0.`}, {"Los Alamos", "New Mexico", 
        35.8666666666667`, \(-106.316666666667`\), 0.`, 0.`}, {"Raton", 
        "New Mexico", 36.75`, \(-104.5`\), 0.`, 0.`}, {"Roswell", 
        "New Mexico", 33.3`, \(-104.533333333333`\), 0.`, 0.`}, {"Santa Fe", 
        "New Mexico", 35.6166666666667`, \(-106.083333333333`\), 0.`, 
        0.`}, {"Silver City", "New Mexico", 
        32.6333333333333`, \(-108.166666666667`\), 0.`, 0.`}, {"Socorro", 
        "New Mexico", 34.05`, \(-106.883333333333`\), 0.`, 
        0.`}, {"Tucumcari", "New Mexico", 35.1833333333333`, \(-103.6`\), 
        0.`, 0.`}, {"Albany", "New York", 42.75`, \(-73.8`\), 0.`, 
        0.`}, {"Auburn", "New York", 42.9`, \(-76.5333333333333`\), 0.`, 
        0.`}, {"Batavia", "New York", 43.`, \(-78.1833333333333`\), 0.`, 
        0.`}, {"Binghamton", "New York", 
        42.2166666666667`, \(-75.9833333333333`\), 0.`, 0.`}, {"Buffalo", 
        "New York", 42.9333333333333`, \(-78.7333333333333`\), 0.`, 
        12.`}, {"Cortland", "New York", 42.6`, \(-76.1833333333333`\), 0.`, 
        0.`}, {"Dunkirk", "New York", 
        42.4833333333333`, \(-79.2666666666667`\), 0.`, 0.`}, {"Elmira", 
        "New York", 42.1666666666667`, \(-76.9`\), 0.`, 0.`}, {"Geneva", 
        "New York", 42.75`, \(-76.9`\), 0.`, 0.`}, {"Glens Falls", 
        "New York", 43.3333333333333`, \(-73.6166666666667`\), 0.`, 
        0.`}, {"Gloversville", "New York", 43.0333333333333`, \(-74.35`\), 
        0.`, 0.`}, {"Hornell", "New York", 42.35`, \(-77.7`\), 0.`, 
        0.`}, {"Ithaca", "New York", 42.45`, \(-76.4833333333333`\), 0.`, 
        0.`}, {"Jamestown", "New York", 
        42.1166666666667`, \(-79.2333333333333`\), 0.`, 0.`}, {"Kingston", 
        "New York", 41.9333333333333`, \(-74.`\), 0.`, 0.`}, {"Lockport", 
        "New York", 43.15`, \(-79.25`\), 0.`, 0.`}, {"Massena", "New York", 
        44.9333333333333`, \(-74.85`\), 0.`, 0.`}, {"Newburgh", "New York", 
        41.5`, \(-74.1`\), 0.`, 0.`}, {"New York City", "New York", 
        40.7833333333333`, \(-73.9666666666667`\), 0.`, 
        0.`}, {"Niagara Falls", "New York", 43.1`, \(-79.95`\), 0.`, 
        0.`}, {"Olean", "New York", 
        42.2333333333333`, \(-78.3666666666667`\), 0.`, 0.`}, {"Oneonta", 
        "New York", 42.5166666666667`, \(-75.0666666666667`\), 0.`, 
        0.`}, {"Oswego", "New York", 43.4666666666667`, \(-76.55`\), 0.`, 
        44.`}, {"Poughkeepsie", "New York", 
        41.6333333333333`, \(-73.9166666666667`\), 0.`, 0.`}, {"Rochester", 
        "New York", 43.1166666666667`, \(-77.6666666666667`\), 0.`, 
        0.`}, {"Rome", "New York", 43.2333333333333`, \(-75.4166666666667`\), 
        0.`, 0.`}, {"Schenectady", "New York", 42.85`, \(-73.95`\), 0.`, 
        0.`}, {"Syracuse", "New York", 
        43.1166666666667`, \(-76.1166666666667`\), 0.`, 0.`}, {"Utica", 
        "New York", 43.15`, \(-75.3833333333333`\), 0.`, 0.`}, {"Watertown", 
        "New York", 43.9833333333333`, \(-76.0166666666667`\), 0.`, 
        0.`}, {"Asheville", "North Carolina", 
        35.4333333333333`, \(-82.5333333333333`\), 0.`, 0.`}, {"Charlotte", 
        "North Carolina", 35.2166666666667`, \(-80.9333333333333`\), 0.`, 
        0.`}, {"Durham", "North Carolina", 
        35.8666666666667`, \(-78.7833333333333`\), 0.`, 
        0.`}, {"Elizabeth City", "North Carolina", 
        36.2666666666667`, \(-76.1833333333333`\), 0.`, 
        0.`}, {"Fayetteville", "North Carolina", 
        35.1666666666667`, \(-79.0166666666667`\), 0.`, 0.`}, {"Goldsboro", 
        "North Carolina", 35.3333333333333`, \(-77.9666666666667`\), 0.`, 
        0.`}, {"Seymour-Johnson", "North Carolina", 
        35.3333333333333`, \(-77.9666666666667`\), 0.`, 0.`}, {"Greensboro", 
        "North Carolina", 36.0833333333333`, \(-79.95`\), 0.`, 
        0.`}, {"Greenville", "North Carolina", 
        35.6166666666667`, \(-77.4166666666667`\), 0.`, 0.`}, {"Henderson", 
        "North Carolina", 36.3666666666667`, \(-78.4166666666667`\), 0.`, 
        0.`}, {"Hickory", "North Carolina", 35.75`, \(-81.3833333333333`\), 
        0.`, 0.`}, {"Jacksonville", "North Carolina", 
        34.8333333333333`, \(-77.6166666666667`\), 0.`, 0.`}, {"Lumberton", 
        "North Carolina", 34.6166666666667`, \(-79.0666666666667`\), 0.`, 
        0.`}, {"New Bern", "North Carolina", 35.0833333333333`, \(-77.05`\), 
        0.`, 0.`}, {"Raleigh", "North Carolina", 
        35.8666666666667`, \(-78.7833333333333`\), 0.`, 0.`}, {"Rocky Mount", 
        "North Carolina", 35.9666666666667`, \(-77.8`\), 0.`, 
        0.`}, {"Wilmington", "North Carolina", 
        34.2666666666667`, \(-77.9166666666667`\), 0.`, 
        0.`}, {"Winston-Salem", "North Carolina", 
        36.1333333333333`, \(-80.2166666666667`\), 0.`, 0.`}, {"Bismarck", 
        "North Dakota", 46.7666666666667`, \(-100.75`\), 0.`, 
        0.`}, {"Devils Lake", "North Dakota", 48.1166666666667`, \(-98.9`\), 
        0.`, 0.`}, {"Dickinson", "North Dakota", 46.8`, \(-102.8`\), 0.`, 
        0.`}, {"Fargo", "North Dakota", 46.9`, \(-96.8`\), 0.`, 
        0.`}, {"Grand Forks", "North Dakota", 47.95`, \(-97.4`\), 0.`, 
        0.`}, {"Jamestown", "North Dakota", 
        46.9166666666667`, \(-98.6833333333333`\), 0.`, 0.`}, {"Minot", 
        "North Dakota", 48.4166666666667`, \(-101.35`\), 0.`, 
        0.`}, {"Williston", "North Dakota", 48.15`, \(-103.583333333333`\), 
        0.`, 0.`}, {"Akron-Canton", "Ohio", 
        40.9166666666667`, \(-81.4333333333333`\), 0.`, 0.`}, {"Ashtabula", 
        "Ohio", 41.85`, \(-80.8`\), 0.`, 0.`}, {"Athens", "Ohio", 
        39.3333333333333`, \(-82.1`\), 0.`, 0.`}, {"Bowling Green", "Ohio", 
        41.3833333333333`, \(-83.6333333333333`\), 0.`, 0.`}, {"Cambridge", 
        "Ohio", 40.0666666666667`, \(-81.5833333333333`\), 0.`, 
        51.`}, {"Chillicothe", "Ohio", 39.35`, \(-83.`\), 0.`, 
        0.`}, {"Cincinnati", "Ohio", 39.15`, \(-84.5166666666667`\), 0.`, 
        0.`}, {"Cleveland", "Ohio", 41.4`, \(-81.85`\), 0.`, 
        0.`}, {"Columbus", "Ohio", 40.`, \(-82.8833333333333`\), 0.`, 
        0.`}, {"Dayton", "Ohio", 39.9`, \(-84.2166666666667`\), 0.`, 
        0.`}, {"Defiance", "Ohio", 41.2833333333333`, \(-84.3833333333333`\), 
        0.`, 0.`}, {"Findlay", "Ohio", 
        41.0166666666667`, \(-83.6666666666667`\), 0.`, 0.`}, {"Fremont", 
        "Ohio", 41.3333333333333`, \(-83.1166666666667`\), 0.`, 
        0.`}, {"Hamilton", "Ohio", 39.4`, \(-84.5833333333333`\), 0.`, 
        0.`}, {"Lancaster", "Ohio", 
        39.7333333333333`, \(-82.6333333333333`\), 0.`, 0.`}, {"Lima", 
        "Ohio", 40.7`, \(-84.0333333333333`\), 0.`, 0.`}, {"Mansfield", 
        "Ohio", 40.8166666666667`, \(-82.5166666666667`\), 0.`, 
        0.`}, {"Marion", "Ohio", 40.6`, \(-83.1666666666667`\), 0.`, 
        0.`}, {"Middletown", "Ohio", 
        39.5166666666667`, \(-84.4166666666667`\), 0.`, 0.`}, {"Newark", 
        "Ohio", 40.0166666666667`, \(-82.4666666666667`\), 0.`, 
        0.`}, {"Norwalk", "Ohio", 41.2666666666667`, \(-82.6166666666667`\), 
        0.`, 0.`}, {"Portsmouth", "Ohio", 38.75`, \(-82.9166666666667`\), 
        0.`, 56.`}, {"Sandusky", "Ohio", 41.45`, \(-82.7166666666667`\), 0.`, 
        0.`}, {"Springfield", "Ohio", 
        39.8333333333333`, \(-83.8333333333333`\), 0.`, 
        0.`}, {"Steubenville", "Ohio", 
        40.3833333333333`, \(-80.6333333333333`\), 185.`, 0.`}, {"Toledo", 
        "Ohio", 41.6`, \(-83.8`\), 0.`, 0.`}, {"Warren", "Ohio", 
        41.3333333333333`, \(-80.85`\), 0.`, 0.`}, {"Wooster", "Ohio", 
        40.7833333333333`, \(-81.9166666666667`\), 0.`, 0.`}, {"Youngstown", 
        "Ohio", 41.2666666666667`, \(-80.6666666666667`\), 0.`, 
        0.`}, {"Zanesville", "Ohio", 39.95`, \(-81.9`\), 0.`, 0.`}, {"Ada", 
        "Oklahoma", 34.7833333333333`, \(-96.6833333333333`\), 0.`, 
        0.`}, {"Ardmore", "Oklahoma", 34.3`, \(-97.0166666666667`\), 0.`, 
        0.`}, {"Bartlesville", "Oklahoma", 36.75`, \(-96.`\), 0.`, 
        0.`}, {"Chickasha", "Oklahoma", 35.05`, \(-97.9166666666667`\), 0.`, 
        0.`}, {"Enid", "Oklahoma", 36.35`, \(-97.9166666666667`\), 0.`, 
        0.`}, {"Lawton", "Oklahoma", 
        34.5666666666667`, \(-98.4166666666667`\), 0.`, 0.`}, {"McAlester", 
        "Oklahoma", 34.8333333333333`, \(-95.9166666666667`\), 0.`, 
        0.`}, {"Muskogee", "Oklahoma", 
        35.6666666666667`, \(-95.3666666666667`\), 0.`, 0.`}, {"Norman", 
        "Oklahoma", 35.25`, \(-97.4833333333333`\), 0.`, 
        0.`}, {"Oklahoma City", "Oklahoma", 35.4`, \(-97.6`\), 0.`, 
        0.`}, {"Ponca City", "Oklahoma", 36.7333333333333`, \(-97.1`\), 0.`, 
        0.`}, {"Seminole", "Oklahoma", 
        35.2333333333333`, \(-96.6666666666667`\), 0.`, 0.`}, {"Stillwater", 
        "Oklahoma", 36.1666666666667`, \(-97.0833333333333`\), 0.`, 
        0.`}, {"Tulsa", "Oklahoma", 36.2`, \(-95.9`\), 0.`, 
        0.`}, {"Woodward", "Oklahoma", 36.6`, \(-99.5166666666667`\), 0.`, 
        0.`}, {"Albany", "Oregon", 44.6333333333333`, \(-123.116666666667`\), 
        0.`, 0.`}, {"Astoria", "Oregon", 46.15`, \(-123.883333333333`\), 0.`, 
        0.`}, {"Baker", "Oregon", 44.8333333333333`, \(-117.816666666667`\), 
        0.`, 0.`}, {"Bend", "Oregon", 
        44.0666666666667`, \(-121.316666666667`\), 0.`, 0.`}, {"Corvallis", 
        "Oregon", 44.5`, \(-123.283333333333`\), 0.`, 0.`}, {"Eugene", 
        "Oregon", 44.1166666666667`, \(-123.216666666667`\), 0.`, 
        0.`}, {"Grants Pass", "Oregon", 
        42.4333333333333`, \(-123.316666666667`\), 0.`, 
        29.`}, {"Klamath Falls", "Oregon", 42.15`, \(-121.733333333333`\), 
        0.`, 0.`}, {"Medford", "Oregon", 
        42.3666666666667`, \(-122.866666666667`\), 0.`, 0.`}, {"Pendleton", 
        "Oregon", 45.6833333333333`, \(-118.85`\), 0.`, 0.`}, {"Portland", 
        "Oregon", 45.6`, \(-122.6`\), 0.`, 0.`}, {"Roseburg", "Oregon", 
        43.2333333333333`, \(-123.366666666667`\), 0.`, 0.`}, {"Salem", 
        "Oregon", 44.9166666666667`, \(-123.016666666667`\), 0.`, 
        0.`}, {"The Dalles", "Oregon", 45.6`, \(-121.2`\), 0.`, 
        0.`}, {"Allentown", "Pennsylvania", 40.65`, \(-75.4333333333333`\), 
        0.`, 0.`}, {"Altoona", "Pennsylvania", 40.3`, \(-78.3166666666667`\), 
        0.`, 0.`}, {"Butler", "Pennsylvania", 40.8666666666667`, \(-79.9`\), 
        0.`, 0.`}, {"Chambersburg", "Pennsylvania", 
        39.9333333333333`, \(-77.6333333333333`\), 0.`, 0.`}, {"Erie", 
        "Pennsylvania", 42.0833333333333`, \(-80.1833333333333`\), 0.`, 
        0.`}, {"Harrisburg", "Pennsylvania", 40.2`, \(-76.7666666666667`\), 
        0.`, 0.`}, {"Johnstown", "Pennsylvania", 
        40.3166666666667`, \(-78.8333333333333`\), 298.`, 0.`}, {"Lancaster", 
        "Pennsylvania", 40.1166666666667`, \(-76.3`\), 0.`, 
        0.`}, {"Meadville", "Pennsylvania", 
        41.6333333333333`, \(-80.1666666666667`\), 0.`, 0.`}, {"New Castle", 
        "Pennsylvania", 41.0166666666667`, \(-80.3666666666667`\), 0.`, 
        0.`}, {"Philadelphia", "Pennsylvania", 
        39.8833333333333`, \(-75.25`\), 0.`, 0.`}, {"Pittsburgh", 
        "Pennsylvania", 40.5`, \(-80.2166666666667`\), 0.`, 0.`}, {"Reading", 
        "Pennsylvania", 40.3333333333333`, \(-75.6333333333333`\), 0.`, 
        0.`}, {"Scranton", "Pennsylvania", 
        41.3333333333333`, \(-75.7333333333333`\), 0.`, 
        0.`}, {"Wilkes-Barre", "Pennsylvania", 
        41.3333333333333`, \(-75.7333333333333`\), 0.`, 
        0.`}, {"State College", "Pennsylvania", 
        40.8`, \(-77.8666666666667`\), 0.`, 0.`}, {"Sunbury", "Pennsylvania", 
        40.8833333333333`, \(-76.7666666666667`\), 0.`, 0.`}, {"Uniontown", 
        "Pennsylvania", 39.9166666666667`, \(-79.7166666666667`\), 0.`, 
        0.`}, {"Warren", "Pennsylvania", 41.85`, \(-79.1333333333333`\), 0.`, 
        0.`}, {"West Chester", "Pennsylvania", 
        39.9666666666667`, \(-75.6333333333333`\), 0.`, 
        0.`}, {"Williamsport", "Pennsylvania", 
        41.25`, \(-76.9166666666667`\), 0.`, 0.`}, {"York", "Pennsylvania", 
        39.9166666666667`, \(-76.75`\), 0.`, 0.`}, {"Newport", 
        "Rhode Island", 41.5`, \(-71.3333333333333`\), 0.`, 
        0.`}, {"Providence", "Rhode Island", 
        41.7333333333333`, \(-71.4333333333333`\), 0.`, 0.`}, {"Anderson", 
        "South Carolina", 34.5`, \(-82.7166666666667`\), 0.`, 
        0.`}, {"Charleston", "South Carolina", 32.9`, \(-79.9666666666667`\), 
        0.`, 0.`}, {"Columbia", "South Carolina", 
        33.95`, \(-81.1166666666667`\), 0.`, 0.`}, {"Florence", 
        "South Carolina", 34.1833333333333`, \(-79.7166666666667`\), 0.`, 
        0.`}, {"Georgetown", "South Carolina", 
        33.3833333333333`, \(-79.2833333333333`\), 0.`, 0.`}, {"Greenville", 
        "South Carolina", 34.9`, \(-82.2166666666667`\), 0.`, 
        0.`}, {"Greenwood", "South Carolina", 
        34.1666666666667`, \(-82.1166666666667`\), 0.`, 16.`}, {"Orangeburg", 
        "South Carolina", 33.5`, \(-80.8666666666667`\), 0.`, 
        0.`}, {"Rock Hill", "South Carolina", 
        34.9833333333333`, \(-80.9666666666667`\), 0.`, 0.`}, {"Spartanburg", 
        "South Carolina", 34.9666666666667`, \(-82.`\), 0.`, 0.`}, {"Sumter", 
        "South Carolina", 33.9`, \(-80.3666666666667`\), 0.`, 
        0.`}, {"Aberdeen", "South Dakota", 45.45`, \(-98.4333333333333`\), 
        0.`, 0.`}, {"Brookings", "South Dakota", 44.3`, \(-96.8`\), 0.`, 
        0.`}, {"Huron", "South Dakota", 
        44.3833333333333`, \(-98.2166666666667`\), 0.`, 0.`}, {"Mitchell", 
        "South Dakota", 43.6833333333333`, \(-98.0166666666667`\), 0.`, 
        0.`}, {"Pierre", "South Dakota", 
        44.3833333333333`, \(-100.283333333333`\), 0.`, 0.`}, {"Rapid City", 
        "South Dakota", 44.05`, \(-103.066666666667`\), 0.`, 
        0.`}, {"Sioux Falls", "South Dakota", 
        43.5666666666667`, \(-96.7333333333333`\), 0.`, 0.`}, {"Watertown", 
        "South Dakota", 44.9166666666667`, \(-97.15`\), 0.`, 
        0.`}, {"Yankton", "South Dakota", 
        42.9166666666667`, \(-97.3833333333333`\), 0.`, 0.`}, {"Athens", 
        "Tennessee", 35.4333333333333`, \(-84.5833333333333`\), 0.`, 
        0.`}, {"Bristol-Tri City", "Tennessee", 
        36.4833333333333`, \(-82.4`\), 0.`, 67.`}, {"Chattanooga", 
        "Tennessee", 35.0333333333333`, \(-85.2`\), 0.`, 
        0.`}, {"Clarksville", "Tennessee", 36.55`, \(-87.3666666666667`\), 
        0.`, 0.`}, {"Columbia", "Tennessee", 
        35.6333333333333`, \(-87.0333333333333`\), 0.`, 0.`}, {"Dyersburg", 
        "Tennessee", 36.0166666666667`, \(-89.4`\), 0.`, 0.`}, {"Greenville", 
        "Tennessee", 36.0666666666667`, \(-82.8333333333333`\), 0.`, 
        0.`}, {"Jackson", "Tennessee", 35.6`, \(-88.9166666666667`\), 0.`, 
        90.`}, {"Knoxville", "Tennessee", 
        35.8166666666667`, \(-83.9833333333333`\), 0.`, 0.`}, {"Memphis", 
        "Tennessee", 35.05`, \(-90.`\), 0.`, 0.`}, {"Murfreesboro", 
        "Tennessee", 34.9166666666667`, \(-86.4666666666667`\), 0.`, 
        0.`}, {"Nashville", "Tennessee", 
        36.1166666666667`, \(-86.6833333333333`\), 408.`, 0.`}, {"Tullahoma", 
        "Tennessee", 35.3833333333333`, \(-86.0833333333333`\), 0.`, 
        0.`}, {"Abilene", "Texas", 32.4166666666667`, \(-99.6833333333333`\), 
        0.`, 0.`}, {"Alice", "Texas", 
        27.7333333333333`, \(-98.0333333333333`\), 0.`, 0.`}, {"Amarillo", 
        "Texas", 35.2333333333333`, \(-100.7`\), 0.`, 0.`}, {"Austin", 
        "Texas", 30.3`, \(-97.7`\), 0.`, 51.`}, {"Bay City", "Texas", 
        29.`, \(-95.9666666666667`\), 0.`, 0.`}, {"Beaumont", "Texas", 
        29.95`, \(-94.0166666666667`\), 0.`, 0.`}, {"Beeville", "Texas", 
        28.3666666666667`, \(-97.6666666666667`\), 0.`, 65.`}, {"Big Spring", 
        "Texas", 32.3`, \(-101.45`\), 0.`, 91.`}, {"Brownsville", "Texas", 
        25.9`, \(-97.4333333333333`\), 0.`, 0.`}, {"Brownwood", "Texas", 
        31.8`, \(-98.95`\), 0.`, 0.`}, {"Bryan", "Texas", 
        30.6666666666667`, \(-96.55`\), 0.`, 0.`}, {"Corpus Christi", 
        "Texas", 27.7666666666667`, \(-97.5`\), 0.`, 0.`}, {"Corsicana", 
        "Texas", 32.0833333333333`, \(-96.4666666666667`\), 0.`, 
        0.`}, {"Dallas", "Texas", 32.85`, \(-96.85`\), 0.`, 0.`}, {"Del Rio", 
        "Texas", 29.3666666666667`, \(-100.783333333333`\), 0.`, 
        0.`}, {"Denton", "Texas", 33.2`, \(-97.1`\), 0.`, 
        0.`}, {"Eagle Pass", "Texas", 
        28.8666666666667`, \(-100.533333333333`\), 0.`, 80.`}, {"El Paso", 
        "Texas", 31.8`, \(-106.4`\), 0.`, 0.`}, {"Fort Worth", "Texas", 
        32.8333333333333`, \(-97.05`\), 0.`, 0.`}, {"Galveston", "Texas", 
        29.3`, \(-94.8`\), 0.`, 0.`}, {"Greenville", "Texas", 
        33.0666666666667`, \(-96.05`\), 0.`, 0.`}, {"Harlingen", "Texas", 
        26.2333333333333`, \(-97.65`\), 0.`, 0.`}, {"Houston", "Texas", 
        29.9666666666667`, \(-95.35`\), 0.`, 87.`}, {"Huntsville", "Texas", 
        30.7166666666667`, \(-95.55`\), 0.`, 89.`}, {"Killeen", "Texas", 
        31.0833333333333`, \(-97.6833333333333`\), 0.`, 0.`}, {"Lamesa", 
        "Texas", 32.7`, \(-101.933333333333`\), 0.`, 0.`}, {"Longview", 
        "Texas", 32.4666666666667`, \(-94.7333333333333`\), 0.`, 
        0.`}, {"Lubbock", "Texas", 33.65`, \(-101.816666666667`\), 0.`, 
        0.`}, {"Lufkin", "Texas", 31.4166666666667`, \(-94.8`\), 0.`, 
        0.`}, {"Mcallen", "Texas", 26.2`, \(-98.2166666666667`\), 0.`, 
        93.`}, {"Midland", "Texas", 31.95`, \(-102.183333333333`\), 0.`, 
        0.`}, {"Mineral Wells", "Texas", 
        32.7833333333333`, \(-98.0666666666667`\), 0.`, 0.`}, {"Palestine", 
        "Texas", 31.7833333333333`, \(-95.6333333333333`\), 0.`, 
        0.`}, {"Pampa", "Texas", 35.5333333333333`, \(-100.983333333333`\), 
        0.`, 0.`}, {"Pecos", "Texas", 31.4166666666667`, \(-103.5`\), 0.`, 
        0.`}, {"Plainview", "Texas", 34.1833333333333`, \(-101.7`\), 0.`, 
        0.`}, {"Port Arthur", "Texas", 29.95`, \(-94.0166666666667`\), 0.`, 
        0.`}, {"San Angelo", "Texas", 31.4333333333333`, \(-100.4`\), 0.`, 
        0.`}, {"San Antonio", "Texas", 
        29.5333333333333`, \(-98.4666666666667`\), 0.`, 0.`}, {"Sherman", 
        "Texas", 33.7166666666667`, \(-96.6666666666667`\), 0.`, 
        0.`}, {"Snyder", "Texas", 32.7166666666667`, \(-100.916666666667`\), 
        0.`, 0.`}, {"Temple", "Texas", 31.1`, \(-97.35`\), 0.`, 
        0.`}, {"Tyler", "Texas", 32.35`, \(-95.2666666666667`\), 0.`, 
        43.`}, {"Vernon", "Texas", 34.1666666666667`, \(-99.3`\), 0.`, 
        0.`}, {"Victoria", "Texas", 28.85`, \(-96.9166666666667`\), 0.`, 
        0.`}, {"Waco", "Texas", 31.6166666666667`, \(-97.2166666666667`\), 
        0.`, 0.`}, {"Wichita Falls", "Texas", 
        33.9666666666667`, \(-98.4833333333333`\), 0.`, 0.`}, {"Cedar City", 
        "Utah", 37.7`, \(-113.1`\), 0.`, 0.`}, {"Logan", "Utah", 
        41.75`, \(-111.816666666667`\), 0.`, 0.`}, {"Moab", "Utah", 
        38.6`, \(-109.6`\), 0.`, 56.`}, {"Ogden", "Utah", 
        41.2`, \(-112.016666666667`\), 0.`, 0.`}, {"Price", "Utah", 
        39.6166666666667`, \(-110.833333333333`\), 0.`, 0.`}, {"Provo", 
        "Utah", 40.2166666666667`, \(-111.716666666667`\), 0.`, 
        0.`}, {"Richfield", "Utah", 
        38.7666666666667`, \(-112.083333333333`\), 0.`, 83.`}, {"St George", 
        "Utah", 37.0333333333333`, \(-113.516666666667`\), 0.`, 
        0.`}, {"Salt Lake City", "Utah", 
        40.7666666666667`, \(-111.966666666667`\), 0.`, 0.`}, {"Vernal", 
        "Utah", 40.45`, \(-109.516666666667`\), 0.`, 0.`}, {"Barre", 
        "Vermont", 44.2`, \(-72.5166666666667`\), 0.`, 0.`}, {"Burlington", 
        "Vermont", 44.4666666666667`, \(-73.15`\), 0.`, 0.`}, {"Rutland", 
        "Vermont", 43.6`, \(-72.9666666666667`\), 0.`, 
        0.`}, {"Charlottesville", "Virginia", 
        38.0333333333333`, \(-78.5166666666667`\), 0.`, 0.`}, {"Danville", 
        "Virginia", 36.5666666666667`, \(-79.3333333333333`\), 0.`, 
        0.`}, {"Fredericksburg", "Virginia", 38.3`, \(-77.4666666666667`\), 
        0.`, 0.`}, {"Harrisonburg", "Virginia", 38.45`, \(-78.9`\), 0.`, 
        0.`}, {"Lynchburg", "Virginia", 37.3333333333333`, \(-79.2`\), 0.`, 
        0.`}, {"Norfolk", "Virginia", 36.9`, \(-76.2`\), 0.`, 
        0.`}, {"Petersburg", "Virginia", 
        37.1833333333333`, \(-77.5166666666667`\), 0.`, 0.`}, {"Richmond", 
        "Virginia", 37.5`, \(-77.3333333333333`\), 0.`, 0.`}, {"Roanoke", 
        "Virginia", 37.3166666666667`, \(-79.9666666666667`\), 0.`, 
        0.`}, {"Staunton", "Virginia", 38.2666666666667`, \(-78.9`\), 0.`, 
        0.`}, {"Winchester", "Virginia", 39.2`, \(-78.1666666666667`\), 0.`, 
        0.`}, {"Aberdeen", "Washington", 
        46.9833333333333`, \(-123.816666666667`\), 0.`, 0.`}, {"Bellingham", 
        "Washington", 48.8`, \(-122.533333333333`\), 0.`, 0.`}, {"Bremerton", 
        "Washington", 47.5666666666667`, \(-122.666666666667`\), 0.`, 
        0.`}, {"Ellensburg", "Washington", 
        47.0333333333333`, \(-120.516666666667`\), 0.`, 0.`}, {"Everett", 
        "Washington", 47.9166666666667`, \(-122.283333333333`\), 262.`, 
        0.`}, {"Kennewick", "Washington", 
        46.2166666666667`, \(-119.133333333333`\), 0.`, 0.`}, {"Longview", 
        "Washington", 46.1666666666667`, \(-122.933333333333`\), 0.`, 
        0.`}, {"Moses Lake", "Washington", 47.2`, \(-119.316666666667`\), 
        0.`, 0.`}, {"Olympia", "Washington", 46.9666666666667`, \(-122.9`\), 
        0.`, 0.`}, {"Port Angeles", "Washington", 
        48.1166666666667`, \(-123.433333333333`\), 0.`, 0.`}, {"Seattle", 
        "Washington", 47.65`, \(-122.3`\), 0.`, 0.`}, {"Spokane", 
        "Washington", 47.6333333333333`, \(-117.516666666667`\), 0.`, 
        0.`}, {"Tacoma", "Washington", 47.25`, \(-122.5`\), 0.`, 
        29.`}, {"Walla Walla", "Washington", 46.1`, \(-118.283333333333`\), 
        0.`, 0.`}, {"Wenatchee", "Washington", 
        47.4166666666667`, \(-120.316666666667`\), 0.`, 0.`}, {"Yakima", 
        "Washington", 46.5666666666667`, \(-120.533333333333`\), 0.`, 
        0.`}, {"Beckley", "West Virginia", 
        37.7833333333333`, \(-81.1166666666667`\), 0.`, 0.`}, {"Bluefield", 
        "West Virginia", 37.3`, \(-81.2166666666667`\), 0.`, 
        0.`}, {"Charleston", "West Virginia", 38.3666666666667`, \(-81.6`\), 
        0.`, 0.`}, {"Clarksburg", "West Virginia", 
        39.2666666666667`, \(-80.35`\), 0.`, 0.`}, {"Elkins", 
        "West Virginia", 38.8833333333333`, \(-79.85`\), 0.`, 
        0.`}, {"Huntington", "West Virginia", 38.4166666666667`, \(-82.5`\), 
        0.`, 0.`}, {"Martinsburg", "West Virginia", 
        39.4`, \(-77.9833333333333`\), 0.`, 0.`}, {"Morgantown", 
        "West Virginia", 39.65`, \(-79.9166666666667`\), 0.`, 
        23.`}, {"Parkersburg", "West Virginia", 
        39.2666666666667`, \(-81.5666666666667`\), 499.`, 0.`}, {"Wheeling", 
        "West Virginia", 40.1166666666667`, \(-80.7`\), 0.`, 
        0.`}, {"Appleton", "Wisconsin", 44.25`, \(-88.3833333333333`\), 0.`, 
        0.`}, {"Ashland", "Wisconsin", 
        46.5666666666667`, \(-90.9666666666667`\), 0.`, 0.`}, {"Beloit", 
        "Wisconsin", 42.5`, \(-89.0333333333333`\), 0.`, 0.`}, {"Eau Claire", 
        "Wisconsin", 44.8666666666667`, \(-91.4833333333333`\), 0.`, 
        0.`}, {"Fond Du Lac", "Wisconsin", 43.8`, \(-88.45`\), 0.`, 
        0.`}, {"Green Bay", "Wisconsin", 
        44.4833333333333`, \(-88.1333333333333`\), 0.`, 0.`}, {"La Crosse", 
        "Wisconsin", 43.8666666666667`, \(-91.25`\), 0.`, 0.`}, {"Madison", 
        "Wisconsin", 43.1333333333333`, \(-89.3333333333333`\), 0.`, 
        0.`}, {"Manitowoc", "Wisconsin", 44.1`, \(-87.6833333333333`\), 0.`, 
        0.`}, {"Marinette", "Wisconsin", 45.1`, \(-87.6333333333333`\), 0.`, 
        0.`}, {"Milwaukee", "Wisconsin", 42.95`, \(-87.9`\), 0.`, 
        0.`}, {"Racine", "Wisconsin", 42.7166666666667`, \(-87.85`\), 0.`, 
        0.`}, {"Sheboygan", "Wisconsin", 43.75`, \(-87.7166666666667`\), 0.`, 
        0.`}, {"Stevens Point", "Wisconsin", 44.5`, \(-89.5666666666667`\), 
        0.`, 0.`}, {"Waukesha", "Wisconsin", 
        43.0166666666667`, \(-88.2333333333333`\), 0.`, 0.`}, {"Wausau", 
        "Wisconsin", 44.9166666666667`, \(-89.6166666666667`\), 0.`, 
        98.`}, {"Casper", "Wyoming", 
        42.9166666666667`, \(-106.466666666667`\), 0.`, 0.`}, {"Cheyenne", 
        "Wyoming", 41.15`, \(-104.816666666667`\), 0.`, 0.`}, {"Cody", 
        "Wyoming", 44.55`, \(-109.066666666667`\), 0.`, 0.`}, {"Evanston", 
        "Wyoming", 41.2666666666667`, \(-110.95`\), 0.`, 0.`}, {"Lander", 
        "Wyoming", 42.8166666666667`, \(-108.733333333333`\), 0.`, 
        0.`}, {"Laramie", "Wyoming", 
        41.3166666666667`, \(-105.683333333333`\), 0.`, 0.`}, {"Newcastle", 
        "Wyoming", 43.85`, \(-104.216666666667`\), 0.`, 0.`}, {"Rawlins", 
        "Wyoming", 41.8`, \(-107.2`\), 0.`, 0.`}, {"Rock Springs", "Wyoming", 
        41.6`, \(-109.`\), 0.`, 0.`}, {"Sheridan", "Wyoming", 
        44.7666666666667`, \(-106.966666666667`\), 0.`, 0.`}, {"Torrington", 
        "Wyoming", 42.0833333333333`, \(-104.216666666667`\), 0.`, 
        0.`}}\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(cityheaders = First[citytable]; 
    citydata\  = \ Rest[citytable];\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[citydata]\)], "Input"],

Cell[BoxData[
    \(726\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculations", "Section"],

Cell[CellGroupData[{

Cell["Visualizing", "Subsection",
  CellTags->"Transport"],

Cell[BoxData[
    \(\(borderdata = \ 
        First[WorldData["\<USA\>"]]\  /. \ {lat_, lon_}\ \  -> \ {lon, lat}/
              60;\)\)], "Input",
  CellTags->"Transport"],

Cell[BoxData[
    \(\(borderpoly\  = \ 
        Graphics[{GrayLevel[ .8], \ Polygon[borderdata]}];\)\)], "Input",
  CellTags->"Transport"],

Cell[BoxData[
    \(\(citypoints = \ 
        Graphics[{Hue[ .8], AbsolutePointSize[4], \ 
            citydata /. \ {city_String, state_, lat_, lon_, supply_, 
                  demand_} -> Point[{lon, lat}]}];\)\)], "Input",
  CellTags->"Transport"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[{borderpoly, citypoints}]\)], "Input",
  CellTags->"Transport"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.08891 0.0165583 -0.576296 0.0240738 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.8 g
.14965 .2069 m
.14689 .21814 L
.0917 .25585 L
.06079 .32687 L
.07845 .33891 L
.04064 .36098 L
.03264 .4348 L
.03457 .53792 L
.02381 .58887 L
.05637 .58326 L
.05113 .55798 L
.05637 .60292 L
.05665 .60332 L
.15103 .60332 L
.16759 .60332 L
.36684 .60332 L
.47944 .60332 L
.60556 .57925 L
.6958 .54394 L
.72423 .45928 L
.72036 .44804 L
.71954 .42718 L
.78218 .45687 L
.7797 .46128 L
.7797 .4653 L
.83379 .49459 L
.87436 .50743 L
.90499 .50743 L
.91189 .51425 L
.94252 .56641 L
.97619 .51144 L
.91741 .46048 L
.9163 .45567 L
.91134 .42317 L
.91106 .42277 L
.91134 .42317 L
.89919 .41835 L
.86939 .41073 L
.85945 .39909 L
.84952 .36138 L
.84648 .38665 L
.83986 .38184 L
.84648 .34934 L
.84096 .33891 L
.8313 .31764 L
.83627 .3377 L
.82661 .35095 L
.83324 .37662 L
.82523 .33971 L
.81364 .35777 L
.81281 .36017 L
.81171 .34252 L
.82606 .31644 L
.80923 .32206 L
.83296 .3036 L
.83848 .28514 L
.83158 .30761 L
.81833 .28916 L
.83462 .28113 L
.81309 .27913 L
.82496 .26348 L
.78825 .239 L
.74962 .19447 L
.73941 .16317 L
.76369 .06848 L
.74631 .02836 L
.70325 .14391 L
.63978 .15274 L
.62515 .15515 L
.60666 .15033 L
.59148 .14953 L
.60915 .14712 L
.60832 .12024 L
.53574 .14592 L
.53601 .14552 L
.4742 .09456 L
.48054 .04882 L
.44826 .05925 L
.41928 .12866 L
.36602 .12987 L
.32517 .18885 L
.28322 .17802 L
.18939 .21132 L
.14965 .2069 L
F
.8 0 1 r
4 Mabswid
.66572 .21693 Mdot
.66738 .23218 Mdot
.67317 .20851 Mdot
.65247 .23178 Mdot
.64861 .25706 Mdot
.674 .17761 Mdot
.6373 .26147 Mdot
.66489 .24261 Mdot
.65523 .25906 Mdot
.62764 .16237 Mdot
.65882 .20329 Mdot
.63205 .20209 Mdot
.66324 .22897 Mdot
.63812 .22335 Mdot
.27412 .18082 Mdot
.2399 .2695 Mdot
.26197 .18403 Mdot
.20098 .2711 Mdot
.25231 .17842 Mdot
.2341 .22857 Mdot
.2272 .25786 Mdot
.25204 .19687 Mdot
.25535 .26669 Mdot
.19105 .20971 Mdot
.55202 .23258 Mdot
.55202 .22335 Mdot
.52967 .29036 Mdot
.52636 .27431 Mdot
.54733 .25385 Mdot
.58707 .28635 Mdot
.56168 .25987 Mdot
.56416 .24943 Mdot
.5327 .22897 Mdot
.11764 .27632 Mdot
.15517 .26267 Mdot
.18939 .23298 Mdot
.12923 .24703 Mdot
.07128 .38184 Mdot
.06907 .3377 Mdot
.13723 .24422 Mdot
.03236 .42919 Mdot
.13282 .24061 Mdot
.15214 .21372 Mdot
.17366 .21372 Mdot
.1502 .22095 Mdot
.03402 .41033 Mdot
.03402 .41033 Mdot
.0699 .34493 Mdot
.1066 .30882 Mdot
.13861 .23138 Mdot
.06962 .33129 Mdot
.09253 .25947 Mdot
.13254 .2378 Mdot
.1284 .24061 Mdot
.09253 .32366 Mdot
.08535 .33008 Mdot
.07045 .3048 Mdot
.0641 .34372 Mdot
.19105 .25666 Mdot
.06355 .33409 Mdot
.14469 .22376 Mdot
.14165 .24342 Mdot
.11543 .24703 Mdot
.13337 .25746 Mdot
.15931 .2378 Mdot
.13254 .24582 Mdot
.05831 .34412 Mdot
.13917 .24342 Mdot
.06383 .39909 Mdot
.14855 .24342 Mdot
.063 .3369 Mdot
.14745 .2398 Mdot
.07707 .35095 Mdot
.07542 .30641 Mdot
.14717 .24542 Mdot
.14883 .21172 Mdot
.1273 .24903 Mdot
.06245 .32928 Mdot
.0699 .32326 Mdot
.09004 .27431 Mdot
.13723 .23619 Mdot
.10467 .25264 Mdot
.06852 .31403 Mdot
.09446 .26388 Mdot
.12702 .24261 Mdot
.11709 .25064 Mdot
.05527 .35095 Mdot
.08121 .3361 Mdot
.04892 .36619 Mdot
.1135 .29838 Mdot
.05831 .42798 Mdot
.07542 .36579 Mdot
.33593 .32527 Mdot
.34587 .38665 Mdot
.35498 .35817 Mdot
.35249 .38064 Mdot
.30254 .32125 Mdot
.34891 .40471 Mdot
.29178 .36539 Mdot
.35636 .39709 Mdot
.37512 .33971 Mdot
.32876 .3686 Mdot
.35884 .34573 Mdot
.38009 .4015 Mdot
.36132 .32045 Mdot
.87712 .41514 Mdot
.88595 .42838 Mdot
.88595 .42838 Mdot
.86497 .41835 Mdot
.89505 .41915 Mdot
.87325 .41354 Mdot
.89561 .42357 Mdot
.87905 .42477 Mdot
.8854 .4332 Mdot
.8854 .4332 Mdot
.8371 .37863 Mdot
.81337 .35897 Mdot
.75348 .06527 Mdot
.75486 .10941 Mdot
.74686 .12626 Mdot
.76176 .05123 Mdot
.73333 .06367 Mdot
.75845 .08493 Mdot
.72671 .13829 Mdot
.73609 .15795 Mdot
.73527 .01472 Mdot
.73195 .09857 Mdot
.75983 .04481 Mdot
.75955 .04441 Mdot
.72892 .12626 Mdot
.74134 .11101 Mdot
.67179 .14752 Mdot
.64475 .15595 Mdot
.74217 .14511 Mdot
.70905 .09215 Mdot
.74299 .11623 Mdot
.72202 .08292 Mdot
.69194 .15515 Mdot
.7223 .09697 Mdot
.76259 .06607 Mdot
.69663 .18444 Mdot
.69415 .19527 Mdot
.70933 .24101 Mdot
.69083 .23379 Mdot
.73168 .22697 Mdot
.73968 .17601 Mdot
.68256 .2065 Mdot
.68228 .25585 Mdot
.71622 .20209 Mdot
.70325 .24663 Mdot
.69359 .22335 Mdot
.68035 .21854 Mdot
.70381 .21092 Mdot
.68946 .24021 Mdot
.74437 .19727 Mdot
.71126 .16919 Mdot
.7245 .17601 Mdot
.16456 .47252 Mdot
.20512 .44764 Mdot
.15462 .57363 Mdot
.23327 .47131 Mdot
.15131 .54033 Mdot
.15214 .54875 Mdot
.1698 .45968 Mdot
.22444 .45687 Mdot
.19326 .44644 Mdot
.62626 .42878 Mdot
.60114 .35175 Mdot
.61605 .39829 Mdot
.61108 .33329 Mdot
.62709 .38746 Mdot
.63785 .43199 Mdot
.6384 .39147 Mdot
.61743 .38264 Mdot
.60722 .43079 Mdot
.62736 .4356 Mdot
.60501 .44202 Mdot
.59148 .40912 Mdot
.6086 .35977 Mdot
.62902 .42317 Mdot
.63316 .41273 Mdot
.61356 .41835 Mdot
.61356 .41835 Mdot
.58762 .39789 Mdot
.59011 .42156 Mdot
.61743 .34613 Mdot
.6039 .4027 Mdot
.57879 .38545 Mdot
.62957 .39388 Mdot
.61439 .44323 Mdot
.60418 .38264 Mdot
.63371 .44323 Mdot
.67124 .38906 Mdot
.65661 .35897 Mdot
.65468 .36579 Mdot
.66655 .369 Mdot
.64999 .38786 Mdot
.6395 .33971 Mdot
.67814 .41073 Mdot
.66821 .42357 Mdot
.6442 .42357 Mdot
.67317 .40792 Mdot
.6602 .38024 Mdot
.66903 .34533 Mdot
.66407 .39669 Mdot
.66351 .38746 Mdot
.65303 .42517 Mdot
.67014 .39829 Mdot
.67566 .39107 Mdot
.66241 .4023 Mdot
.68421 .38104 Mdot
.66848 .37502 Mdot
.65965 .42758 Mdot
.64337 .37341 Mdot
.64778 .42317 Mdot
.6395 .35496 Mdot
.53574 .4356 Mdot
.58017 .40551 Mdot
.57051 .43199 Mdot
.59507 .43079 Mdot
.50235 .41875 Mdot
.53822 .42357 Mdot
.58707 .44443 Mdot
.52939 .44804 Mdot
.57299 .42598 Mdot
.57548 .39628 Mdot
.55009 .43641 Mdot
.54347 .46249 Mdot
.54843 .42718 Mdot
.55809 .41314 Mdot
.49296 .44443 Mdot
.55892 .44804 Mdot
.51394 .37622 Mdot
.50787 .33048 Mdot
.43363 .33289 Mdot
.48551 .33409 Mdot
.496 .34653 Mdot
.42093 .3369 Mdot
.40493 .37141 Mdot
.45184 .34693 Mdot
.4684 .34011 Mdot
.41707 .31564 Mdot
.48662 .36378 Mdot
.48662 .36378 Mdot
.50731 .32246 Mdot
.45267 .35937 Mdot
.47199 .35777 Mdot
.50538 .36419 Mdot
.47585 .33008 Mdot
.71898 .35175 Mdot
.65717 .28956 Mdot
.69635 .31323 Mdot
.68697 .36378 Mdot
.64033 .30641 Mdot
.64033 .30641 Mdot
.68808 .33931 Mdot
.66931 .34292 Mdot
.64033 .32206 Mdot
.64558 .33249 Mdot
.61908 .31604 Mdot
.56058 .17962 Mdot
.57962 .15876 Mdot
.60087 .16477 Mdot
.58762 .13428 Mdot
.56554 .15073 Mdot
.5454 .14873 Mdot
.54402 .20851 Mdot
.56499 .2065 Mdot
.54761 .18845 Mdot
.59452 .14552 Mdot
.53546 .2053 Mdot
.93314 .49057 Mdot
.94915 .50221 Mdot
.96267 .55196 Mdot
.92569 .48375 Mdot
.95135 .52267 Mdot
.92458 .47452 Mdot
.93535 .49579 Mdot
.81944 .36699 Mdot
.82358 .37061 Mdot
.78467 .37743 Mdot
.80702 .37341 Mdot
.80178 .37943 Mdot
.83876 .34653 Mdot
.91272 .44363 Mdot
.90195 .44443 Mdot
.91106 .42798 Mdot
.90637 .44162 Mdot
.91851 .44885 Mdot
.89561 .43601 Mdot
.91051 .45165 Mdot
.90803 .45045 Mdot
.91382 .42718 Mdot
.87518 .44523 Mdot
.88788 .43962 Mdot
.91216 .4324 Mdot
.89892 .44122 Mdot
.69773 .4328 Mdot
.70739 .50863 Mdot
.67731 .44243 Mdot
.65772 .43801 Mdot
.71429 .44483 Mdot
.64696 .52468 Mdot
.70243 .45807 Mdot
.6729 .45607 Mdot
.66324 .45165 Mdot
.69028 .44122 Mdot
.67152 .44162 Mdot
.68808 .45366 Mdot
.64171 .54474 Mdot
.68532 .47292 Mdot
.66103 .46289 Mdot
.70767 .45085 Mdot
.72423 .45848 Mdot
.69663 .47172 Mdot
.69194 .54233 Mdot
.67179 .50101 Mdot
.70574 .44042 Mdot
.54319 .47452 Mdot
.50952 .52789 Mdot
.51697 .56761 Mdot
.53022 .54073 Mdot
.56251 .55116 Mdot
.54457 .49017 Mdot
.49821 .53752 Mdot
.54264 .59289 Mdot
.5327 .48656 Mdot
.5454 .50422 Mdot
.55726 .48094 Mdot
.52939 .52107 Mdot
.55644 .56721 Mdot
.51449 .50983 Mdot
.57161 .48415 Mdot
.6166 .15595 Mdot
.58928 .24703 Mdot
.59728 .23018 Mdot
.61108 .17641 Mdot
.59728 .20169 Mdot
.61246 .18604 Mdot
.59093 .17601 Mdot
.61936 .20209 Mdot
.57575 .18323 Mdot
.61908 .24863 Mdot
.58569 .20369 Mdot
.60556 .32005 Mdot
.55947 .36178 Mdot
.59204 .33289 Mdot
.57631 .37943 Mdot
.56251 .35215 Mdot
.52415 .31804 Mdot
.52277 .36539 Mdot
.55644 .38906 Mdot
.5672 .36699 Mdot
.55837 .37221 Mdot
.59176 .30882 Mdot
.57023 .33811 Mdot
.51725 .38104 Mdot
.59231 .35656 Mdot
.60528 .31162 Mdot
.53988 .35576 Mdot
.60528 .31162 Mdot
.54264 .32005 Mdot
.29178 .52628 Mdot
.24845 .52588 Mdot
.2261 .52989 Mdot
.22831 .59409 Mdot
.3249 .58928 Mdot
.3536 .55838 Mdot
.24486 .56681 Mdot
.27301 .59289 Mdot
.23438 .54554 Mdot
.19684 .58647 Mdot
.2766 .55678 Mdot
.26032 .52388 Mdot
.33593 .54153 Mdot
.19988 .55317 Mdot
.48689 .39307 Mdot
.38202 .45486 Mdot
.47723 .42196 Mdot
.49131 .42116 Mdot
.46095 .41033 Mdot
.45902 .4011 Mdot
.44936 .40431 Mdot
.48689 .40712 Mdot
.42259 .39147 Mdot
.47558 .4344 Mdot
.42176 .41394 Mdot
.50097 .41795 Mdot
.37347 .43159 Mdot
.38175 .41594 Mdot
.10577 .36659 Mdot
.17173 .40672 Mdot
.18719 .3694 Mdot
.18194 .29237 Mdot
.12592 .38826 Mdot
.1055 .37462 Mdot
.1502 .34011 Mdot
.13834 .40832 Mdot
.91299 .48415 Mdot
.89616 .45968 Mdot
.90499 .46369 Mdot
.89202 .45687 Mdot
.91244 .46008 Mdot
.90609 .45727 Mdot
.9163 .46048 Mdot
.85642 .37181 Mdot
.86332 .39428 Mdot
.86083 .40351 Mdot
.85642 .39829 Mdot
.86111 .40832 Mdot
.844 .40311 Mdot
.8509 .39187 Mdot
.84704 .37422 Mdot
.33207 .21453 Mdot
.32352 .26749 Mdot
.3605 .21252 Mdot
.36243 .20209 Mdot
.37816 .25144 Mdot
.29675 .30801 Mdot
.28764 .27872 Mdot
.30227 .2703 Mdot
.37981 .21212 Mdot
.31855 .20129 Mdot
.32848 .28715 Mdot
.35856 .30842 Mdot
.35801 .22536 Mdot
.33235 .28113 Mdot
.29785 .20931 Mdot
.3191 .24342 Mdot
.37347 .2707 Mdot
.86691 .45286 Mdot
.82165 .45647 Mdot
.79432 .45888 Mdot
.83075 .44002 Mdot
.78522 .45727 Mdot
.82744 .44925 Mdot
.77639 .44644 Mdot
.81557 .43881 Mdot
.81557 .45286 Mdot
.86994 .4669 Mdot
.8578 .45968 Mdot
.80233 .44323 Mdot
.82247 .44564 Mdot
.77694 .43761 Mdot
.86359 .4332 Mdot
.77666 .46249 Mdot
.84952 .50542 Mdot
.86194 .42277 Mdot
.86415 .40551 Mdot
.76507 .46128 Mdot
.79129 .44042 Mdot
.84593 .44724 Mdot
.82137 .47011 Mdot
.86497 .42598 Mdot
.80288 .46168 Mdot
.84014 .46449 Mdot
.86442 .45527 Mdot
.82855 .46168 Mdot
.84069 .46249 Mdot
.8302 .48255 Mdot
.7223 .27672 Mdot
.74879 .2715 Mdot
.78439 .28715 Mdot
.82744 .29678 Mdot
.78053 .2703 Mdot
.79791 .27431 Mdot
.79791 .27431 Mdot
.76507 .29237 Mdot
.80702 .28113 Mdot
.79046 .29919 Mdot
.74134 .28434 Mdot
.80371 .26227 Mdot
.7797 .25706 Mdot
.81309 .26829 Mdot
.78439 .28715 Mdot
.80067 .28956 Mdot
.79874 .24863 Mdot
.76066 .29357 Mdot
.42066 .54955 Mdot
.45129 .58205 Mdot
.38671 .55036 Mdot
.48606 .55276 Mdot
.47613 .57804 Mdot
.45488 .55317 Mdot
.41072 .58928 Mdot
.37374 .58286 Mdot
.74051 .40872 Mdot
.751 .43119 Mdot
.72947 .37061 Mdot
.70408 .41996 Mdot
.73803 .38826 Mdot
.71457 .37101 Mdot
.68946 .36619 Mdot
.73361 .42036 Mdot
.7165 .38665 Mdot
.69442 .38425 Mdot
.69166 .41755 Mdot
.70353 .41113 Mdot
.71264 .41875 Mdot
.68835 .37221 Mdot
.72064 .38024 Mdot
.69746 .40351 Mdot
.72257 .40632 Mdot
.71181 .4011 Mdot
.69111 .37502 Mdot
.7234 .38706 Mdot
.72092 .41715 Mdot
.71595 .35656 Mdot
.71926 .42156 Mdot
.70077 .38264 Mdot
.75376 .39588 Mdot
.70132 .42517 Mdot
.75017 .41875 Mdot
.73251 .40551 Mdot
.7532 .41715 Mdot
.73278 .38545 Mdot
.488 .26107 Mdot
.48248 .24943 Mdot
.49931 .30842 Mdot
.46757 .26749 Mdot
.46757 .29879 Mdot
.45929 .25585 Mdot
.50069 .26227 Mdot
.5098 .28234 Mdot
.47475 .2723 Mdot
.47282 .27592 Mdot
.4811 .30801 Mdot
.48827 .2719 Mdot
.48137 .29437 Mdot
.50097 .29517 Mdot
.44108 .3048 Mdot
.0503 .4982 Mdot
.03761 .53471 Mdot
.13806 .50301 Mdot
.08011 .48455 Mdot
.04754 .49499 Mdot
.04865 .48576 Mdot
.04699 .44523 Mdot
.07321 .43841 Mdot
.05444 .44363 Mdot
.12095 .52347 Mdot
.05886 .52147 Mdot
.04616 .46449 Mdot
.05196 .50502 Mdot
.08204 .52147 Mdot
.83986 .4023 Mdot
.79212 .39388 Mdot
.7659 .40752 Mdot
.80343 .38505 Mdot
.76121 .43681 Mdot
.81778 .39147 Mdot
.78356 .39428 Mdot
.82551 .38946 Mdot
.76148 .42598 Mdot
.75817 .41113 Mdot
.8429 .38385 Mdot
.76066 .39869 Mdot
.83655 .39468 Mdot
.83489 .41875 Mdot
.83489 .41875 Mdot
.79957 .40591 Mdot
.81778 .40792 Mdot
.76894 .38465 Mdot
.77859 .43119 Mdot
.83655 .38585 Mdot
.8153 .41675 Mdot
.81806 .38465 Mdot
.90775 .42277 Mdot
.90609 .42838 Mdot
.71926 .25425 Mdot
.7648 .21573 Mdot
.74575 .24101 Mdot
.76894 .24663 Mdot
.77611 .22737 Mdot
.72754 .26388 Mdot
.7292 .24622 Mdot
.74989 .23018 Mdot
.74824 .26588 Mdot
.73113 .26548 Mdot
.75817 .2398 Mdot
.45902 .51786 Mdot
.48606 .49017 Mdot
.46261 .49218 Mdot
.46592 .47533 Mdot
.42839 .49218 Mdot
.3823 .48415 Mdot
.48717 .47252 Mdot
.48027 .50502 Mdot
.4764 .45687 Mdot
.68835 .27672 Mdot
.7245 .302 Mdot
.67814 .26709 Mdot
.64226 .3036 Mdot
.64778 .28153 Mdot
.6086 .29076 Mdot
.71733 .29196 Mdot
.6166 .28073 Mdot
.69829 .28595 Mdot
.59866 .26749 Mdot
.65717 .26428 Mdot
.65358 .29317 Mdot
.66351 .27551 Mdot
.43832 .2041 Mdot
.46564 .09135 Mdot
.42149 .2719 Mdot
.47116 .15314 Mdot
.49986 .12184 Mdot
.53215 .14471 Mdot
.47171 .1066 Mdot
.40907 .20129 Mdot
.47558 .04721 Mdot
.45046 .18925 Mdot
.4902 .16197 Mdot
.47447 .09215 Mdot
.49158 .19607 Mdot
.48524 .21453 Mdot
.42011 .13067 Mdot
.4811 .22295 Mdot
.42425 .11863 Mdot
.3271 .18925 Mdot
.48192 .21413 Mdot
.51918 .12907 Mdot
.49848 .21974 Mdot
.47199 .05524 Mdot
.51007 .14511 Mdot
.50676 .16317 Mdot
.47144 .172 Mdot
.40106 .21092 Mdot
.52028 .2053 Mdot
.403 .23379 Mdot
.51918 .18002 Mdot
.46261 .05444 Mdot
.39692 .19286 Mdot
.46509 .21292 Mdot
.50538 .18885 Mdot
.41679 .27913 Mdot
.37512 .18002 Mdot
.40493 .24663 Mdot
.53215 .14471 Mdot
.42645 .18042 Mdot
.45847 .13468 Mdot
.48827 .23539 Mdot
.4179 .21132 Mdot
.47696 .1724 Mdot
.51145 .20249 Mdot
.44467 .24622 Mdot
.48413 .11823 Mdot
.47916 .18484 Mdot
.45819 .24141 Mdot
.21616 .33129 Mdot
.23741 .42878 Mdot
.27412 .35295 Mdot
.2341 .41554 Mdot
.25369 .37743 Mdot
.23907 .39187 Mdot
.233 .35696 Mdot
.20926 .31524 Mdot
.23493 .40511 Mdot
.2755 .39749 Mdot
.88816 .48776 Mdot
.87767 .49418 Mdot
.8807 .47332 Mdot
.78881 .33931 Mdot
.77528 .304 Mdot
.80619 .34573 Mdot
.78246 .34934 Mdot
.77749 .32246 Mdot
.82717 .31203 Mdot
.80536 .31885 Mdot
.8084 .32647 Mdot
.7648 .32206 Mdot
.78246 .34493 Mdot
.7946 .3674 Mdot
.03871 .55477 Mdot
.05996 .5985 Mdot
.05775 .56881 Mdot
.09335 .55597 Mdot
.0641 .57724 Mdot
.11626 .53631 Mdot
.05334 .53511 Mdot
.11322 .55999 Mdot
.05389 .55437 Mdot
.04506 .58205 Mdot
.06383 .57082 Mdot
.14303 .57042 Mdot
.06051 .56119 Mdot
.13033 .5335 Mdot
.09667 .5652 Mdot
.09308 .54474 Mdot
.74575 .33329 Mdot
.7441 .32166 Mdot
.73775 .34733 Mdot
.75845 .369 Mdot
.76673 .35977 Mdot
.72285 .34854 Mdot
.79764 .37221 Mdot
.76562 .37823 Mdot
.7383 .369 Mdot
.75265 .38946 Mdot
.62543 .48897 Mdot
.58265 .54474 Mdot
.61467 .44684 Mdot
.5741 .50381 Mdot
.62433 .47814 Mdot
.62957 .49459 Mdot
.57796 .47974 Mdot
.6097 .46209 Mdot
.63702 .48536 Mdot
.63785 .50943 Mdot
.63343 .45767 Mdot
.63426 .45206 Mdot
.63647 .47693 Mdot
.60584 .49499 Mdot
.62791 .45928 Mdot
.60501 .50502 Mdot
.326 .45687 Mdot
.35332 .41434 Mdot
.28295 .49619 Mdot
.25176 .41715 Mdot
.28847 .45446 Mdot
.33897 .41835 Mdot
.36326 .47934 Mdot
.31386 .42999 Mdot
.28405 .42517 Mdot
.31772 .50141 Mdot
.36326 .43681 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00=9oo`9T7daoo`00dGoo16@OBgoo003AOol4I1m;Ool00=9oo`9T7daoo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00eWoo00=W>GooOol0Agoo003FOol00fLiOomoo`17Ool00=Eoo`=W>@03OomT7f@O
04Eoo`00R7oo0V@OBgoo0fLi16@OA7oo0027Ool4I1m:Ool3IcT4I1m4Ool008Aoo`MT7dUoo`AW>@AT
7dAoo`00Pgoo1f@OBWoo16Li16@OA7oo0023Ool6I1m8Ool2I1l6IcT2I1m5Ool0081oo`AW>@AT7`03
IcUoogoo04Eoo`AT7`=W>@9T7`03IcUT7f@O04Aoo`00P7oo2FLiAgoo16@O0VLi1f@O@goo0020Ool9
IcU8Ool2I1l3IcT7I1m3Ool007moo`YW>DUoo`EW>@9T7`03IcUT7f@O04Aoo`00Ogoo2VLiB7oo2FLi
AWoo001nOol;IcU5Ool2I1l00gooIcUW>@05IcT2I1m6Ool007ioo`]W>DAoo`AT7`IW>@AT7dEoo`00
OWoo1fLi16@O@Goo0V@O00=oof@OI1l00V@O1VLi16@OAGoo001mOol7IcT6I1loOol4I1l00gooI1mT
7`08IcT2I1m6Ool007eoo`MW>@IT7cmoo`AT7`04OomT7f@OIcT2I1l6IcU7Ool007aoo`UW>@AT7d5o
o`9T7`03OomT7f@O00ET7`EW>DMoo`00O7oo3VLi@goo1f@O16LiB7oo001kOol;IcT2I1l3IcU3Ool2
I1l00fLiI1mT7`04IcT2I1m7Ool007]oo`YW>@AT7`=W>D9oo`IW>@IT7dIoo`00Ngoo2VLi16@O16Li
@7oo1VLi1f@OAWoo001iOol2I1l;IcT2I1l2IcT2I1l3IcTnOol6IcT6I1m7Ool007Qoo`AT7`eW>@AT
7`03IcUT7f@O03eoo`IW>@AT7dUoo`00N7oo16@O3FLi26@O>goo16Li0V@O0VLi0f@OBGoo001hOol3
I1l?IcT2I1l00fLiI1mT7`02I1l00fLiOomoo`02I1lEOol3IcTNOol3IcT4I1l00fLiI1mT7`02I1m8
Ool007Moo`AT7a=W>@9T7`=W>@AT7a5oo`IW>Aeoo`AW>@AT7`03IcUT7f@O009T7dQoo`00JGoo3VLi
16@O26Li0V@O3VLi16@O3Woo0fLi0V@O16Li7Goo1FLi0V@O0fLi0V@OBGoo001YOol?IcT2I1l8IcT4
I1l>IcT2I1l<Ool5IcT4I1l3IcTMOol4IcT2I1l5IcU:Ool006QooaYW>@AT7a5W>@03OomT7f@O00Eo
o`QW>@AT7`=W>Aaoo`AW>@AT7`AW>DYoo`00Igoo76Li0V@O36Li0V@O16Li16@O00=oofLiIcT02VLi
16@O0VLi4Woo0V@O27oo16Li16@O0VLi0V@OBWoo001WOolYIcT4I1l3IcT6I1l4IcT2I1l6IcT4I1l0
0fLiOomoo`0?Ool4I1l6Ool6IcT2I1l2IcT4I1m9Ool006Ioob1W>@9T7`QW>@AT7`AW>@IT7`9W>@AT
7`EW>@AT7`03IcUoogoo00moo`AT7`9W>@9T7`aW>@AT7dUoo`00IGoo86Li16@O26Li0V@O1fLi16@O
0VLi16@O1VLi0V@O0VLi0Woo0V@O1Goo00=W>F@OI1l01VLi0V@O0VLi16@O2VLi16@OBWoo001UOolP
IcT4I1l3IcT2I1l=IcT2I1l4IcT2I1l2IcT2I1l8IcT4I1l4IcT4I1l9IcT4I1l9IcT4I1m;Ool006Ao
ob9W>@9T7`=W>@AT7`03IcUT7f@O019W>@AT7`=W>@9T7`9W>@IT7`9W>@AT7`YW>@9T7`YW>@AT7d]o
o`00Hgoo:6Li26@O4FLi16@O0VLi16@O0VLi1V@O0VLi0V@O4FLi0V@O1FLi0V@OC7oo001ROolTIcT4
I1l2IcT2I1l00fLiI1mT7`02I1lBIcT2I1l3IcT4I1l4IcT4I1lDIcT4I1l7IcU;Ool0069oob=W>@IT
7`EW>@9T7aMW>@AT7`IW>@9T7aEW>@AT7`03IcUT7f@O009W>@9T7d]oo`00B7oo0V@O5goo96Li1V@O
5FLi0V@O1VLi16@O0VLi0V@O46Li0V@O2FLi0V@O00=W>F@OI1l01V@OBWoo0017Ool4I1l3Ool2I1l@
Ool;IcT2I1l<IcT2I1l;IcT4I1l:IcT2I1l9IcT4I1l5IcT4I1l00fLiI1mT7`02I1l>IcT4I1l;IcT8
I1m:Ool004Moo`ET7`03OomT7f@O009T7`moo`YW>@AT7`YW>@AT7`eW>@9T7`QW>@AT7`QW>@AT7`03
IcUT7f@O00=W>@9T7`9W>@AT7`iW>@AT7`AW>@9T7`IW>@9T7`9W>@9T7`03IcUoogoo04Qoo`00B7oo
2F@O16Li27oo0V@O2fLi16@O2VLi16@O16Li0V@O1VLi16@O16Li0V@O00=W>F@OI1l00V@O1FLi0V@O
0VLi0V@O00=W>F@OI1l00V@O1fLi16@O3VLi0V@O16Li16@O36LiBWoo0019Ool4I1l00fLiI1mT7`09
IcT3Ool4I1l;IcT2I1l4IcT2I1l6IcT2I1l4IcT4I1l5IcT4I1l3IcT4I1l00fLiI1mT7`05IcT4I1l4
IcT4I1l7IcT4I1lDIcT4I1l<IcU:Ool004Qoo`AT7a1W>@AT7a1W>@AT7`]W>@AT7`IW>@9T7`04IcUT
7f@OIcT4I1l8IcT4I1l5IcT2I1l9IcT2I1lEIcT3I1l=IcU:Ool004Eoo`9W>@AT7a9W>@9T7a5W>@AT
7`aW>@9T7`UW>@AT7`03IcUT7f@O00YW>@9T7bMW>@AT7`]W>@9T7dYoo`00@Woo1FLi16@O46Li0V@O
2VLi0V@O26Li0V@O00=W>F@OI1l01fLi0V@O36Li16@O0fLi0V@O4fLi0V@O00=W>F@OI1l01FLi0V@O
00=W>F@OI1l01VLi0V@O1fLi16@O0fLi0V@O1FLi16@OBGoo000oOol9IcT2I1l@IcT4I1l8IcT4I1l9
IcT4I1l5IcT4I1l<IcT2I1l3IcT5I1l3IcT2I1l6IcT2I1l3IcT7I1l3IcT7I1l4IcT4I1l4IcT2I1l0
0fLiI1mT7`03IcT4I1l4IcT4I1l00fLiOomoo`16Ool003Ioo`9T7`AooaUW>@9T7`=W>@AT7`QW>@AT
7`QW>@ET7`EW>@AT7a5W>@IT7`03IcUT7f@O00=T7`=W>@AT7`9W>@MT7`=W>@MT7`AW>@AT7`03IcUT
7f@O00AT7`=W>@IT7`EW>@9T7`=W>DMoo`00:Woo0f@O17oo0V@O0Woo16@O6fLi16@O0fLi0V@O00=W
>F@OI1l01fLi0V@O0fLi0V@O0fLi1F@O00=W>F@OI1l016Li0V@O1VLi0V@O0VLi0f@O1VLi1F@O00=W
>F@OI1l016@O0VLi16@O0fLi0V@O00=W>F@OI1l01FLi0V@O00=W>F@OI1l01VLi0V@O00=W>F@OI1l0
1F@O0VLi1V@O36LiAWoo000YOol5I1l2IcT4I1l00fLiI1mT7`02I1lKIcT4I1l5IcT4I1l5IcT4I1l0
0fLiI1mT7`02I1l2IcT4I1l00fLiI1mT7`02I1l:IcT9I1l7IcT2I1l3IcT5I1l3IcT2I1lKIcT7I1l3
IcT4I1l>IcT2I1m4Ool002Uoo`ET7`9W>@AT7`9W>@9T7aeW>@9T7`IW>@AT7`EW>@AT7`03IcUT7f@O
009T7`=W>@9T7`9W>@AT7`YW>@UT7`03IcUT7f@O00]W>@9T7b1W>@MT7`EW>@9T7`iW>@AT7d=oo`00
:Goo16@O16Li0V@O:fLi0V@O1fLi0V@O0fLi0V@O2FLi0V@O36Li0V@O0VLi0f@O00=W>F@OI1l00V@O
36Li0V@O5fLi0V@O1FLi26@O00=W>F@OI1l04FLi16@O@goo000XOol5I1lEIcT2I1lRIcT2I1lPIcT4
I1l00fLiI1mT7`02I1l;IcT4I1lEIcT4I1l5IcT2I1l00fLiI1mT7`06I1l8IcT2I1l7IcT2I1l2IcT2
I1m0Ool002Moo`ET7aEW>@AT7b1W>@AT7amW>@AT7`9W>@9T7`QW>@9T7`9W>@AT7`YW>@9T7`UW>@AT
7`04IcUT7f@OIcT2I1l3IcT2I1l00fLiI1mT7`02I1l7IcT4I1l2IcT2I1l5IcT4I1loOol002Ioo`ET
7`]W>@9T7`UW>@AT7b1W>@AT7`YW>@9T7aAW>@AT7`YW>@AT7`9W>@9T7`YW>@AT7`UW>@9T7`03IcUT
7f@O00ET7`EW>@=T7`QW>@AT7`03IcUT7f@O009T7`AW>@AT7cmoo`009Goo1F@O0fLi0V@O1VLi16@O
2FLi0V@O8VLi0V@O2VLi16@O56Li16@O2FLi16@O00=W>F@OI1l00V@O2FLi16@O36Li26@O0fLi16@O
2FLi0V@O0VLi16@O1FLi0V@O00=W>GooOol0?Goo000SOol00fLiI1mT7`0:I1l5IcT4I1liIcT4I1l=
IcT2I1l5IcT4I1l:IcT2I1l2IcT4I1l:IcT2I1l>IcT2I1l00fLiI1mT7`02I1l3IcT4I1l2IcT2I1l9
IcT5I1l8IcTnOol0029oo`03IcUT7f@O00]T7`IW>@9T7b=W>@9T7aIW>@9T7`eW>@AT7`EW>@9T7a1W
>@9T7amW>@9T7`AW>@AT7`03IcUT7f@O009T7`MW>@MT7`MW>Cioo`0087oo0V@O00=W>F@OI1l02V@O
:fLi16@O5FLi0V@O2VLi0V@O00=W>F@OI1l00V@O0fLi0V@O5VLi0V@O1FLi0V@O1fLi0V@O2VLi16@O
0fLi16@O00=W>F@OI1l00V@O0fLi0V@O0VLi2F@O1fLi0V@O>Woo000MOol@I1l]IcT4I1l>IcT2I1l4
IcT4I1l8IcT4I1l00fLiI1mT7`03IcT4I1lDIcT4I1l3IcT4I1l5IcT4I1l9IcT4I1l4IcT2I1l00fLi
I1mT7`02I1l3IcT4I1l2IcT2I1l00fLiI1mT7`04I1l5IcT4I1liOol001aooa1T7bmW>@9T7`iW>@AT
7`=W>@AT7`QW>@AT7`03IcUT7f@O00=W>@AT7a1W>@9T7`9W>@AT7`=W>@AT7`EW>@AT7`YW>@9T7`=W
>@9T7`=W>@AT7`03IcUT7f@O00AT7`MW>@AT7`EW>@AT7cUoo`006Woo3V@O3VLi0V@O26Li0V@O:FLi
16@O16Li0V@O2VLi0V@O00=W>F@OI1l00V@O0fLi0V@O46Li16@O00AW>F@OI1mT7`EW>@9T7`MW>@9T
7`IW>@AT7`EW>@AT7`=W>@9T7`03IcUT7f@O00AT7`UW>@9T7`9W>@9T7`=W>@9T7`9W>CQoo`006Goo
1V@O0VLi0V@O0VLi16@O0fLi0V@O1fLi16@O1VLi16@O:FLi0V@O56Li16@O1FLi0V@O0VLi0V@O2VLi
26@O4fLi26@O16Li16@O1VLi16@O3VLi16@O0fLi0V@O0fLi=Woo000IOol4I1l8IcT4I1l2IcT4I1l6
IcT4I1l6IcT4I1l5IcT2I1liIcT2I1l5IcT8I1l:IcT2I1l00fLiI1mT7`02I1lBIcT9I1l5IcT2I1l8
IcT2I1l016LiI1mT7f@O0fLi0V@O1VLi16@O0VLi16@O0fLi=Goo000IOol4I1l9IcT2I1l3IcT4I1l7
IcT2I1l8IcT2I1l2IcT2I1l00fLiI1mT7`02I1l;IcT2I1l4IcT2I1lWIcT2I1l3IcT8I1l>IcT2I1l9
IcT2I1l8IcT9I1l4IcT2I1l;IcT5I1l00fLiI1mT7`02I1l6IcT2I1l3IcT6I1l2IcTdOol001Uoo`AT
7`mW>@9T7`]W>@9T7`QW>@QT7`YW>@AT7`9W>@AT7`]W>@9T7`aW>@9T7`YW>@ET7`9W>@9T7`9W>@9T
7aUW>@AT7`QW>@9T7`9W>@AT7`=W>@AT7`YW>@ET7`03IcUT7f@O009T7`EW>@AT7`=W>@IT7`03IcUo
ogoo039oo`006Goo0f@O1FLi0V@O5FLi16@O1fLi16@O00=W>F@OI1l02fLi16@O0VLi16@O2VLi16@O
2VLi16@O2FLi2V@O26Li0V@O4VLi16@O3FLi16@O0VLi1F@O26Li1F@O0VLi16@O1FLi16@O0VLi0V@O
00=W>F@OI1l00V@O=Goo000HOol4I1l4IcT4I1lDIcT4I1l8IcT2I1l<IcT2I1l2IcT2I1l4IcT2I1l;
IcT4I1l:IcT4I1l:IcT9I1l7IcT4I1lBIcT2I1l3IcT2I1l:IcT4I1l2IcT5I1l6IcT4I1l4IcT4I1l6
IcT2I1l2IcT4I1l00fLiI1mT7`0fOol001Qoo`AT7`AW>@AT7aEW>@9T7aIW>@AT7`YW>@9T7`UW>@9T
7`YW>@AT7`aW>@AT7`03IcUT7f@O00AW>@9T7`9W>@AT7aIW>@AT7`IW>@9T7`03IcUT7f@O009T7`=W
>@AT7`IW>@AT7`=W>@AT7`]W>@ET7`03IcUoogoo03Eoo`005goo0VLi0V@O1VLi0V@O;VLi16@O26Li
1F@O56Li16@O3FLi0V@O1fLi16@O0VLi0V@O3fLi0V@O1VLi16@O1FLi16@O00=W>F@OI1l01FLi0V@O
00=W>F@OI1l01FLi0V@O0fLi16@O2FLi0V@O0VLi1F@O1VLi<Goo000GOolkIcT2I1l8IcT6I1lEIcT2
I1lGIcT4I1l3IcT2I1l=IcT4I1l4IcT4I1l6IcT5I1l9IcT4I1l9IcT4I1l8IcT4I1l2IcT4I1l4IcTc
Ool001IooaeW>@9T7bMW>@ET7bQW>@9T7`IW>@9T7`=W>@AT7`aW>@AT7`=W>@AT7`QW>@ET7`QW>@AT
7`=W>@9T7`EW>@9T7`=W>@=T7`=W>@AT7`03IcUT7f@O009T7`9W>CIoo`005Woo2VLi0V@O46Li16@O
9fLi0V@O:FLi16@O0fLi0V@O1FLi16@O3FLi0V@O16Li16@O26Li1F@O2FLi0V@O0fLi16@O26Li1F@O
0fLi0V@O0VLi16@O0fLi00=oof@OI1l0<Woo000FOol9IcT4I1l?IcT4I1m?IcT2I1l00fLiI1mT7`02
I1l2IcT4I1l5IcT2I1lEIcT2I1l9IcT4I1l?IcT4I1l8IcT5I1l5IcT2I1l00fLiI1mT7`04IcT4I1l0
0fLiOomoo`0^Ool001Aoo`9T7`UW>@AT7a1W>@9T7dUW>@9T7`AW>@AT7`03IcUT7f@O00=W>@AT7bEW
>@9T7`03IcUT7f@O015W>@AT7`QW>@=T7`03IcUT7f@O009W>@AT7`IW>@AT7c5oo`004goo16@O1fLi
16@O<VLi0V@O46Li0V@O5FLi16@O0fLi16@O00=W>F@OI1l00fLi0f@O66Li0V@O2fLi16@O56Li16@O
2VLi16@O00=W>F@OI1l00V@O1fLi0V@O00=W>GooOol0;goo000COol5I1l5IcT4I1lbIcT4I1l>IcT4
I1lDIcT4I1l4IcT2I1l00fLiI1mT7`02I1l00fLiI1mT7`02I1lGIcT4I1l00fLiI1mT7`07IcT4I1lD
IcT4I1l:IcT4I1l2IcT2I1l8IcT2I1l00fLiOomoo`0_Ool001=oo`ET7`EW>@AT7aYW>@9T7aIW>@AT
7`iW>@AT7`iW>@9T7`EW>@9T7`QW>@AT7`03IcUT7f@O009T7aMW>@QT7`IW>@AT7`eW>@9T7`IW>@9T
7`aW>@9T7`aW>@AT7c5oo`004Woo1F@O1fLi0V@O6VLi16@O5VLi0V@O46Li0V@O3VLi16@O3fLi0V@O
0fLi0V@O1FLi0V@O4VLi0V@O00=W>F@OI1l00V@O00=W>F@OI1l016Li0V@O3FLi16@O76Li0V@O0fLi
16@O<Goo000BOol4I1lTIcT4I1lHIcT2I1l?IcT2I1l=IcT4I1lGIcT2I1l00fLiI1mT7`02I1l3IcT2
I1l@IcT2I1l00fLiI1mT7`02I1l3IcT2I1l=IcT4I1l:IcT2I1l4IcT2I1l2IcT2I1l5IcT4I1l00fLi
Oomoo`02I1lbOol0019oo`03IcUT7f@O00EW>@9T7amW>@9T7aQW>@AT7`MW>@9T7`AW>@AT7`eW>@9T
7aMW>@QT7`9W>@AT7`iW>@QT7`9W>@AT7`eW>@9T7`YW>@AT7`9W>@QT7`AW>@AT7`03OomW>FLi03Ao
o`004Goo1F@O0fLi16@O>6Li16@O1VLi16@O0fLi16@O9VLi16@O00=W>F@OI1l00fLi16@O3VLi16@O
00=W>F@OI1l00fLi16@O6FLi16@O0VLi26@O1FLi0f@O0VLi=Goo000@Ool6I1l2IcT5I1lPIcT2I1lG
IcT2I1l7IcT4I1l4IcT2I1lCIcT2I1l:IcT2I1l7IcT2I1l8IcT2I1l<IcT2I1l2IcT3I1l7IcT3I1lJ
IcT3I1l3IcT2I1l2IcT2I1l6IcT4I1l00fLiOomoo`02Ool00fLiOomoo`0^Ool0011oo`IT7`03IcUT
7f@O00=T7b1W>@AT7b1W>@9T7aUW>@AT7`QW>@ET7`AW>@AT7aAW>@AT7`03IcUT7f@O009T7`IW>@AT
7aUW>@AT7`iW>@AT7`Eoo`03IcUoogoo02ioo`004Goo2V@O3fLi0V@O46Li16@O:fLi0V@O2fLi0V@O
00=W>F@OI1l00V@O1VLi26@O0fLi16@O3fLi0V@O0fLi16@O00=W>F@OI1l00V@O1FLi1F@O2FLi0V@O
3VLi16@O2FLi0V@O16Li0V@O00=W>GooOol00goo0VLi;goo000@Ool:I1l?IcT4I1l@IcT2I1l[IcT4
I1l9IcT4I1l00fLiI1mT7`06IcT9I1l4IcT2I1l?IcT4I1l3IcT2I1l3IcT2I1l5IcT5I1l5IcT2I1l2
IcT4I1l>IcT2I1l9IcT4I1l5IcT6Ool2IcT_Ool0011oo`IT7`03IcUT7f@O011W>@AT7cUW>@9T7`9W
>@AT7`UW>@AT7`IW>@9T7`03IcUT7f@O009T7`9W>@9T7`03IcUT7f@O01=W>@AT7`YW>@9T7`=W>@AT
7`EW>@AT7`03IcUT7f@O009T7`aW>@9T7`YW>@ET7`9W>@9T7`03IcUoogoo00Aoo`9T7bmoo`003goo
1f@O56Li0V@O>FLi16@O0VLi0V@O2fLi0V@O1VLi16@O00=W>F@OI1l01FLi16@O4fLi0V@O2VLi16@O
0fLi0V@O1VLi16@O0VLi0V@O26Li0V@O0VLi16@O26Li1F@O0VLi16@O0goo00=W>GooI1l00f@O;Woo
000?Ool8I1lgIcT2I1lEIcT4I1lGIcT4I1l8IcT4I1l@IcT2I1l9IcT2I1l2IcT4I1l;IcT4I1l;IcT4
I1l00fLiI1mT7`02I1l8IcT4I1l3IcT4I1l2Ool2IcT00gooI1mT7`02I1l^Ool000ioo`AT7`03IcUT
7f@O00=T7bYW>@9T7`UW>@AT7aEW>@9T7aUW>@9T7`=W>@9T7`EW>@9T7`]W>@9T7`=W>@AT7`IW>@ET
7`9W>@9T7`AW>@9T7`MW>@9T7`]W>@ET7`9W>@9T7`UW>@AT7`AW>@9T7`03IcUoogoo00AW>@9T7`03
IcUoogoo02aoo`003Woo16@O0VLi16@O:FLi16@O26Li16@O56Li0V@O6VLi0V@O0VLi16@O46Li16@O
0VLi16@O1FLi26@O1FLi16@O0VLi0V@O3VLi1F@O2fLi0V@O0VLi0V@O1fLi0V@O0fLi00=oofLiIcT0
0VLi;Woo000=Ool2IcT2I1l4IcT2I1lZIcT4I1l9IcT2I1lDIcT4I1lHIcT4I1l00fLiI1mT7`02I1l2
IcT2I1l3IcT2I1l7IcT4I1l3IcT2I1l6IcT9I1l4IcT4I1l00fLiI1mT7`02I1l6IcT2I1l5IcT4I1l;
IcT4I1l9IcT4I1l2IcT00gooIcUW>@02IcT^Ool000]oo`9W>@9T7`IW>@9T7`MW>@9T7b9W>@9T7`mW
>@9T7`mW>@AT7aQW>@AT7`9W>@9T7`9W>@AT7`03IcUT7f@O009T7`9W>@9T7`=W>@9T7`=W>@ET7`EW
>@9T7`9W>@AT7`EW>@9T7`9W>@AT7`EW>@AT7`EW>@9T7`aW>@AT7`EW>@9T7`9W>@ET7`IW>Bioo`00
2goo00=W>F@OI1l00V@O16Li16@O1FLi16@O56Li0V@O6fLi16@O1fLi0V@O1VLi0V@O36Li0V@O36Li
0V@O1fLi16@O00=W>F@OI1l00V@O00=W>F@OI1l00V@O1fLi1V@O2FLi0V@O2VLi1V@O0fLi1F@O16Li
0V@O0VLi0V@O00=W>F@OI1l00fLi0V@O00=W>F@OI1l01FLi16@O0VLi1F@O1FLi00=oofLiOol0:goo
000;Ool00fLiI1mT7`02I1l4IcT4I1l5IcT4I1lCIcT4I1lJIcT4I1l6IcT4I1lBIcT4I1lEIcT2I1l3
IcT2I1l2IcT4I1l7IcT6I1lCIcT9I1l3IcT4I1l3IcT;I1l00fLiI1mT7`02I1l7IcT6I1l00fLiI1mT
7`03I1l3IcT017ooI1mT7goo0V@O:Goo000;Ool2IcT2I1l6IcT2I1l6IcT4I1lCIcT4I1l@IcT2I1l9
IcT2I1l7IcT4I1lBIcT4I1lLIcT2I1l00fLiI1mT7`07IcT6I1lCIcT;I1l00fLiI1mT7`03I1l3IcT;
I1l00fLiI1mT7`04I1l3IcT2I1l00fLiI1mT7`04I1l00fLiI1mT7`02I1l00fLiI1mT7`07I1lXOol0
00]oo`UW>@9T7`MW>@AT7aAW>@9T7a1W>@AT7a9W>@9T7`EW>@9T7`eW>@9T7aaW>@AT7`UW>@AT7`9W
>@9T7a5W>@AT7`03IcUT7f@O00AT7`03IcUT7f@O00=T7`AW>@IT7`03IcUT7f@O00=W>@IT7`03IcUT
7f@O00QT7`9W>@9T7`03IcUT7f@O00QT7bQoo`002goo26Li16@O1fLi0V@O9fLi16@O66Li16@O:VLi
1F@O2FLi0V@O0VLi16@O1FLi0V@O0VLi0V@O1VLi0V@O00=W>F@OI1l016@O00=W>F@OI1l01V@O0fLi
1V@O1fLi16@O00=W>F@OI1l00V@O00=W>F@OI1l00V@O0VLi0V@O0VLi1V@O00=W>F@OI1l0:Goo000;
Ool8IcT4I1l<IcT2I1lSIcT2I1lHIcT5I1l[IcT4I1l9IcT2I1l2IcT5I1l3IcT:I1l4IcT6I1l00fLi
I1mT7`09I1l00fLiI1mT7`07I1l5IcT4I1l2IcT2I1l2IcT4I1l00fLiI1mT7`02I1l2IcT5I1l00fLi
Oomoo`0YOol000]oo`UW>@9T7`aW>@AT7aiW>@9T7a]W>@ET7a9W>@9T7aUW>@9T7`UW>@AT7`9W>@AT
7`=W>B]T7`04IcUT7f@OIcT4I1l6IcT4I1l00fLiI1mT7`0:I1l[Ool000]ooaMW>@AT7aeW>@AT7aYW
>@AT7a9W>@AT7a1W>@9T7a5W>@AT7`=W>@9T7`EW>@9T7`9W>AAT7`9W>@AT7`03IcUT7f@O00eT7`03
IcUT7f@O00=W>@AT7`04IcUT7f@OIcT>I1l00gooI1mT7`0WOol000]oo`MW>@9T7`mW>@9T7aiW>@AT
7`MW>@9T7a9W>@9T7`03IcUT7f@O011W>@AT7`mW>@AT7a5W>@9T7`=W>@9T7`9W>@9T7`IW>@9T7`03
IcUT7f@O00IT7`9W>@MT7`QW>@AT7`=W>@9T7`03IcUT7f@O00=T7`AW>@IT7`=W>A9T7bIoo`002goo
1VLi16@O;fLi0V@O1fLi16@O4fLi16@O16Li0V@O2VLi0V@O2FLi0V@O1FLi16@O5FLi26@O00AW>F@O
I1mW>@UT7`AW>@MT7`QW>@9T7`UW>@IT7`=W>@IT7`AW>@9T7`03IcUT7f@O00aT7bIoo`002Woo1fLi
16@O;VLi0V@O26Li16@O4VLi1F@O0fLi16@O4FLi1V@O1FLi0V@O5VLi46@O00=W>F@OI1l01VLi1V@O
1FLi0V@O00=W>F@OI1l016@O00=W>F@OI1l016Li1F@O16Li1V@O2FLi2V@O9goo000:Ool8IcT2I1lC
IcT2I1l8IcT2I1l?IcT4I1l8IcT2I1lBIcT5I1l4IcT4I1l@IcT7I1l5IcT2I1lGIcT;I1l00fLiI1mT
7`0:IcT6I1l4IcT?I1l4IcT4I1l6IcT4I1l2IcT2I1l4IcT5I1l00fLiI1mT7`03I1lVOol000Uoo`9T
7a]W>@AT7`IW>@AT7`iW>@AT7aaW>@AT7`IW>@9T7a5W>@IT7`EW>@AT7a5W>@9T7`=W>@YT7`MW>@9T
7`IW>@MT7`9W>A1T7`9W>@IT7`EW>@AT7`03IcUT7f@O009T7`AW>@=T7`9W>@IT7bEoo`0027oo16@O
6VLi16@O1VLi16@O3VLi0f@O0VLi0V@O6VLi16@O1VLi0V@O2FLi0V@O1VLi1V@O16Li16@O46Li16@O
0fLi0V@O00=W>F@OI1l00V@O26Li16@O1fLi1V@O0VLi1F@O0VLi0V@O00=W>F@OI1l00f@O00=W>F@O
I1l01F@O1VLi0V@O0VLi16@O2FLi1f@O97oo0008Ool4I1lKIcT2I1l8IcT2I1l>IcT4I1l00fLiI1mT
7`02I1lFIcT2I1l2IcT4I1l4IcT4I1l7IcT4I1l7IcT4I1l5IcT2I1l2IcT2I1l=IcT4I1l7IcT2I1l4
IcT2I1l3IcT4I1l8IcT7I1l00fLiI1mT7`0;I1l00fLiI1mT7`05I1l;IcT4I1l2IcT2I1l6IcT7I1l3
Ool2I1lNOol000Uoo`9T7cIW>@AT7`03IcUT7f@O009T7aEW>@AT7`03IcUT7f@O009T7`AW>@AT7`MW
>@AT7`QW>@9T7`=W>@9T7`9W>@IT7`MW>@9T7`AW>@9T7`MW>@9T7`AW>@AT7`03IcUT7f@O009T7`04
IcUT7f@OI1l4IcT2I1l00fLiI1mT7`0@I1l00fLiI1mT7`03I1l>IcT4I1l00fLiI1mT7`02I1l5IcT7
I1l2IcT6I1lKOol000YoocQW>@9T7`=W>@9T7`QW>@9T7`aW>@AT7`9W>@9T7`IW>@9T7`UW>@9T7`eW
>@]T7`IW>@IT7`EW>@9T7`9W>@AT7`=W>@QT7`03IcUT7f@O00UT7`9W>A1T7`03IcUT7f@O00AT7`iW
>@9T7`9W>@AT7`AW>@QT7`9W>@QT7aUoo`002Goo0V@O1FLi0V@O<FLi0V@O2fLi16@O1FLi0V@O1FLi
0V@O9FLi2V@O1fLi1f@O0fLi16@O00=W>F@OI1l00f@O00=W>F@OI1l00V@O00=W>F@OI1l00V@O00=W
>F@OI1l02F@O0fLi2f@O00=W>F@OI1l00fLi1V@O4VLi0V@O1FLi4f@O67oo0008Ool4I1l3IcT4I1l_
IcT4I1l:IcT4I1l4IcT4I1l>IcT2I1lLIcT2I1l2IcT2I1l;IcT6I1l3IcT4I1l2IcT8I1l2IcT?I1l6
IcT4I1l2IcT2I1l7IcT6I1l2IcT2I1lFIcTBI1lHOol000Qoo`AT7`=W>@AT7bmW>@AT7`]W>@9T7`EW
>@AT7`]W>@IT7aYW>@AT7`iW>@9T7`04IcUT7f@OI1l3IcT4I1l3IcT7I1l2IcT7I1l00fLiI1mT7`02
I1l8IcT4I1l4IcT3Ool4IcT6I1l2IcT4I1lEIcT4I1l00fLiI1mT7`0:I1lIOol000Uoo`9T7`EW>@9T
7`9W>@9T7beW>@9T7aAW>@9T7`]W>@MT7aYW>@AT7`eW>@QT7`9W>@AT7`AW>@9T7`03IcUT7f@O00=W
>@MT7`9W>@AT7`03IcUT7f@O00=W>@IT7`=W>@Eoo`9W>@MT7`03IcUT7f@O009T7`03IcUT7f@O00EW
>@9T7`9W>@9T7`MW>@AT7`9W>@]T7aUoo`002Woo1FLi0V@O0VLi16@OCfLi1V@O76Li0V@O0VLi0V@O
2VLi26@O0fLi0V@O0VLi0V@O16Li16@O00=W>F@OI1l016@O0fLi26@O00=W>F@OI1l026@O1goo00=W
>F@OI1l016@O00=W>F@OI1l026@O00=W>F@OI1l01V@O1fLi0V@O16Li2V@O6Goo000:Ool3IcT5I1l0
0fLiI1mT7`02I1lPIcT2I1l00fLiI1mT7`0[IcT2I1lRIcT4I1l8IcT4I1l2IcT4I1l5IcT4I1l2IcT6
I1l00fLiI1mT7`03I1l4IcT2I1l00fLiI1mT7`0>I1l8Ool2IcT2I1l3IcT2I1l00fLiI1mT7`0=I1l2
IcT2I1l6IcT2I1l00fLiI1mT7`09I1lHOol000Yoo`9W>@IT7`9W>@9T7b1W>@MT7diW>@AT7`MW>@AT
7`AW>@AT7`AW>@AT7`9W>@IT7`9W>@AT7`EW>@9T7`03IcUT7f@O009T7`03IcUT7f@O009W>@IT7`]o
o`=W>@AT7`03IcUT7f@O00AT7`03IcUT7f@O00AT7`9W>@AT7`AW>@AT7`04IcUT7f@OIcT7I1lHOol0
00Yoo`9W>@ET7bEW>@MT7aEW>@9T7aUW>@9T7aeW>@9T7`QW>@AT7`AW>@AT7`EW>@9T7`AW>@ET7`9W
>@AT7`AW>@AT7`04IcUT7f@OIcT2I1l3IcT5I1l>Ool00fLiI1mT7`02I1l4IcT2I1l2IcT6I1l2IcT4
I1l2IcT6I1l5IcT7I1lGOol000Yoo`=W>@9T7bQW>@9T7`03IcUT7f@O00AW>@9T7`mW>@AT7`QW>@9T
7`eW>@AT7aQW>@9T7`eW>@9T7`IW>@9T7`iW>@9T7`=W>@AT7`AW>@IT7`03IcUT7f@O009T7`03IcUT
7f@O00=T7`9W>@9T7`eoo`AT7`03IcUT7f@O00=W>@MT7`=W>@9T7`9W>@IT7`=W>@9T7`03IcUT7f@O
00ET7aMoo`002Woo9VLi0V@O3FLi16@O3VLi16@O1fLi16@O36Li16@O5fLi16@O46Li0V@O4FLi0V@O
0fLi1F@O1FLi3f@O0VLi16@O27oo0V@O0Woo2F@O00=W>F@OI1l01F@O00=W>F@OI1l00fLi1V@O0fLi
2V@O67oo000:Ool3IcT2I1lPIcT4I1l<IcT4I1l?IcT2I1l8IcT4I1l=IcT2I1lHIcT4I1l?IcT4I1l?
IcT4I1l00fLiI1mT7`04I1l5IcT6I1l016LiI1mT7fLi16@O0fLi16@O1goo3f@O00=W>F@OI1l026@O
00=W>F@OI1l016@O16Li2f@O5goo000:Ool2IcT4I1lOIcT4I1l=IcT2I1lKIcT2I1lYIcT2I1l@IcT4
I1l?IcT4I1l00fLiI1mT7`03I1l5IcT6I1l6IcT2I1l5IcT2I1l8Ool9I1l00fLiI1mT7`03I1l3IcT8
I1l00fLiI1mT7`04I1l5IcT:I1lGOol000Yoo`9W>@AT7aiW>@AT7a1W>@9T7dMW>@9T7`iW>@9T7a5W
>@9T7`=W>@9T7`MW>@AT7`AW>@9T7`03IcUT7f@O00IW>@]oo`9T7`9oo`9T7`EW>@9T7`AW>@QT7`9W
>@IT7`EW>@QT7`9W>AIoo`002Woo0fLi0V@O7VLi16@O46Li16@O@6Li0V@O0fLi16@O3FLi0V@O86Li
0V@O16Li1f@O16Li4goo2FLi16@O0VLi0V@O1FLi1V@O1FLi0V@O16Li0V@O00=W>GooOol04goo000:
OolSIcT4I1l@IcT4I1lRIcT2I1lKIcT4I1l2IcT4I1l<IcT4I1l7IcT2I1l;IcT2I1l2IcT2I1l;IcT7
I1l4IcTEOol7IcT4I1l:IcT6I1l9IcT4I1l00fLiOomoo`0BOol000YoobAW>@9T7a9W>@9T7b9W>@AT
7aYW>@AT7`=W>@9T7`eW>@AT7`03IcUT7f@O00=W>@AT7`UW>@QT7`]W>@9T7`03IcUT7f@O00EW>AMo
o`IW>@AT7`]W>@AT7`UW>@AT7`9W>A=oo`002Woo0fLi0V@O1fLi0V@OCVLi16@O0fLi0V@O5VLi0V@O
4FLi0V@O00AW>F@OI1mW>@AT7`03IcUT7f@O00=T7`UW>@QT7aAW>AYoo`EW>@AT7`]W>@9T7`QW>@9T
7`03IcUT7f@O00AW>A9oo`002Woo0VLi16@O1FLi16@OCVLi0V@O0fLi16@O6fLi0V@O2VLi1V@O00=W
>F@OI1l01f@O2fLi0V@O00=W>F@OI1l00V@O56Li77oo0fLi16@O3VLi0V@O16Li1f@O16Li4Goo000:
Ool2IcT4I1l5IcT4I1mCIcT4I1l:IcT2I1l8IcT2I1l4IcT4I1l9IcT7I1l016LiI1mT7fLi16@O2fLi
26@O56Li7Woo0VLi0V@O3VLi16@O0fLi2F@O0fLi47oo000:Ool3IcT2I1l7IcT2I1lhIcT2I1lKIcT2
I1l:IcT4I1l6IcT4I1l3IcT4I1l:IcT6I1l5IcT2I1l8IcT2I1l2IcT7I1lDIcTQOol>IcT6I1l4IcT2
I1l00fLiI1mT7`04I1l3IcT?Ool000Yoo`9W>@AT7cmW>@AT7bIW>@AT7`IW>@AT7`AW>@9T7`iW>@9T
7`mW>@AT7`9W>@ET7`UW>@9T7`YW>B=oo`]W>@IT7`YW>@AT7`AW>@ioo`002Woo0VLi1F@O5VLi0V@O
9VLi16@O1fLi0V@O7VLi0V@O26Li0V@O5FLi0V@O1fLi0V@O1VLi16@O0fLi16@O26Li16@O2FLi9Woo
26Li16@O36Li16@O00=W>F@OI1l00VLi3Goo000:Ool3IcT4I1lEIcT4I1lVIcT2I1l7IcT4I1l/IcT2
I1l?IcT4I1l5IcT4I1l6IcT2I1l5IcT2I1l9IcT4I1l8IcTXOol2I1l6IcT2I1l>IcT2I1l00fLiI1mT
7`02I1l2IcT<Ool000Yoo`=W>@AT7aEW>@AT7bmW>@AT7b]W>@AT7`MW>@9T7`EW>@AT7`EW>@AT7`EW
>@AT7`IW>@9T7`QW>@9T7`QW>@9T7bIoo`AT7`9ooaIW>@AT7`=W>@]oo`002Woo0fLi16@O5VLi0V@O
<FLi0V@O;6Li16@O1VLi16@O1FLi0V@O1fLi0V@O1VLi16@O1FLi16@O46Li16@O9Goo16@O17oo5FLi
0V@O1FLi2Woo000:Ool4IcT2I1mcIcT2I1l4IcT2I1l7IcT4I1lGIcT2I1l6IcT4I1l@IcT4I1lVOol2
I1l?OolCIcT9Ool000Yoo`IW>@9T7`EW>@9T7fUW>@AT7`eW>@9T7`9W>@9T7aeW>@9T7a9W>@9T7cUo
oa9W>@Uoo`002Woo1FLi16@O0fLi16@O26Li0V@O9VLi0V@O=VLi16@O46Li16@O7fLi0V@O3fLi?7oo
2VLi0V@O16Li2Woo000:Ool5IcT4I1l3IcT4I1l7IcT4I1lQIcT2I1l00fLiI1mT7`02I1l6IcT2I1l^
IcT2I1l<IcT2I1l3IcT4I1lNIcT4I1l=IcTnOol8IcT4I1l3IcT:Ool000Yoo`IW>@9T7`EW>@9T7`QW
>@AT7a]W>@9T7`=W>@QT7`EW>@AT7cYW>@AT7`=W>@9T7amW>@AT7`eW>Cioo`QW>@AT7`9W>@]oo`00
2Woo0V@O0fLi0V@O4FLi0V@O00=W>F@OI1l066Li16@O0VLi16@O00=W>F@OI1l01VLi16@O>VLi16@O
9FLi0V@O3VLi?goo26Li0V@O0fLi2goo0009Ool4I1l00fLiI1mT7`02I1l?IcT2I1l00fLiI1mT7`02
I1lGIcT4I1l3IcT2I1l;IcT2I1liIcT2I1l00fLiI1mT7`0eIcU0Ool<IcT<Ool000Uoo`AT7`03IcUT
7f@O009T7`iW>@QT7`=W>@9T7a=W>@9T7aiW>@9T7b]W>@AT7`IW>@9T7baW>@9T7`03IcUoogoo03mo
o`]W>@aoo`002Woo0V@O0fLi0V@O2FLi0V@O16Li16@O00=W>F@OI1l00fLi16@O56Li0V@O6fLi16@O
:VLi16@O1FLi16@O36Li0V@O3fLi0V@O2fLi16@O@Woo2FLi3Goo000:Ool?IcT4I1l4IcT2I1l7IcT4
I1lCIcT4I1lJIcT4I1lEIcT2I1lDIcT2I1l6IcT4I1l;IcT4I1l=IcT4I1l:IcT4I1m2Ool8IcT>Ool0
00Yoo`mW>@AT7`eW>@AT7`]W>@9T7`IW>@AT7a]W>@9T7`aW>@9T7`MW>@AT7`MW>@9T7`MW>@9T7`YW
>@9T7`MW>@9T7`=W>@AT7`eW>@AT7`]W>@9T7dAoo`MW>@03OomT7f@O00]oo`002Woo0V@O0fLi0V@O
2FLi0V@O3VLi16@O2VLi16@O1VLi0V@O2fLi0V@O76Li16@O1VLi16@O1VLi16@O1FLi16@O4FLi16@O
0fLi0V@O3fLi0V@O2FLiBGoo1VLi00=oof@OI1l00V@O2Woo0009Ool4I1l00fLiI1mT7`02I1l7IcT4
I1l3IcT2I1l9IcT2I1l;IcT4I1lBIcT4I1lCIcT2I1l6IcT4I1l7IcT2I1l7IcT4I1l5IcT4I1lAIcT4
I1lMIcU<Ool5IcT00gooI1mT7`02I1l:Ool000Uoo`AT7`03IcUT7f@O00=T7`IW>@AT7`9W>@AT7aIW
>@9T7a=W>@AT7a9W>@AT7`IW>@9T7a9W>@9T7`MW>@9T7a=W>@9T7a]W>E1oo`=W>@=oo`9T7`]oo`00
2Goo00=W>F@OI1l00fLi1F@O1VLi0f@O0VLi16@O8VLi0V@O26Li0V@O4fLi16@O=fLi0V@O6FLiDgoo
0fLi47oo0009Ool7IcT4I1l6IcT4I1l2IcT2I1l6IcT2I1lJIcT4I1lMIcT2I1l/IcT2I1l9IcT4I1lF
IcUFOol00fLiOomoo`0?Ool000Uoo`IW>@IT7`EW>@AT7`UW>@AT7`03IcUT7f@O01IW>@AT7dYW>@AT
7`QW>@AT7a=W>F]oo`002Goo1VLi1V@O1VLi0V@O2VLi26@O5VLi0V@OBfLi16@O2FLi0V@O4VLiKGoo
0008Ool8IcT5I1lCIcT2I1l00fLiI1mT7`02I1mIIcT2I1l9IcT2I1lKIcU`Ool000Qoo`AW>@9T7`=W
>@AT7aMW>@9T7caW>@9T7aEW>@9T7`AW>@AT7b9W>G=oo`0027oo0fLi16@O0fLi0V@O96Li0V@O;fLi
16@O4fLi16@O0fLi16@O7FLiN7oo0008Ool3IcT4I1lXIcT4I1lQIcT2I1l;IcT4I1l8IcT2I1l9IcT4
I1l4IcT2I1lIIcUmOol000aoo`9T7`9oobMW>@AT7`IW>@9T7`]W>@9T7`]W>@AT7`]W>@9T7`QW>@AT
7`UW>@9T7aQW>@9T7`03IcUoogoo081oo`0047oo00=W>F@OI1l09FLi0V@O1VLi16@O2FLi16@O2VLi
16@O5FLi16@O8FLi00=oof@OI1l00V@OPWoo000@Ool4I1l/IcT4I1l9IcT4I1l;IcT2I1lGIcT2I1lM
IcT6Ool4I1n2Ool0011oo`AT7beW>@9T7`]W>@9T7cmW>@aoo`9T7h=oo`0047oo00=W>F@OI1l0MVLi
Ugoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-126.23, 23.9386, 0.210949, \
0.145094}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Filtering", "Subsection",
  CellTags->"Transport"],

Cell[BoxData[
    \(\(supplycities\  = \ 
        Select[citydata, \ Part[#, 5] > 0\  &];\)\)], "Input",
  CellTags->"Transport"],

Cell[BoxData[
    \(\(demandcities\  = \ 
        Select[citydata, \ Part[#, 6] > 0\  &];\)\)], "Input",
  CellTags->"Transport"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length\  /@ \ {supplycities, \ demandcities}\)], "Input",
  CellTags->"Transport"],

Cell[BoxData[
    \({10, 50}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(supplypoints = \ 
        Graphics[{Hue[ .3], \ AbsolutePointSize[5], \ 
            supplycities /. \ {city_String, state_, lat_, lon_, supply_, 
                  demand_} :> Point[{lon, lat}]}];\)\)], "Input",
  CellTags->"Transport"],

Cell[CellGroupData[{

Cell[BoxData[
    \(demandpoints = \ 
      Graphics[{Hue[ .8], AbsolutePointSize[4], 
          demandcities /. \ {city_String, state_, lat_, lon_, supply_, 
                demand_} :> Point[{lon, lat}]}]\)], "Input",
  CellTags->"Transport"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[borderpoly, supplypoints, \ demandpoints]\)], "Input",
  CellTags->"Transport"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.08891 0.0165583 -0.604284 0.024645 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.8 g
.14965 .1975 m
.14689 .209 L
.0917 .24761 L
.06079 .32031 L
.07845 .33264 L
.04064 .35523 L
.03264 .4308 L
.03457 .53637 L
.02381 .58853 L
.05637 .58278 L
.05113 .5569 L
.05637 .60291 L
.05665 .60332 L
.15103 .60332 L
.16759 .60332 L
.36684 .60332 L
.47944 .60332 L
.60556 .57867 L
.6958 .54253 L
.72423 .45586 L
.72036 .44436 L
.71954 .423 L
.78218 .4534 L
.7797 .45791 L
.7797 .46202 L
.83379 .49201 L
.87436 .50515 L
.90499 .50515 L
.91189 .51213 L
.94252 .56553 L
.97619 .50926 L
.91741 .45709 L
.9163 .45216 L
.91134 .41889 L
.91106 .41848 L
.91134 .41889 L
.89919 .41396 L
.86939 .40616 L
.85945 .39425 L
.84952 .35564 L
.84648 .38151 L
.83986 .37659 L
.84648 .34331 L
.84096 .33264 L
.8313 .31087 L
.83627 .3314 L
.82661 .34496 L
.83324 .37125 L
.82523 .33346 L
.81364 .35194 L
.81281 .3544 L
.81171 .33633 L
.82606 .30963 L
.80923 .31538 L
.83296 .29649 L
.83848 .27759 L
.83158 .3006 L
.81833 .2817 L
.83462 .27349 L
.81309 .27143 L
.82496 .25541 L
.78825 .23036 L
.74962 .18477 L
.73941 .15273 L
.76369 .05579 L
.74631 .01472 L
.70325 .13301 L
.63978 .14205 L
.62515 .14451 L
.60666 .13958 L
.59148 .13876 L
.60915 .1363 L
.60832 .10878 L
.53574 .13506 L
.53601 .13465 L
.4742 .08249 L
.48054 .03566 L
.44826 .04634 L
.41928 .1174 L
.36602 .11863 L
.32517 .17901 L
.28322 .16792 L
.18939 .20202 L
.14965 .1975 L
F
.2 1 0 r
5 Mabswid
.26197 .17409 Mdot
.62626 .42464 Mdot
.50538 .35851 Mdot
.58762 .12315 Mdot
.87518 .44148 Mdot
.75376 .39096 Mdot
.78356 .38932 Mdot
.65358 .28581 Mdot
.0641 .57662 Mdot
.7383 .36344 Mdot
.8 0 1 r
4 Mabswid
.17366 .20448 Mdot
.13861 .22255 Mdot
.08535 .3236 Mdot
.13337 .24925 Mdot
.04892 .36057 Mdot
.29178 .35974 Mdot
.74299 .10467 Mdot
.69663 .1745 Mdot
.73168 .21804 Mdot
.68035 .20941 Mdot
.74437 .18764 Mdot
.63316 .40821 Mdot
.61356 .41396 Mdot
.67124 .38398 Mdot
.64999 .38275 Mdot
.6395 .33346 Mdot
.54843 .423 Mdot
.55809 .40862 Mdot
.47585 .3236 Mdot
.64033 .29936 Mdot
.81944 .36139 Mdot
.87518 .44148 Mdot
.71429 .44107 Mdot
.69194 .54088 Mdot
.54319 .47147 Mdot
.61936 .19257 Mdot
.3249 .58894 Mdot
.1055 .36919 Mdot
.89616 .45627 Mdot
.78522 .45381 Mdot
.82137 .46695 Mdot
.73803 .38316 Mdot
.71595 .35071 Mdot
.04699 .44148 Mdot
.7292 .23775 Mdot
.7245 .29485 Mdot
.6166 .27308 Mdot
.47116 .14246 Mdot
.47171 .09481 Mdot
.40907 .19175 Mdot
.42425 .10713 Mdot
.51007 .13424 Mdot
.50676 .15273 Mdot
.46261 .04141 Mdot
.51145 .19298 Mdot
.27412 .34701 Mdot
.233 .35112 Mdot
.06051 .56019 Mdot
.76562 .37289 Mdot
.60501 .50269 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{429.75, 265.625},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006]00012A000`40O003h00Oogoo[Woo003oOon^
Ool00?moojioo`00ogoo[Woo003oOon^Ool00?moojioo`00ogoo[Woo003oOom0Ool00fLiOomoo`1[
Ool00?mood1oo`03IcUoogoo06]oo`00ogoo?goo0fLiK7oo003oOoloOol3IcU/Ool00?moocmoo`AW
>F]oo`00ogoo?Woo1FLiJgoo003oOolnOol6IcUZOol00?moocioo`IW>FYoo`00ogoo?Goo1fLiJWoo
0035Ool2I1l5Ool2IcU^Ool8IcUYOol00<Aoo`AT7`03OomW>FLi00=W>Fioo`QW>FUoo`00a7oo16@O
1VLiKGoo2VLiJ7oo0033Ool2IcT2I1l7IcU]Ool:IcUXOol00<1oo`iW>Feoo`]W>FMoo`00`7oo3VLi
K7oo36LiIgoo0030Ool=IcU]Ool=IcUVOol00;moo`iW>Faoo`iW>FIoo`00_goo3VLiK7oo3VLiIWoo
002nOol?IcU/Ool>IcUVOol00;ioo`mW>F]oo`mW>FIoo`00_Goo46LiJgoo3fLiIWoo002mOol@IcU[
Ool>IcUWOol00;eoo`mW>F]oo`mW>FMoo`00_7oo46LiJgoo3fLiIgoo002lOol@IcU[Ool?IcUWOol0
0;]ooa5W>FYoo`mW>FQoo`00^goo4FLiJWoo3fLiJ7oo002jOolBIcUZOol?IcUXOol00;Yooa5W>FYo
oa1W>FQoo`00^Woo4fLiJ7oo3fLiJGoo002iOolEIcUWOol?IcUYOol00;UooaIW>FEooa1W>FUoo`00
^7oo4FLi0V@O1FLiI7oo3fLiJWoo002hOol@IcT4I1l5IcUROol@IcUZOol00;Mooa5W>@AT7`IW>F5o
oa1W>FYoo`00]goo4VLi0V@O26LiH7oo46LiJWoo002gOolNIcUMOol;IcT2I1l3IcU[Ool00;Eoo`9T
7amW>Eaoo`YW>@AT7`9W>F]oo`00]7oo16@O7fLiFgoo2VLi16@O0VLiJgoo002dOol4I1lPIcUIOol<
IcT2I1l3IcU[Ool00;Eoo`9T7b9W>BUoo`=W>Baooa1W>Faoo`00]7oo9VLi9Goo1VLi;7oo46LiK7oo
002dOolWIcTROol8IcT[OolAIcU/Ool00;=oobUW>Aioo`]W>B]ooa5W>Faoo`00WGoo@FLi6Woo0VLi
0a_P26Li:goo46LiKGoo002MOom2IcTFOol4IcT56n07IcTZOolAIcU]Ool009aoodAW>A9oo`MW>@DK
h0MW>BYooa5W>Feoo`00VgooAVLi3goo2FLi1A_P1fLi:Woo46LiKWoo002KOom7IcT;Ool=IcT36n08
IcTYOolAIcU^Ool009Yood1W>@9T7`MW>@QooaYW>BUooa5W>Fioo`00VGoo@6Li16@O1fLi17oo7FLi
:7oo4VLiKWoo002IOom0IcT4I1lXIcTROolGIcU_Ool009Qooc5W>@9T7`mW>@9T7b5W>B=ooaiW>Fmo
o`00Ugoo<FLi16@O>6Li5Goo9FLiKgoo002GOolaIcT4I1llIcT:Ool/IcU_Ool009Iooc=W>@9T7g9W
>G1oo`00UGooZ6LiL7oo002DOom4IcT2I1mSIcU`Ool009Aood=W>@AT7f5W>G5oo`00TgooA6Li16@O
HVLiL7oo002BOom6IcT2I1mSIcU`Ool0099oojaW>Fmoo`00TGoo[FLiKgoo002@Oon^IcU_Ool0091o
ojmW>Fioo`00Kgoo0a_P7Goo/6LiKWoo001^Ool56n04Ool6IcTAOonLIcT2I1lCIcU^Ool006ioo`DK
h003OomW>FLi00]W>@eooi]W>@AT7a=W>Feoo`00KWoo1A_P4FLi2GooW6Li16@O4fLiKGoo001^Ool0
16Li6n0Kh1_P5VLi17ooWVLi0V@O56LiKGoo001[OooFIcU/Ool006QoomUW>Faoo`00IGoofFLi0V@O
00=W>GooOol0JWoo001SOom;IcT2I1n=IcT4I1l00fLiOomoo`1YOol0061oodeW>@AT7bUW>@9T7baW
>@9T7c=W>@AT7`9W>FYoo`00GGooD6Li16@O:6Li16@O:VLi16@O<fLi0V@O16LiJGoo001JOomDIcT2
I1lYIcT4I1lZIcT4I1ljIcUXOol005Mooh=W>@9T7baW>@9T7c]W>FQoo`00@7oo2FLi2goolVLiIgoo
0010Ool:IcT2I1okIcUVOol0041oo`UW>@AT7o]W>FEoo`00@7oo2FLi16@OeVLi0V@O96LiI7oo000o
Ool;IcT2I1oFIcT4I1lSIcUTOol003ioonAW>@AT7bAW>F=oo`00?GooiVLi0V@O9VLiHWoo000kOoon
IcT2I1lAIcUQOol003YoooiW>@AT7a5W>F1oo`00>7oo0fLi0V@OnfLi16@O4FLiH7oo000gOol3IcT4
I1okIcT2I1lCIcUOOol003Ioo`AW>@AT7omW>A9W>Eioo`00=7oo1fLi0V@OofLi56LiGGoo000cOooo
IcTOIcULOol0035ooomW>B5W>Eaoo`00<7ooofLi2FLi0V@O6FLiFWoo000_OoooIcT9IcT4I1lJIcUH
Ool002eooomW>@]W>@AT7a]W>EMoo`00;7ooofLi3FLi0V@O7VLiEGoo000ZOoooIcT`IcUDOol002Uo
o`mW>@9T7omW>B9W>E9oo`009goo46Li16@OofLi8fLiD7oo000WOol@IcT4I1ooIcTTIcU?Ool002Mo
oa5W>@9T7omW>BMW>Deoo`009WooofLi?6LiC7oo000VOoooIcTlIcU<Ool002EooomW>CaW>Deoo`00
9GooofLi>fLiCWoo000UOoooIcTkIcU>Ool002AooomW>C]W>Dmoo`0097oohfLi0V@OE6LiD7oo000S
OooSIcT4I1mBIcUAOol002=oon=W>@AT7e]W>DQoo`008WooiFLi0V@OFVLiBWoo000ROoooIcU0IcU<
Ool0029oooEW>@<Kh4AW>Dmoo`008GoomFLi1A_PA6LiCWoo000QOooeIcT56n15IcT6Ool00fLiOomo
o`14Ool0021oooIW>@DKh4EW>Deoo`0087oomfLi0a_PAfLiC7oo000POoooIcTGIcT2I1lZIcT3Ool0
0fLiOomoo`15Ool001mooomW>AMW>@AT7bUW>D]oo`007goolVLi0V@O8VLi16@O:VLi00=oofLiOol0
Agoo000NOoobIcT4I1lRIcT2I1l[IcT00gooIcUoo`17Ool001iooo9W>@AT7diW>D]oo`007Goom6Li
0V@OCVLiC7oo000MOoooIcU3IcU>Ool001eooomW>D9W>Dmoo`0077ooofLi@VLi0Woo0VLiC7oo000L
OoooIcU1IcT017ooIcUW>FLiCGoo000KOoooIcU6IcU=Ool001]ooomW>DEW>@Ioo`03IcUoogoo04Eo
o`006Woo2VLi0V@OYFLi0V@OTVLi1Woo00=W>GooOol0AGoo000LOol7IcT4I1nSIcT4I1n@IcT8Ool0
0fLiOomoo`14Ool001eoo`IW>@AT7j=W>@AT7i1W>@Qoo`03IcUoogoo04Aoo`007goo1FLi0V@OYFLi
0V@OT6Li2Goo0VLiAGoo000POooaIcT2I1m:IcT9Ool2IcU5Ool0025oonmW>@AT7dQW>@Yoo`9W>DEo
o`0087ool6Li16@OB6Li2Woo0fLiA7oo000NOoocIcT2I1m8IcT6Ool016LiOomoogoo16LiA7oo000M
OoooIcU0IcT4Ool2IcT2Ool6IcU3Ool001]ooomW>D9W>@Aoo`9W>@9oo`IW>D=oo`006GooG6Li0V@O
iFLi0goo0fLi00=oofLiIcT01FLi@goo000HOomLIcT4I1oTIcT2Ool<IcU3Ool001IoodeW>@9T7`mW
>@AT7kYW>@9T7bQW>@9oo`aW>D=oo`005GooCFLi16@O3fLi0V@O^VLi16@O9fLi00=oofLiIcT02fLi
@goo000COom?IcT4I1maIcT36n1GIcT4I1leIcU3Ool0015ooe9W>@9T7aMW>@9T7eQW>@DKh5MW>@9T
7cEW>DAoo`004Goo0fLi0V@OIFLi16@OEfLi1A_PH6Li0a_P86Li0V@O2FLi0goo00=W>GooOol0?Woo
000AOol2IcT4I1mTIcT4I1mGIcT56n1OIcT56n0NIcT4I1l8IcT3Ool00fLiOomoo`0nOol0015oo`9W
>@AT7fEW>@9T7eUW>@<Kh61W>@DKh1iW>@AT7`QW>@=oo`03IcUoogoo03ioo`004Goo0fLi0V@O5VLi
0V@OofLi3FLi1A_P7fLi0V@O2FLi0goo00=W>GooOol0?Woo000AOolJIcT4I1ooIcT=IcT36n0ZIcT4
Ool2IcToOol0015ooaYW>@AT7omW>AUW>@9T7amW>@=oo`=W>Cmoo`004Goo6fLi0V@OofLi6FLi16@O
7VLi0goo0fLi?goo000AOoooIcTfIcT4I1lNIcT3Ool3IcToOol0015ooomW>CMW>@9T7aiW>@Aoo`AW
>Cioo`004GooofLi1VLi0V@O8fLi0V@O;6Li0Woo16Li?Woo000@OoooIcT6IcT4I1l6IcT2I1lIIcT4
I1laIcTnOol0011ooomW>@IW>@AT7`EW>@AT7aQW>@AT7c5W>Cioo`0047ooofLi1fLi0V@O1VLi16@O
6FLi0V@O1FLi0a_P2FLi0a_P7fLi?Goo000@OoooIcT@IcT2I1lPIcT56n07IcT56n0NIcTmOol0011o
oomW>C9W>@DKh0MW>@DKh1iW>Ceoo`0047ooofLi<VLi1A_P1fLi1A_P7VLi?Goo000@OoooIcTcIcT3
6n09IcT36n0OIcTmOol0011ooomW>F9W>Caoo`0047ooofLiHfLi>goo000@OoooIcUTIcTjOol0011o
omiW>@9T7aiW>@9T7fAW>CUoo`003googVLi16@O76Li16@OHfLi>Goo000?OooNIcT4I1lLIcT4I1mX
IcTdOol000moommW>@9T7aIW>@9T7`IW>@9T7feW>C1oo`003goomVLi16@ON6Li;7oo000?OoofIcT4
I1mkIcTYOol000moom]W>@9T7aYW>@9T7giW>BMoo`003goofVLi16@O7VLi0a_PNFLi9Woo000?OooJ
IcT4I1lMIcT56n1hIcTVOol000moom]W>@9T7aiW>@DKh2EW>@=ooe1W>BIoo`003goonfLi1A_P9FLi
1GooCVLi9Woo000>OoomIcT36n0VIcT7Oom<IcTVOol000mooomW>BIW>@UoodYW>BIoo`003gooofLi
9VLi2gooB6Li9Woo000?Ool4IcT2I1ooIcTMIcT2I1l00fLiOomoo`0;OoleIcT2I1l00a_PIcUW>@0=
IcTUOol000moo`=W>@AT7omW>A]W>@AT7`mooc9W>@AT7`036n1W>FLi00aW>BEoo`003goo0fLi16@O
ofLi6fLi16@O4Goo<6Li16@O00<Kh6LiIcT036Li9Goo000?Ool4IcT2I1ooIcTMIcT2I1l00fLiOomo
o`0AOol^IcT00a_PI1mT7`026n0>IcTUOol000mooomW>BMW>AAoobeW>@<Kh0mW>BEoo`003gooofLi
9fLi5Woo?FLi9Goo000?OoooIcTXIcTGOol2IcT2I1lgIcTUOol000mooomW>BQW>AQoo`AT7beW>@9T
7`QW>BAoo`003gooofLi:6Li67oo16@O;6Li16@O1fLi97oo000?OoooIcTXIcTHOol00fLiI1mT7`0]
IcT4I1l7IcTTOol000mooomW>BQW>AQooc5W>@9T7`YW>B9oo`003gooofLi:6Li67oo4FLi0V@O:fLi
8Goo000?OoooIcTWIcTKOol>IcT4I1l[IcTPOol000moomUW>@9T7d]W>Aeoo`aW>@AT7baW>Amoo`00
3goof6Li16@OBVLi7goo2fLi0V@O;VLi7Woo000?OooHIcT4I1m9IcTROoljIcTMOol000moomUW>@9T
7dYW>B=oocYW>Aaoo`003gooofLi9VLi9Goo>VLi6Woo000?OoooIcTUIcTXOoliIcTIOol000mooomW
>BEW>BYoocQW>AQoo`003gooofLi9FLi:goo>6Li5goo000?OoooIcTTIcT^OolgIcTFOol000mooomW
>BAW>C1oocIW>AEoo`003gooofLi96Li<Woo=FLi57oo000?OoooIcTSIcTdOolfIcTBOol000mooomW
>B=W>CQooc=W>A5oo`003gooofLi8fLi>goo<FLi47oo000?OoocIcT2I1l/IcU0Ool^IcT?Ool000mo
oo9W>@AT7b]W>D=oobaW>@ioo`003goolVLi16@O:fLiAWoo:VLi3Goo000?OoocIcT2I1l[IcUEOolM
IcT<Ool000mooomW>B5W>EIooaeW>@]oo`003gooofLi8FLiEgoo76Li2goo000?OoooIcTPIcUIOolJ
IcT<Ool000mooomW>B1W>EYooaUW>@aoo`003gooofLi86LiFWoo66Li3Goo000?OoooIcTOIcULOolF
IcT>Ool000mooomW>AmW>EaooaIW>@ioo`003gooofLi7fLiGGoo56Li3goo000?OoooIcTNIcUNOolC
IcT@Ool000mooomW>AiW>Emooa9W>A1oo`003gooofLi7VLiH7oo46Li4Goo000?OoooIcTMIcUQOol@
IcTAOol000mooomW>AYW>@9T7`03IcUoogoo061oo`iW>A9oo`003gooofLi6FLi16@OHWoo3FLi4goo
000?OoooIcTIIcT4I1mSOol<IcTCOol000mooomW>AYW>@9T7fAoo`]W>AAoo`003gooofLi66LiJGoo
2FLi5Goo000>OoooIcTFIcU]Ool8IcTEOol000iooomW>AAW>Fmoo`MW>AIoo`003WooofLi4FLiLgoo
1VLi5Woo000>Ool;IcT2I1ooIcT2IcUeOol5IcTGOol000eoo`]W>@AT7oeW>GUoo`=W>AQoo`003Goo
2fLi16@OnfLiNgoo0fLi67oo000=Ool<IcT2I1ojIcUnOol00fLiOomoo`0GOol000eooomW>@IW>I]o
o`003GooofLi16LiWGoo000<OoooIcT2IcVPOol000aoo`iW>@<Kh>iW>J9oo`0037oo3FLi1A_PjVLi
YGoo000<Ool=IcT56n3XIcVWOol000]oo`iW>@DKh>EW>JYoo`002goo3fLi0a_PhFLi[goo000;Ool9
IcT4OooQIcVdOol000]oo`AW>@Uoog9W>@9T7fMW>KYoo`0067ooLFLi16@OHFLi_goo000HOomaIcT4
I1mKIcW5Ool001Qoog9W>@9T7eMW>LYoo`0067ooaVLicgoo000HOoo0IcWEOol001Qook]W>MYoo`00
67oo]FLih7oo003oOon^Ool00?moojioo`00ogoo[Woo003oOon^Ool00?moojioo`00ogoo[Woo0000
\
\>"],
  ImageRangeCache->{{{0, 428.75}, {264.625, 0}} -> {-126.196, 24.5194, \
0.141048, 0.0947664}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Shipments", "Subsection",
  CellTags->"Transport"],

Cell[BoxData[
    \(Off[General::spell1]\)], "Input",
  CellTags->"Transport"],

Cell[BoxData[
    \(TransportationProblem[costs_, supplies_, 
        demands_] := \n\ \ Module[{c, b, n, m, sbase, dbase, sconstraints, 
          dconstraints, a}, \n\ \ \ \ c\  = \ 
          Flatten[costs]; \n\ \ \ \ b\  = \ 
          Join[\(-supplies\), demands]; \n\ \ \ \ n\  = \ 
          Length[supplies]; \n\ \ \ \ m\  = \ 
          Length[demands]; \n\ \ \ \ sbase\  = \ 
          Join[Table[\(-1\), {m}], 
            Table[0, {m*\((n - 1)\)}]]; \ \n\ \ \ \ dbase\  = 
          Flatten[\ 
            Table[Join[{1}, 
                Table[0, {m - 1}]], {n}]]; \ \n\ \ \ \ sconstraints\  = \ 
          Table[RotateRight[sbase, \ m*i], {i, 0, 
              n - 1}]; \n\ \ \ \ dconstraints\  = \ 
          Table[RotateRight[dbase, \ i], {i, 0, m - 1}]; \n\ \ \ \ a\  = \ 
          Join[sconstraints, dconstraints]; \n\ \ \ \ Partition[
          LinearProgramming[c, \ a, \ b], \ m]\n\ \ ]\)], "Input",
  CellTags->"Transport"],

Cell[BoxData[
    \(CalculateDistances[s_, \ d_] := \ \n
      Table[\ Sqrt[\ \((s[\([i, 1]\)] - 
                  d[\([j, 1]\)])\)^2\  + \ \((s[\([i, 2]\)] - 
                  d[\([j, 2]\)])\)^2\ ], {i, 1, Length[s]}, {j, 1, 
          Length[d]}]\)], "Input",
  CellTags->"Transport"],

Cell[BoxData[
    \(\(Arcs[qarcs_, \ scoords_, \ dcoords_]\  := \n\ \ Graphics[
          Table[\n\t\tWith[{q = qarcs[\([i, j]\)], sxy = scoords[\([i]\)], 
                dxy = dcoords[\([j]\)]}, \n\ \ \ \ \ \ \ \ If[
                Chop[q] == 
                  0, \n\ \ \ \ \ \ \ \ \ \ {}, \n\t\ \ \ \ \ \ \ {Line[{sxy, \
\ dxy}]}\n\ \ \ \ \ \ \ \ ]], \n\ \ {i, 1, Length[scoords]}, {j, 1, 
              Length[dcoords]}]];\)\)], "Input",
  CellTags->"Transport"],

Cell[BoxData[
    \(TextCoord[{sx_, sy_}, {dx_, dy_}] := \ {\((sx + dx)\)/2, \((sy + dy)\)/
          2}\)], "Input",
  CellTags->"Transport"],

Cell[BoxData[
    \(\(TransportationArcs[supplycities_, 
          demandcities_] := \n\ \ Module[{s, d, scoords, dcoords, costs, 
            q}, \n\ \ \ \ s\  = 
            supplycities\  /. \ {city_String, state_, lat_, lon_, s_, d_} -> 
                s; \n\ \ \ \ d\  = 
            demandcities\  /. \ {city_String, state_, lat_, lon_, s_, d_} -> 
                d; \n\ \ \ \ scoords\  = 
            supplycities\  /. {city_String, state_, lat_, lon_, s_, 
                  d_} -> {lon, lat}; \n\ \ \ \ dcoords\  = \ 
            demandcities\  /. \ {city_String, state_, lat_, lon_, s_, 
                  d_} -> {lon, lat}; \n\ \ \ \ costs\  = \ 
            CalculateDistances[scoords, dcoords]; \n\ \ \ \ q\  = \ 
            TransportationProblem[costs, s, d]; \n\ \ \ Arcs[q, scoords, 
            dcoords]\ \n\ \ ];\)\)], "Input",
  CellTags->"Transport"],

Cell[CellGroupData[{

Cell[BoxData[
    \(shipments\  = \ 
      TransportationArcs[supplycities, demandcities]\)], "Input",
  CellTags->"Transport"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Results", "Section",
  CellTags->"Transport"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[borderpoly, shipments, supplypoints, demandpoints]\)], "Input",
  CellTags->"Transport"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.08891 0.0165583 -0.604284 0.024645 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.8 g
.14965 .1975 m
.14689 .209 L
.0917 .24761 L
.06079 .32031 L
.07845 .33264 L
.04064 .35523 L
.03264 .4308 L
.03457 .53637 L
.02381 .58853 L
.05637 .58278 L
.05113 .5569 L
.05637 .60291 L
.05665 .60332 L
.15103 .60332 L
.16759 .60332 L
.36684 .60332 L
.47944 .60332 L
.60556 .57867 L
.6958 .54253 L
.72423 .45586 L
.72036 .44436 L
.71954 .423 L
.78218 .4534 L
.7797 .45791 L
.7797 .46202 L
.83379 .49201 L
.87436 .50515 L
.90499 .50515 L
.91189 .51213 L
.94252 .56553 L
.97619 .50926 L
.91741 .45709 L
.9163 .45216 L
.91134 .41889 L
.91106 .41848 L
.91134 .41889 L
.89919 .41396 L
.86939 .40616 L
.85945 .39425 L
.84952 .35564 L
.84648 .38151 L
.83986 .37659 L
.84648 .34331 L
.84096 .33264 L
.8313 .31087 L
.83627 .3314 L
.82661 .34496 L
.83324 .37125 L
.82523 .33346 L
.81364 .35194 L
.81281 .3544 L
.81171 .33633 L
.82606 .30963 L
.80923 .31538 L
.83296 .29649 L
.83848 .27759 L
.83158 .3006 L
.81833 .2817 L
.83462 .27349 L
.81309 .27143 L
.82496 .25541 L
.78825 .23036 L
.74962 .18477 L
.73941 .15273 L
.76369 .05579 L
.74631 .01472 L
.70325 .13301 L
.63978 .14205 L
.62515 .14451 L
.60666 .13958 L
.59148 .13876 L
.60915 .1363 L
.60832 .10878 L
.53574 .13506 L
.53601 .13465 L
.4742 .08249 L
.48054 .03566 L
.44826 .04634 L
.41928 .1174 L
.36602 .11863 L
.32517 .17901 L
.28322 .16792 L
.18939 .20202 L
.14965 .1975 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.26197 .17409 m
.17366 .20448 L
s
.26197 .17409 m
.13861 .22255 L
s
.26197 .17409 m
.27412 .34701 L
s
.26197 .17409 m
.233 .35112 L
s
.62626 .42464 m
.63316 .40821 L
s
.62626 .42464 m
.61356 .41396 L
s
.62626 .42464 m
.64999 .38275 L
s
.62626 .42464 m
.54843 .423 L
s
.62626 .42464 m
.55809 .40862 L
s
.62626 .42464 m
.54319 .47147 L
s
.62626 .42464 m
.60501 .50269 L
s
.50538 .35851 m
.29178 .35974 L
s
.50538 .35851 m
.47585 .3236 L
s
.50538 .35851 m
.3249 .58894 L
s
.50538 .35851 m
.47116 .14246 L
s
.50538 .35851 m
.40907 .19175 L
s
.50538 .35851 m
.42425 .10713 L
s
.50538 .35851 m
.51145 .19298 L
s
.50538 .35851 m
.27412 .34701 L
s
.58762 .12315 m
.47171 .09481 L
s
.58762 .12315 m
.51007 .13424 L
s
.58762 .12315 m
.46261 .04141 L
s
.87518 .44148 m
.87518 .44148 L
s
.87518 .44148 m
.89616 .45627 L
s
.87518 .44148 m
.82137 .46695 L
s
.75376 .39096 m
.71429 .44107 L
s
.75376 .39096 m
.69194 .54088 L
s
.75376 .39096 m
.76562 .37289 L
s
.78356 .38932 m
.81944 .36139 L
s
.78356 .38932 m
.78522 .45381 L
s
.65358 .28581 m
.69663 .1745 L
s
.65358 .28581 m
.68035 .20941 L
s
.65358 .28581 m
.6395 .33346 L
s
.65358 .28581 m
.64033 .29936 L
s
.65358 .28581 m
.61936 .19257 L
s
.65358 .28581 m
.6166 .27308 L
s
.65358 .28581 m
.51007 .13424 L
s
.65358 .28581 m
.50676 .15273 L
s
.65358 .28581 m
.51145 .19298 L
s
.0641 .57662 m
.08535 .3236 L
s
.0641 .57662 m
.13337 .24925 L
s
.0641 .57662 m
.04892 .36057 L
s
.0641 .57662 m
.1055 .36919 L
s
.0641 .57662 m
.04699 .44148 L
s
.0641 .57662 m
.233 .35112 L
s
.0641 .57662 m
.06051 .56019 L
s
.7383 .36344 m
.74299 .10467 L
s
.7383 .36344 m
.69663 .1745 L
s
.7383 .36344 m
.73168 .21804 L
s
.7383 .36344 m
.74437 .18764 L
s
.7383 .36344 m
.67124 .38398 L
s
.7383 .36344 m
.64999 .38275 L
s
.7383 .36344 m
.73803 .38316 L
s
.7383 .36344 m
.71595 .35071 L
s
.7383 .36344 m
.7292 .23775 L
s
.7383 .36344 m
.7245 .29485 L
s
.2 1 0 r
5 Mabswid
.26197 .17409 Mdot
.62626 .42464 Mdot
.50538 .35851 Mdot
.58762 .12315 Mdot
.87518 .44148 Mdot
.75376 .39096 Mdot
.78356 .38932 Mdot
.65358 .28581 Mdot
.0641 .57662 Mdot
.7383 .36344 Mdot
.8 0 1 r
4 Mabswid
.17366 .20448 Mdot
.13861 .22255 Mdot
.08535 .3236 Mdot
.13337 .24925 Mdot
.04892 .36057 Mdot
.29178 .35974 Mdot
.74299 .10467 Mdot
.69663 .1745 Mdot
.73168 .21804 Mdot
.68035 .20941 Mdot
.74437 .18764 Mdot
.63316 .40821 Mdot
.61356 .41396 Mdot
.67124 .38398 Mdot
.64999 .38275 Mdot
.6395 .33346 Mdot
.54843 .423 Mdot
.55809 .40862 Mdot
.47585 .3236 Mdot
.64033 .29936 Mdot
.81944 .36139 Mdot
.87518 .44148 Mdot
.71429 .44107 Mdot
.69194 .54088 Mdot
.54319 .47147 Mdot
.61936 .19257 Mdot
.3249 .58894 Mdot
.1055 .36919 Mdot
.89616 .45627 Mdot
.78522 .45381 Mdot
.82137 .46695 Mdot
.73803 .38316 Mdot
.71595 .35071 Mdot
.04699 .44148 Mdot
.7292 .23775 Mdot
.7245 .29485 Mdot
.6166 .27308 Mdot
.47116 .14246 Mdot
.47171 .09481 Mdot
.40907 .19175 Mdot
.42425 .10713 Mdot
.51007 .13424 Mdot
.50676 .15273 Mdot
.46261 .04141 Mdot
.51145 .19298 Mdot
.27412 .34701 Mdot
.233 .35112 Mdot
.06051 .56019 Mdot
.76562 .37289 Mdot
.60501 .50269 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{410.563, 253.75},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006J0000oA000`40O003h00OogooVgoo003oOonK
Ool00?mooi]oo`00ogooVgoo003oOonKOol00?mooi]oo`00ogooVgoo003oOolbOol00fLiOomoo`1V
Ool00?mooc9oo`03IcUoogoo06Ioo`00ogoo<Goo0fLiIgoo003oOolaOol3IcUWOol00?mooc5oo`AW
>FIoo`00ogoo<7oo1FLiIWoo003oOol`Ool5IcUVOol00?moobmoo`MW>FEoo`00_7oo0V@O17oo0VLi
JWoo1fLiIGoo002kOol4I1l5IcUZOol8IcUTOol00;]oo`AT7`EW>FUoo`UW>FAoo`00^Woo0VLi0V@O
0P0016LiJGoo2FLiI7oo002gOol9IcT01000IcUW>FLiJGoo2VLiHgoo002gOol:IcT200000fLiOomo
o`1VOol;IcUSOol00;Moo`aW>@03001oogoo06Ioo`aW>F9oo`00]Woo3VLi0P00IGoo3FLiHWoo002f
Ool>IcT2Ool2001SOol=IcUROol00;Eoo`iW>@Eoo`03001oogoo061oo`eW>F9oo`00]Goo3VLi1Woo
0P00Ggoo3VLiHWoo002eOol>IcT8Ool00`00Oomoo`1LOol>IcUROol00;Aoo`mW>@Uoo`8005aoo`eW
>F=oo`00]7oo3fLi2goo00<007ooOol0F7oo3VLiHgoo002cOol@IcT<Ool2001HOol>IcUSOol00;=o
oa1W>@ioo`03001oogoo05Aoo`mW>F=oo`00/goo46Li3goo0P00E7oo3VLiI7oo002bOolAIcTAOol0
0`00Oomoo`1AOol>IcUTOol00;9ooa1W>A=oo`80051oo`mW>FAoo`00/Goo4fLi4goo0P00CWoo3fLi
I7oo002aOolDIcTDOol00`00Oomoo`1;Ool>IcUUOol00;1ooaIW>AAoo`8004Yoo`mW>FEoo`00/7oo
46Li0V@O1FLi5Goo00<007ooOol0Agoo3fLiIGoo002`Ool?IcT4I1l5IcTEOol20016Ool@IcUUOol0
0:mooa1W>@AT7`03001W>FLi00=W>AIoo`03001oogoo04=oo`mW>FIoo`00[goo4FLi0V@O0VLi1000
0VLi5Woo0P00@goo3fLiIWoo002^OolJIcT4000FOol00`00Oomoo`0oOol;IcT2I1l3IcUVOol00:eo
o`9T7aeW>@@001=oo`8003moo`YW>@AT7`9W>FIoo`00[7oo16@O7VLi0Woo1@0047oo00<007ooOol0
?7oo2VLi16@O00=W>GooOol0IGoo002/Ool4I1lOIcT6Ool4000=Ool2000kOol<IcT2I1l2IcUWOol0
0:eoo`9T7b5W>@Uoo`@000]oo`8000eoo`9W>BYoo`eW>@03001W>FLi06Moo`00[7oo0VLi00<006Li
IcT086Li37oo1@0027oo00<007ooOol01goo1FLi:Goo3VLi00<006LiIcT0Igoo002/Ool2IcT00`00
IcUW>@0QIcT@Ool40005Ool20004Ool8IcTYOol>IcT00`00IcUoo`1WOol00:]oo`=W>@03001W>FLi
02=W>A9oo`@000=oo`03001ooa_P008Kh0MW>BUoo`iW>@03001W>Goo06Moo`00UGoo6VLi00<006Li
IcT08fLi5Goo10001A_P1VLi:7oo3fLi00<006LiOol0Igoo002DOolKIcT00`00IcUW>@0TIcTCOol4
IcT00`006n0Kh0036n06IcTXOol?IcT00`00IcUoo`1WOol009Aooa]W>@03001W>FLi02EW>@moo`03
IcT0000000@00003IcTKh1_P00<Kh0IW>BQoo`mW>@03001oogoo06Moo`00Tgoo7FLi00<006LiIcT0
9FLi2Goo1P0026Li0a_P1fLi9goo46Li00<007ooOol0Igoo002BOolNIcT00`00IcUW>@0MIcT2I1l7
IcT00goo00000005000HIcTWOol@IcT00`00Oomoo`1WOol0099ooaiW>@03001W>FLi01aW>@AT7`03
IcT0000000@000Aooa]W>BIooa5W>@03001oogoo06Moo`00TGoo86Li00<006LiIcT06fLi16@O00<0
06LiIcT08fLi87oo5fLi00<007ooOol0Igoo002@OolQIcT00`00IcUW>@0LIcT2I1lPIcTPOolNIcT0
0`00Oomoo`1WOol0091oob5W>@03001W>FLi00aW>@9T7a1W>@03001W>FLi02=W>AAoobAW>@03001o
ogoo06Moo`00Sgoo8fLi00<006LiIcT02VLi16@O46Li00<006LiIcT09VLi2Goo:fLi00<007ooOol0
Igoo002>OolTIcT00`00IcUW>@0:IcT4I1lAIcT00`00IcUW>@1HIcT00goo001oo`1XOol008ioobAW
>@03001W>FLi00]W>@9T7a=W>@03001W>FLi05MW>@03Ool007oo06Qoo`00SGoo9FLi00<006LiIcT0
2fLi00<006LiIcT036Li0V@O1FLi00<006LiIcT0EVLi00=oo`00Ool0J7oo002=OolVIcT00`00IcUW
>@0;IcT00`00IcUW>@0:IcT4I1l5IcT00`00IcUW>@1DIcT2Ool00`00Oomoo`1WOol008aoobMW>@03
001W>FLi00]W>@03001W>FLi00YW>@AT7`IW>@03001W>FLi05AW>@03Ool007oo06Qoo`00Rgoo:6Li
00<006LiIcT02fLi00<006LiIcT02fLi0V@O00<006LiIcT01FLi00<006LiIcT0DfLi00=oo`00Ool0
J7oo002;OolYIcT00`00IcUW>@0:IcT00`00IcUW>@0>IcT00`00IcUW>@05IcT00`00IcUW>@1BIcT0
0goo001oo`1XOol008YoobYW>@03001W>FLi00YW>@03001W>FLi00mW>@03001W>FLi00AW>@03001W
>FLi05=W>@03001oogoo06Moo`00RGoo:fLi00<006LiIcT02VLi00<006LiIcT046Li00<006LiIcT0
16Li00<006LiIcT0DVLi00<007ooOol0Igoo0029Ool/IcT00`00IcUW>@0:IcT00`00IcUW>@0@IcT2
0005IcT00`00IcUW>@1AIcT00`00Oomoo`1WOol006Yoo`<Kh0Eoo`IW>A1oobeW>@03001W>FLi00YW
>@03001W>FLi019W>@03001W>FLi00=W>@03001W>FLi051W>@03001oogoo06Moo`00JGoo1A_P00=o
ofLiIcT02VLi37oo;VLi00<006LiIcT02VLi00<006LiIcT04fLi00<006LiIcT00fLi00<006LiIcT0
>fLi0V@O4FLi00<006LiOol0J7oo001YOol56n0AIcT8Ool_IcT00`00IcUW>@09IcT00`00IcUW>@0D
IcT00`00IcUW>@03IcT00`00IcUW>@0iIcT4I1l@IcT00`00IcUoo`1XOol006Moo`8000DKh1AW>@Ao
oc1W>@03001W>FLi00UW>@03001W>FLi01EW>@03001W>FLi00=W>@03001W>FLi03QW>@AT7a1W>@03
001W>FLi06Qoo`00I7oo10000VLi0a_PBFLi00<006LiIcT02FLi00<006LiIcT05VLi00<006LiIcT0
0fLi00<006LiIcT0>6Li0V@O4FLi00<006LiIcT0J7oo001QOol40005IcT2001;IcT00`00IcUW>@09
IcT00`00IcUW>@0FIcT00`00IcUW>@03IcT00`00IcUW>@0gIcT00`00IcT0000@IcT00`00IcUW>@1X
Ool005ioo`D000MW>@8004]W>@03001W>FLi00UW>@03001W>FLi01MW>@03001W>FLi00=W>@03001W
>FLi03EW>@04001W>FLi000@IcT00`00I1mT7`1XOol005]oo`D000YW>@8004]W>@03001W>FLi00UW
>@03001W>FLi01QW>@03001W>FLi00=W>@03001W>FLi03AW>@04001W>FLi000@IcT4I1mWOol005Qo
o`D000eW>@8003]W>@9T7`mW>@03001W>FLi00QW>@03001W>FLi00YW>@9T7`eW>@03001W>FLi00=W
>@03001W>FLi01EW>@9T7aaW>@04001W>FLi000@IcT4I1l00fLiOomoo`1TOol005Eoo`H000mW>@80
03YW>@AT7`iW>@03001W>FLi00QW>@03001W>FLi00UW>@AT7`eW>@03001W>FLi00=W>@03001W>FLi
01=W>@AT7aYW>@03001W>FLi009W>@03001W>FLi00eW>@03001T7f@O00=W>FEoo`00DWoo0`0000=o
o`0000004VLi00<006Li0000>FLi16@O3VLi00<006LiIcT026Li00<006LiIcT02FLi16@O3VLi0P00
16Li00<006LiIcT04VLi16@O6VLi00<006LiIcT00VLi00<006LiIcT03FLi0P001FLiI7oo001?Ool3
000017oo000000004fLi00@006LiIcT003YW>@9T7a1W>@03001W>FLi00MW>@03001W>FLi00YW>@9T
7`8000mW>@03001W>FLi009W>@03001W>FLi019W>@9T7aYW>@03001W>FLi00=W>@03001W>FLi00eW
>@8000IW>F=oo`00C7oo0`0000AoofLi000001IW>@04001W>FLi000lIcT00`00IcUW>@0=IcT00`00
IcUW>@08IcT00`00IcUW>@0:IcT01000IcUW>@003fLi00<006LiIcT00VLi00<006LiIcT04VLi00<0
06LiIcT066Li00<006LiIcT00fLi00<006LiIcT03FLi0P001fLiHWoo000mOol9IcT2I1l016Li0000
00000VLi0`0066Li00@006LiIcT003aW>@03001W>FLi00eW>@03001W>FLi00QW>@03001W>FLi00YW
>@04001W>FLiIcT2000>IcT00`00IcUW>@02IcT00`00IcUW>@0AIcT00`00IcUW>@0HIcT00`00IcUW
>@03IcT00`00IcUW>@0=IcT20007IcUROol003eoo`QW>@AT7`=W>@8001]W>@04001W>FLi000mIcT0
0`00IcUW>@0=IcT00`00IcUW>@07IcT00`00IcUW>@0:IcT00`00IcUW>@03IcT00`00IcUW>@0<IcT0
0`00IcUW>@02IcT00`00IcUW>@0@IcT00`00IcUW>@0GIcT00`00IcUW>@05IcT00`00IcUW>@0<IcT2
0008IcUQOol003eoo`QW>@AT7`<001eW>@04001W>FLi000mIcT00`00IcUW>@0=IcT00`00IcUW>@07
IcT00`00IcUW>@0:IcT00`00IcUW>@04IcT2000=IcT00`00IcUW>@02IcT00`00IcUW>@0@IcT00`00
IcUW>@0DIcT2I1l00`00IcUW>@05IcT00`00IcUW>@0<IcT20009IcUPOol003aoo`YW>@9T7`03001W
>FLi01iW>@04001W>FLi000nIcT00`00IcUW>@0<IcT00`00IcUW>@07IcT00`00IcUW>@0:IcT00`00
IcUW>@06IcT00`00IcUW>@0;IcT00`00IcUW>@02IcT00`00IcUW>@0?IcT00`00IcUW>@0CIcT4I1l7
IcT00`00IcUW>@0<IcT2000:IcUOOol003]oo`UW>@<0025W>@05001W>FLiIcT0000oIcT00`00IcUW
>@0<IcT00`00IcUW>@06IcT00`00IcUW>@0:IcT00`00IcUW>@07IcT2000<IcT01@00IcUW>FLi0000
4VLi00<006LiIcT04VLi16@O1fLi00<006LiIcT036Li0P002fLiGWoo000jOol7IcT3000TIcT01@00
IcUW>FLi0000?fLi00<006LiIcT036Li00<006LiIcT01fLi00<006LiIcT02FLi00<006LiIcT02FLi
00<006LiIcT02VLi00D006LiIcUW>@00015W>@03001W>FLi019W>@03001T7f@O00UW>@03001W>FLi
00MW>@9T7`9W>@8000aW>Eeoo`00>7oo1fLi0P009fLi00D006LiIcUW>@00041W>@03001W>FLi00]W
>@03001W>FLi00MW>@03001W>FLi00UW>@03001W>FLi00YW>@8000]W>@05001W>FLiIcT0000@IcT0
0`00IcUW>@0BIcT2000:IcT00`00IcUW>@06IcT4I1l00fLi0000000<IcUMOol003Moo`03IcUT7f@O
009W>@<002UW>@05001W>FLiIcT00010IcT00`00IcUW>@0<IcT00`00IcUW>@06IcT00`00IcUW>@09
IcT00`00IcUW>@0<IcT2000:IcT01@00IcUW>FLi000046Li00<006LiIcT04FLi0P002VLi00<006Li
IcT01VLi16@O00=W>@0000003FLiG7oo000eOol2IcT4I1l00`00IcUW>@0ZIcT01@00IcUW>FLi0000
@FLi00<006LiIcT02fLi00<006LiIcT01VLi00<006LiIcT02FLi00<006LiIcT03VLi00<006LiIcT0
26Li0P000VLi00<006LiIcT03FLi00<006LiIcT046Li00<006Li00002VLi00<006LiIcT01fLi0V@O
0VLi0P003VLiFgoo000dOol3IcT4I1l]IcT01@00IcUW>FLi0000@FLi00<006LiIcT02fLi00<006Li
IcT01VLi00<006LiIcT026Li00<006LiIcT046Li0P002VLi00@006LiIcT000iW>@03001W>FLi011W
>@8000]W>@03001W>FLi00MW>@04001W>FLiIcT2000?IcUJOol0039oo`IW>@9T7beW>@03001W>FLi
009W>@03001W>FLi041W>@03001W>FLi00]W>@03001W>FLi00EW>@03001W>FLi00QW>@03001W>FLi
019W>@03001W>FLi00QW>@04001W>FLi000>IcT00`00IcUW>@0?IcT2000<IcT00`00IcUW>@06IcT0
1000IcUW>FLi0P0046LiFGoo000aOolfIcT00`00IcUW>@03IcT00`00IcUW>@10IcT00`00IcUW>@0:
IcT00`00IcUW>@06IcT00`00IcUW>@07IcT00`00IcUW>@0CIcT20009IcT01000IcUW>@003FLi00<0
06LiIcT03VLi0P003FLi00<006LiIcT01VLi00@006LiIcUW>@80015W>EQoo`00<7oo=fLi00<006Li
IcT00fLi00<006LiIcT0@6Li00<006LiIcT02VLi00<006LiIcT01VLi00<006LiIcT01fLi00<006Li
IcT05FLi00<006LiIcT01fLi00@006LiIcT000eW>@03001W>FLi00eW>@8000eW>@03001W>FLi00IW
>@05001W>FLiIcT0000BIcUHOol002ioocUW>@03001W>FLi00=W>@03001W>FLi045W>@03001W>FLi
00UW>@03001W>FLi00IW>@03001W>FLi00MW>@03001W>FLi01IW>@8000QW>@04001W>FLi000<IcT0
0`00IcUW>@0=IcT2000=IcT00`00IcUW>@05IcT2I1l3IcT00`00IcUW>@0BIcUFOol002eoocYW>@03
001W>FLi00=W>@03001W>FLi045W>@03001W>FLi00YW>@03001W>FLi00EW>@03001W>FLi00MW>@03
001W>FLi01QW>@03001W>FLi00IW>@04001W>FLi000;IcT00`00IcUW>@0<IcT2000?IcT00`00IcUW
>@03IcT4I1l2IcT00`00IcUW>@0CIcUEOol002]oocaW>@03001W>FLi00=W>@03001W>FLi049W>@03
001W>FLi00UW>@03001W>FLi00EW>@03001W>FLi00MW>@03001W>FLi01UW>@8000MW>@04001W>FLi
000;IcT00`00IcUW>@0;IcT2000?IcT00`00IcUW>@03IcT4I1l2IcT00`00IcUW>@0EIcUCOol002Yo
ocaW>@03001W>FLi00AW>@03001W>FLi049W>@03001W>FLi00UW>@03001W>FLi00EW>@03001W>FLi
00MW>@03001W>FLi01]W>@03001W>FLi00EW>@04001W>FLi000:IcT00`00IcUW>@0;IcT00`00IcUW
>@0>IcT00`00IcUW>@04IcT2I1l3IcT00`00IcUW>@0FIcUBOol002QoociW>@03001W>FLi00AW>@03
001W>FLi04=W>@03001W>FLi00UW>@03001W>FLi00EW>@03001W>FLi00IW>@03001W>FLi01aW>@80
00IW>@04001W>FLi0009IcT00`00IcUW>@0:IcT2000@IcT00`00IcUW>@04IcT00`00IcT00002IcT0
0`00IcUW>@0HIcU@Ool002Moo`mW>@9T7biW>@03001W>FLi00AW>@03001W>FLi04AW>@03001W>FLi
00QW>@03001W>FLi00EW>@03001W>FLi00IW>@03001W>FLi01iW>@03001W>FLi00AW>@04001W>FLi
0009IcT00`00IcUW>@09IcT2000@IcT00`00IcUW>@04IcT00`00IcT00002IcT00`00IcUW>@0IIcU?
Ool002Eooa1W>@AT7beW>@03001W>FLi00AW>@03001W>FLi04AW>@03001W>FLi00QW>@03001W>FLi
00EW>@03001W>FLi00IW>@03001W>FLi01mW>@8000EW>@800003IcT006Li00MW>@03001W>FLi00QW
>@80019W>@03001W>FLi00=W>@03001W>@00009W>@03001W>FLi01]W>Deoo`009Goo46Li16@O;FLi
00<006LiIcT016Li00<006LiIcT0AFLi00<006LiIcT026Li00<006LiIcT016Li00<006LiIcT01VLi
00<006LiIcT08FLi00<006LiIcT016Li00<006Li00001fLi00<006LiIcT026Li0P004VLi00<006Li
IcT00fLi00<006Li00000VLi00<006LiIcT076LiC7oo000UOolAIcT2I1l^IcT00`00IcUW>@04IcT0
0`00IcUW>@15IcT00`00IcUW>@08IcT00`00IcUW>@04IcT00`00IcUW>@06IcT00`00IcUW>@0RIcT2
0005IcT00`00IcT00007IcT00`00IcUW>@07IcT00`00IcUW>@0AIcT00`00IcUW>@03IcT00`00IcT0
0002IcT00`00IcUW>@0NIcU:Ool002Aooa9W>@03001W>FLi02aW>@03001W>FLi00EW>@03001W>FLi
04IW>@03001W>FLi00MW>@03001W>FLi00AW>@03001W>FLi00IW>@03001W>FLi02AW>@03001W>FLi
00=W>@03001W>@0000IW>@03001W>FLi00IW>@8001=W>@03001W>FLi00AW>@80009W>@03001W>FLi
01mW>DUoo`0097oo4FLi00<006LiIcT0;FLi00<006LiIcT01FLi00<006LiIcT0AVLi00<006LiIcT0
26Li00<006LiIcT00fLi00<006LiIcT01VLi00<006LiIcT09FLi0P0016Li00<006Li00001VLi00<0
06LiIcT01FLi0P0056Li00<006LiIcT00fLi0P000VLi00<006LiIcT07fLiBGoo000SOolBIcT00`00
IcUW>@0]IcT00`00IcUW>@05IcT00`00IcUW>@17IcT00`00IcUW>@07IcT00`00IcUW>@04IcT00`00
IcUW>@05IcT00`00IcUW>@0WIcT00`00IcUW>@02IcT00`00IcT00005IcT00`00IcUW>@05IcT00`00
IcUW>@0CIcT00`00IcUW>@03IcT20002IcT00`00IcUW>@0NIcU:Ool002=ooa9W>@03001W>FLi02eW
>@03001W>FLi00IW>@03001W>FLi04MW>@03001W>FLi00IW>@03001W>FLi00AW>@03001W>FLi00EW
>@03001W>FLi02QW>@8000=W>@8000EW>@03001W>FLi00AW>@8001EW>@03001W>FLi00=W>@80009W
>@03001W>FLi01eW>D]oo`008goo4VLi00<006LiIcT0;FLi00<006LiIcT01VLi00<006LiIcT0AfLi
00<006LiIcT01fLi00<006LiIcT00fLi00<006LiIcT01FLi00<006LiIcT0:VLi0P000VLi0P001FLi
00<006LiIcT00fLi0P005FLi00<006LiIcT00fLi0P000VLi00<006LiIcT07FLiBgoo000ROolCIcT0
0`00IcUW>@0]IcT00`00IcUW>@06IcT00`00IcUW>@18IcT00`00IcUW>@06IcT00`00IcUW>@03IcT0
0`00IcUW>@05IcT00`00IcUW>@0/IcT00`00IcUW>@020004IcT00`00IcUW>@03IcT00`00IcUW>@0D
IcT00`00IcUW>@03IcT20002IcT00`00IcUW>@0LIcU<Ool0029ooa9W>@03001W>FLi02eW>@03001W
>FLi00MW>@03001W>FLi04QW>@03001W>FLi00IW>@03001W>FLi00=W>@03001W>FLi00EW>@03001W
>FLi02QW>@9T7`=W>@800003IcT0000000=W>@03001W>FLi009W>@8001MW>@03001W>FLi009W>@80
009W>@03001W>FLi01]W>Deoo`008Goo4fLi00<006LiIcT0;FLi00<006LiIcT01fLi00<006LiIcT0
BFLi00<006LiIcT01VLi00<006LiIcT00VLi00<006LiIcT01FLi00<006LiIcT09fLi16@O16Li00@0
06Li000000=W>@05001W>FLiIcT0000HIcT00`00IcUW>@02IcT20002IcT00`00IcUW>@0JIcU>Ool0
025ooa=W>@03001W>FLi02eW>@03001W>FLi00MW>@03001W>FLi04UW>@03001W>FLi00IW>@03001W
>FLi00=W>@03001W>FLi00AW>@03001W>FLi02MW>@AT7`8000=W>@@0009W>@05001W>FLiIcT0000H
IcT00`00IcUW>@02IcT20002IcT00`00IcUW>@0SIcU5Ool0025ooa=W>@03001W>FLi02eW>@03001W
>FLi00MW>@03001W>FLi04YW>@03001W>FLi00EW>@03001W>FLi00=W>@03001W>FLi00=W>@03001W
>FLi02UW>@9T7`=W>@<0009W>@03001W>@00009W>@04001W>@00000HIcT00`00IcUW>@02IcT20002
IcT00`00IcUW>@0QIcU7Ool0021ooa=W>@03001W>FLi02iW>@03001W>FLi00MW>@03001W>FLi04]W
>@03001W>FLi00EW>@03001W>FLi009W>@03001W>FLi00=W>@03001W>FLi035W>@800008IcT00000
001W>@00IcT001UW>@03001W>FLi009W>@80009W>@03001W>FLi01mW>DUoo`0087oo4fLi00<006Li
IcT0;VLi00<006LiIcT01fLi00<006LiIcT0BfLi00<006LiIcT01FLi00<006LiIcT00VLi00<006Li
IcT00fLi00<006LiIcT0<fLi1@000a_P6VLi00@006LiIcUW>@80009W>@03001W>FLi01aW>Daoo`00
7goo56Li00<006LiIcT0;FLi00<006LiIcT026Li00<006LiIcT0C6Li00<006LiIcT016Li00<006Li
IcT00VLi00<006LiIcT00fLi00<006LiIcT0=VLi00<001_P6n000a_P6FLi00@006LiIcUW>@80009W
>@03001W>FLi01eW>@Moo`03IcUoogoo045oo`007goo56Li00<006LiIcT0;FLi00<006LiIcT026Li
00<006LiIcT0C6Li00<006LiIcT01FLi00D006LiIcUW>@0000EW>@03001W>FLi03MW>@DKh1UW>@03
001W>FLi009W>@04001W>FLi000PIcU:Ool001mooaAW>@03001W>FLi02eW>@03001W>FLi00QW>@03
001W>FLi04eW>@03001W>FLi00AW>@03001W>FLi009W>@03001W>FLi009W>@03001W>FLi03MW>@DK
h1UW>@03001W>FLi009W>@04001W>FLi000QIcU9Ool001iooaAW>@03001W>FLi02iW>@03001W>FLi
00QW>@03001W>FLi04iW>@03001W>FLi00=W>@03001W>FLi009W>@03001W>FLi009W>@03001W>FLi
03MW>@04000Kh1_P6n0KIcT2I1l2IcT200000fLi001W>@0PIcT4Ool00fLiOomoo`12Ool001iooaAW
>@03001W>FLi02iW>@03001W>FLi00QW>@03001W>FLi04iW>@03001W>FLi00AW>@05001W>FLiIcT0
0004IcT00`00IcUW>@0fIcT00`00IcT0000LIcT4I1l01FLi000006Li00008VLiB7oo000MOolEIcT0
0`00IcUW>@0^IcT00`00IcUW>@09IcT00`00IcUW>@1>IcT00`00IcUW>@03IcT01@00IcUW>FLi0000
16Li00<006LiIcT0<fLi0V@O00@006LiIcT001aW>@AT7`05IcT00000IcT0000SIcT00gooIcUoo`14
Ool001eooaEW>@03001W>FLi02eW>@03001W>FLi00YW>@03001W>FLi04iW>@03001W>FLi00=W>@05
001W>FLiIcT00004IcT00`00IcUW>@0bIcT4I1l00fLi001W>@0MIcT2I1l2IcT4000SIcT00gooIcUo
o`14Ool001eooaEW>@03001W>FLi02eW>@03001W>FLi00YW>@03001W>FLi04mW>@03001W>FLi00=W
>@04001W>FLi0004IcT00`00IcUW>@0bIcT4I1l00fLi001W>@0MIcT20002IcT4000RIcU8Ool001ao
oaEW>@03001W>FLi02iW>@03001W>FLi00YW>@03001W>FLi04mW>@03001W>FLi00=W>@04001W>FLi
0004IcT00`00IcUW>@0cIcT2I1l2IcT00`00IcUW>@0MIcT00`00IcUW>@04000QIcU9Ool001aooaEW
>@03001W>FLi02iW>@03001W>FLi00YW>@03001W>FLi051W>@03001W>FLi009W>@05001W>FLiIcT0
0003IcT00`00IcUW>@0fIcT00`00IcUW>@0NIcT00`00IcUW>@04000PIcU:Ool001]ooaIW>@03001W
>FLi02iW>@03001W>FLi00YW>@03001W>FLi055W>@03001W>FLi009W>@04001W>FLi0003IcT00`00
IcUW>@0fIcT00`00IcUW>@0NIcT00`00IcUW>@04000OIcU;Ool001]ooaIW>@03001W>FLi02iW>@03
001W>FLi00YW>@03001W>FLi055W>@03001W>FLi009W>@04001W>FLi0003IcT00`00IcUW>@0fIcT0
0`00IcUW>@0NIcT00`00IcUW>@04000NIcT2Ool2IcU8Ool001]ooaIW>@03001W>FLi02eW>@03001W
>FLi00]W>@03001W>FLi059W>@05001W>FLiIcT00002IcT01@00IcUW>FLi0000>6Li00<006LiIcT0
7fLi00<006Li00000`007FLi00AoofLiIcUW>DUoo`006Woo5VLi00<006LiIcT0;VLi00<006LiIcT0
2fLi00<006LiIcT0DVLi00D006LiIcUW>@00009W>@05001W>FLiIcT0000gIcT00`00IcUW>@0PIcT0
0`00IcUW>@03000QIcU9Ool001YooaIW>@03001W>FLi02iW>@03001W>FLi00]W>@03001W>FLi05=W
>@07001W>FLiIcT006Li00000fLi00<006LiIcT0=FLi00<006LiIcT086Li00<006LiIcT00P008FLi
1Goo00=W>GooOol0@Woo000IOol9IcT2I1l<IcT00`00IcUW>@0^IcT00`00IcUW>@0;IcT00`00IcUW
>@1@IcT2I1l00fLi001W>@02IcT01000IcUW>@000VLi00<006LiIcT0=FLi00<006LiIcT086Li00<0
06LiIcT00P008FLi1Goo00=W>GooOol0@Woo000KOol6IcT4I1l;IcT00`00IcUW>@0^IcT00`00IcUW
>@0;IcT00`00IcUW>@1?IcT4I1l01FLi001W>FLi00000VLi00@006LiIcT003IW>@03001W>FLi025W
>@800003IcT00000021W>@Moo`03IcUoogoo045oo`0077oo1FLi16@O2fLi00<006LiIcT0;VLi00<0
06LiIcT02fLi00<006LiIcT0CfLi16@O0VLi00H006LiIcT006Li0002IcT00`00IcUW>@0dIcT00`00
IcUW>@0RIcT01000IcT0000086Li1goo00=W>GooOol0@Goo000NOol4IcT2I1l;IcT00`00IcUW>@0^
IcT00`00IcUW>@0<IcT00`00IcUW>@1@IcT2I1l01000IcUW>@000VLi00<006Li00000VLi00<006Li
IcT0=6Li00<006LiIcT08VLi00@006Li000001mW>@Qoo`9W>D9oo`007goo16Li00<006LiIcT02FLi
00<006LiIcT0;VLi00<006LiIcT03FLi00<006LiIcT0DVLi00X006LiIcT006Li001W>@00IcT003IW
>@9T7bAW>@04001W>@00000OIcT8Ool2IcU2Ool0021oo`=W>@03001W>FLi00UW>@03001W>FLi02iW
>@03001W>FLi00eW>@03001W>FLi059W>@04001W>FLi0002IcT200000fLi001W>@0dIcT4I1lSIcT0
1000IcT000007VLi2Goo0VLi@Woo000OOol4IcT00`00IcUW>@09IcT00`00IcUW>@0^IcT00`00IcUW
>@0=IcT00`00IcUW>@1CIcT01`00IcUW>@00IcT006Li008003EW>@AT7bAW>@<001eW>@Eoo`04IcUo
ogooOol4IcU1Ool001eoo`EW>@03001W>FLi00UW>@03001W>FLi02mW>@03001W>FLi00eW>@03001W
>FLi05AW>@06001W>@00IcT006Li0P00=VLi0V@O9FLi0`007FLi17oo0VLi0Woo1FLi@Goo000KOol7
IcT00`00IcUW>@09IcT00`00IcUW>@0_IcT00`00IcUW>@0=IcT00`00IcUW>@1EIcT01000IcT006Li
0`00GFLi0`007FLi17oo0VLi0Woo1VLi@7oo000IOol9IcT00`00IcUW>@09IcT00`00IcUW>@0^IcT0
0`00IcUW>@0=IcT2I1mHIcT00`00IcT00003001MIcT3000MIcT3Ool3IcT00gooIcUW>@05IcU0Ool0
01Qoo`YW>@03001W>FLi00UW>@03001W>FLi02iW>@03001W>FLi00aW>@AT7eQW>@D005eW>@<001eW
>@=oo`]W>D1oo`005Woo36Li00<006LiIcT02FLi00<006LiIcT0;VLi0V@O3FLi16@O2P00CfLi1000
EFLi0V@O1fLi0P007FLi0Woo36Li@7oo000DOol>IcT00`00IcUW>@08IcT00`00IcUW>@0^IcT4I1l=
IcT2I1l;IcTH000gIcT4001DIcT4I1l6IcT2000MIcT2Ool<IcU0Ool0019ooa1W>@03001W>FLi00QW
>@03001W>FLi02iW>@AT7c9W>AL0025W>@04000Kh1_P6n1CIcT4I1l00`00IcUW>@03IcT2000MIcT0
0gooIcUW>@0;IcU0Ool0011ooa9W>@03001W>FLi00QW>@03001W>FLi02iW>@03001T7f@O01IW>@9T
7c9W>AP000UW>@DKh5=W>@9T7`9W>@8000=W>@8002YW>D5oo`0047oo0fLi0V@O3FLi00<006LiIcT0
26Li00<006LiIcT0;FLi00<006LiIcT05VLi16@O:FLi:@001A_PFFLi0P0000AW>A_P6n0Kh1iW>@9T
7`UW>@9oo`03IcUoogoo03aoo`0047oo0VLi16@O36Li00<006LiIcT026Li00<006LiIcT0;6Li00<0
06LiIcT05fLi16@O:@00:FLi1A_PFfLi1A_P76Li16@O26Li0Woo00=W>GooOol0?7oo000@Ool2IcT4
I1l<IcT00`00IcUW>@07IcT00`00IcUW>@0/IcT00`00IcUW>@0IIcT2I1mCIcT010006n0Kh1_PG6Li
1A_P76Li16@O26Li0Woo00=W>GooOol0?7oo000@Ool3IcT2I1l=IcT00`00IcUW>@05IcT2I1l00`00
IcUW>@0/IcT00`00IcUW>@1^IcT00`00IcUW>@1IIcT400056n0LIcT00`00I1mT7`09IcT2Ool00fLi
Oomoo`0lOol0011oo`AW>@03001W>FLi00YW>@03001W>FLi00EW>@AT7beW>@03001W>FLi06iW>@03
001W>FLi05EW>@L000=W>@<Kh1aW>@03001W>FLi00UW>@=oo`9W>Ceoo`0047oo16Li00<006LiIcT0
2VLi00<006LiIcT01FLi16@O;6Li00<006LiIcT0KVLi00<006LiIcT0DVLi100000AW>@00000000MW
>@03001W>FLi00MW>@9T7a5W>@03001W>FLi00YW>@=oo`9W>Ceoo`0047oo16Li00<006LiIcT02VLi
00<006LiIcT01VLi0V@O00<006LiIcT0:FLi00<006LiIcT0KVLi00<006LiIcT0CVLi1@000VLi0`00
2VLi00<006LiIcT01VLi16@O3VLi0P003FLi0goo0VLi?Goo000@Ool4IcT00`00IcUW>@0:IcT00`00
IcUW>@07IcT00`00IcUW>@0ZIcT00`00IcUW>@1^IcT00`00IcUW>@1:IcT40003IcT4000=IcT00`00
IcUW>@06IcT4I1l=IcT00`00IcUW>@0=IcT3Ool2IcTmOol0011oo`AW>@03001W>FLi00YW>@03001W
>FLi00IW>@8002]W>@03001W>FLi06iW>@03001W>FLi04IW>@D000AW>@<0015W>@03001W>FLi00MW
>@9T7`eW>@03001W>FLi00eW>@Aoo`=W>Caoo`0047oo1FLi00<006LiIcT02FLi00<006LiIcT01VLi
0P00:VLi00<006LiIcT0KVLi00<006LiIcT0?fLi0V@O0VLi100000=W>F@OI1l00fLi0`004fLi0V@O
26Li00<006LiIcT02fLi0P004VLi0Woo0fLi?7oo000?Ool6IcT00`00IcUW>@09IcT00`00IcUW>@06
IcT2000YIcT00`00IcUW>@1^IcT00`00IcUW>@0oIcT4I1l00`00IcUW>@02IcT4I1l2000EIcT4I1l6
IcT00`00IcUW>@0;IcT00`00IcUW>@0GIcTlOol000moo`IW>@03001W>FLi00UW>@03001W>FLi00IW
>@8002UW>@03001W>FLi06iW>@03001W>FLi03mW>@AT7`EW>@AT7aMW>@AT7`IW>@03001W>FLi00IW
>@<Kh003IcT006Li01UW>Caoo`003goo1VLi00<006LiIcT02FLi00<006LiIcT01VLi00<006LiIcT0
9fLi00<006LiIcT0KVLi00<006LiIcT0@FLi0V@O1fLi0V@O6FLi0V@O16Li0a_P26Li1A_P76Li>goo
000?Ool6IcT00`00IcUW>@09IcT00`00IcUW>@05IcT2000XIcT00`00IcUW>@1^IcT00`00IcUW>@11
IcT00`00IcUW>@0WIcT56n07IcT56n0LIcTkOol000moo`IW>@03001W>FLi00UW>@03001W>FLi00EW
>@8002MW>@03001W>FLi06iW>@03001W>FLi049W>@03001W>FLi02MW>@DKh0MW>@DKh1aW>C]oo`00
3goo1VLi00<006LiIcT026Li00<006LiIcT01VLi0P009fLi00<006LiIcT0KFLi00<006LiIcT0@VLi
00<006LiIcT0:6Li1A_P26Li0a_P7FLi>goo000?Ool6IcT00`00IcUW>@08IcT00`00IcUW>@06IcT0
0`00IcUW>@0UIcT00`00IcUW>@1^IcT00`00IcUW>@11IcT00`00IcUW>@0YIcT010006n0Kh1_P2VLi
00<006LiIcT07FLi>Woo000?Ool6IcT00`00IcUW>@08IcT00`00IcUW>@06IcT00`00IcUW>@0TIcT0
0`00IcUW>@1^IcT00`00IcUW>@12IcT00`00IcUW>@0YIcT2000<IcT00`00IcUW>@0NIcTiOol000mo
o`IW>@03001W>FLi00QW>@03001W>FLi00EW>@8002EW>@03001W>FLi06iW>@03001W>FLi049W>@03
001W>FLi02UW>@8000eW>@03001W>FLi01mW>CQoo`003goo1VLi00<006LiIcT026Li00<006LiIcT0
1FLi0P009FLi00<006LiIcT0KFLi00<006LiIcT08VLi0V@O76Li0V@O00=W>@00IcT0:FLi00<006Li
00003FLi00<006LiIcT086Li=goo000>Ool7IcT00`00IcUW>@08IcT00`00IcUW>@05IcT2000TIcT0
0`00IcUW>@1^IcT00`00IcUW>@0QIcT4I1lJIcT4I1lZIcT01000IcUW>@003FLi00<006LiIcT086Li
=goo000>Ool7IcT00`00IcUW>@08IcT00`00IcUW>@05IcT00`00IcUW>@0RIcT00`00IcUW>@1^IcT0
0`00IcUW>@0RIcT4I1lJIcT4I1lYIcT01000IcUW>@003VLi00<006LiIcT09FLi<Woo000>Ool7IcT0
0`00IcUW>@08IcT00`00IcUW>@05IcT00`00IcUW>@0QIcT00`00IcUW>@1^IcT00`00IcUW>@0TIcT2
I1l00fLi00000002000?IcT2I1l6IcT2I1lZIcT01000IcUW>@003VLi00<006LiIcT0:FLi;Woo000>
Ool7IcT00`00IcUW>@08IcT00`00IcUW>@04IcT2000SIcT00`00IcUW>@1]IcT00`00IcUW>@0/IcT5
0009IcT4I1l5IcT00`00IcUW>@0XIcT01000IcUW>@003fLi00<006LiIcT0;FLi:Woo000>Ool8IcT0
0`00IcUW>@07IcT00`00IcUW>@04IcT2000RIcT00`00IcUW>@1^IcT00`00IcUW>@0aIcT50004IcT4
I1l4IcT2000YIcT01@00IcUW>FLi00003fLi00<006LiIcT0<6Li9goo000>Ool8IcT00`00IcUW>@07
IcT00`00IcUW>@04IcT2000QIcT00`00IcUW>@1^IcT00`00IcUW>@0RIcT2I1lCIcT4000016LiI1mT
7fLi0P000a_P:FLi00D006LiIcUW>@00011W>@03001W>FLi039W>BEoo`003Woo26Li00<006LiIcT0
1fLi00<006LiIcT016Li00<006LiIcT07fLi00<006LiIcT0KVLi00<006LiIcT08VLi16@O5VLi1@00
1A_P9fLi00<006LiIcT00VLi00<006LiIcT03VLi00<006LiIcT0<fLi97oo000>Ool8IcT00`00IcUW
>@06IcT00`00IcUW>@05IcT00`00IcUW>@0OIcT00`00IcUW>@1]IcT00`00IcUW>@0SIcT4I1lK0005
6n0WIcT00`00IcUW>@02IcT00`00IcUW>@0?IcT00`00IcUW>@0bIcTTOol000ioo`QW>@03001W>FLi
00IW>@03001W>FLi00AW>@80021W>@03001W>FLi06eW>@03001W>FLi02EW>@9T7aaW>@DKh2=W>@=o
o`03001W>FLi009W>@03001W>FLi011W>@03001W>FLi039W>BAoo`003Woo26Li00<006LiIcT01VLi
00<006LiIcT016Li0P007fLi00<006LiIcT0KVLi00<006LiIcT0@FLi0P0000AW>A_P6n0Kh2AW>@9o
o`03001oogoo00=W>@03001W>FLi011W>@03001W>FLi039W>BAoo`003Goo2FLi00<006LiIcT01VLi
00<006LiIcT016Li0P007fLi00<006LiIcT0KFLi00<006LiIcT0@FLi00D006LiIcUW>@0002IW>@03
Ool007oo00Aoo`03001W>FLi015W>@03001W>FLi039W>BAoo`003Woo26Li00<006LiIcT01VLi00<0
06LiIcT016Li00<006LiIcT07FLi00<006LiIcT0KFLi00<006LiIcT0@6Li0P0016Li00<006LiIcT0
96Li00<007ooOol017oo00<007ooIcT04FLi00<006LiIcT0<VLi97oo000>Ool8IcT00`00IcUW>@06
IcT00`00IcUW>@04IcT00`00IcUW>@0LIcT00`00IcUW>@1]IcT00`00IcUW>@0oIcT20006IcT00`00
IcUW>@0TIcT00`00Oomoo`04Ool01000Oomoogoo46Li00<006LiIcT08FLi0a_P3VLi97oo000>Ool5
IcT2I1l00fLi001W>@07IcT00`00IcUW>@03IcT2000MIcT00`00IcUW>@1^IcT00`00IcUW>@0mIcT2
0007IcT00`00IcUW>@0RIcT2I1l00`00Oomoo`04Ool00`00Oomoo`04Ool>IcT00`00IcUW>@0PIcT0
0a_PI1mT7`026n0>IcTSOol000ioo`AW>@AT7`03001W>FLi00IW>@03001W>FLi00=W>@8001eW>@03
001W>FLi06eW>@03001W>FLi03eW>@03001W>FLi00MW>@03001W>FLi025W>@AT7`Ioo`03001oogoo
00Moo`]W>@03001W>FLi021W>@AT7`036n1W>FLi00aW>B=oo`003Woo16Li16@O00<006LiIcT01VLi
00<006LiIcT00fLi00<006LiIcT06fLi00<006LiIcT0KFLi00<006LiIcT0?6Li0P002VLi00<006Li
IcT08FLi16@O1Goo00<007ooOol02Woo2FLi00<006LiIcT086Li16@O00<Kh6LiIcT036Li8goo000>
Ool5IcT2I1l00fLi001W>@07IcT00`00IcUW>@03IcT00`00IcUW>@0JIcT00`00IcUW>@1]IcT00`00
IcUW>@0kIcT2000;IcT00`00IcUW>@0SIcT2I1l2IcT4Ool00`00Oomoo`0<Ool7IcT00`00IcUW>@0N
IcT2000016LiI1mT7a_P0P003FLi8goo000>Ool5IcT01000IcUW>@0026Li00<006LiIcT00fLi00<0
06LiIcT06FLi00<006LiIcT0KVLi00<006LiIcT0>VLi00<006LiIcT02fLi00<006LiIcT09fLi17oo
00<007ooOol03Woo1FLi00<006LiIcT076Li0P0026Li00<006LiIcT02VLi8goo000>Ool5IcT01000
IcUW>@001fLi00<006LiIcT00fLi0P006fLi00<006LiIcT0KFLi00<006LiIcT0>FLi0P003VLi00<0
06LiIcT0:6Li0Woo00<007ooOol04Goo0VLi0V@O76Li0P002fLi00<006LiIcT02FLi8goo000>Ool6
IcT01000IcUW>@001VLi00<006LiIcT00fLi0P006VLi00<006LiIcT0KFLi00<006LiIcT0>6Li0P00
46Li00<006LiIcT0:6Li0Woo00<007ooOol04Woo16@O6FLi0P003VLi0P000V@O1fLi8goo000>Ool6
IcT01000IcUW>@001VLi00<006LiIcT00fLi00<006LiIcT066Li00<006LiIcT0KFLi00<006LiIcT0
>6Li00<006LiIcT03fLi00<006LiIcT0:FLi00=oo`00Ool057oo16@O5fLi0P004FLi16@O1VLi8goo
000>Ool6IcT01000IcUW>@001VLi00<006LiIcT00fLi00<006LiIcT05fLi00<006LiIcT0KFLi00<0
06LiIcT0=fLi0P004VLi00<006LiIcT0:FLi00=oo`00Ool057oo00=W>F@OI1l05VLi0P004fLi16@O
1VLi8goo000>Ool6IcT01000IcUW>@001VLi00<006LiIcT00fLi00<006LiIcT05fLi00<006LiIcT0
KFLi00<006LiIcT0=FLi0P0056Li00<006LiIcT0:FLi00=oo`00Ool057oo5fLi0P005VLi0V@O2FLi
8Goo000>Ool6IcT01000IcUW>@001VLi00<006LiIcT00VLi0P0066Li00<006LiIcT0KFLi00<006Li
IcT0=6Li0P005FLi00<006LiIcT0:FLi00=oo`00Ool05Goo46Li0V@O0fLi0P0096Li87oo000>Ool6
IcT01000IcUW>@001VLi00<006LiIcT00VLi0P005fLi00<006LiIcT0KFLi00<006LiIcT0=6Li00<0
06LiIcT05FLi00<006LiIcT0:FLi00=oo`00Ool05goo3FLi16@O0P009fLi7goo000>Ool6IcT01000
IcUW>@001VLi00<006LiIcT00VLi00<006LiIcT05FLi00<006LiIcT0KFLi00<006LiIcT0;fLi0V@O
0VLi0P0066Li00<006LiIcT0:FLi00<007ooOol06Goo2fLi16@O:VLi7Woo000>Ool6IcT01000IcUW
>@001VLi00<006LiIcT00VLi00<006LiIcT05FLi00<006LiIcT0KFLi00<006LiIcT0;VLi16@O00<0
06LiIcT066Li00<006LiIcT0:6Li00=oo`00Ool077oo2VLi0V@O;6Li7Goo000>Ool7IcT00`00IcT0
0006IcT00`00IcUW>@02IcT00`00IcUW>@0DIcT00`00IcUW>@1]IcT00`00IcUW>@0_IcT4I1lJIcT0
0`00IcUW>@0YIcT00`00Oomoo`0NOolgIcTLOol000ioo`MW>@03001W>@0000IW>@04001W>FLiIcT2
000EIcT00`00IcUW>@1]IcT00`00IcUW>@0aIcT2I1lKIcT00`00IcUW>@0YIcT00`00Oomoo`0POolf
IcTKOol000ioo`MW>@03001W>@0000IW>@04001W>FLiIcT2000DIcT00`00IcUW>@1]IcT00`00IcUW
>@1?IcT00`00IcUW>@0XIcT00goo001oo`0ROolgIcTIOol000ioo`MW>@03001W>@0000EW>@03001W
>FLi009W>@03001W>FLi01=W>@03001W>FLi06eW>@03001W>FLi04mW>@03001W>FLi02QW>@03001o
ogoo02AoocIW>AQoo`003Woo1fLi00<006Li00001FLi00<006LiIcT00VLi00<006LiIcT04VLi00<0
06LiIcT0KFLi00<006LiIcT0CfLi00<006LiIcT0:FLi00<007ooOol09Woo=FLi5goo000>Ool7IcT0
0`00IcT00005IcT00`00IcUW>@02IcT00`00IcUW>@0AIcT00`00IcUW>@1]IcT00`00IcUW>@1@IcT0
0`00IcUW>@0XIcT00`00Oomoo`0YOoldIcTFOol000ioo`MW>@04001W>FLi0004IcT01000IcUW>FLi
0P004VLi00<006LiIcT0KFLi00<006LiIcT0DFLi00<006LiIcT0:6Li00<007ooOol0:goo<fLi5Goo
000>Ool7IcT01000IcUW>@0016Li00@006LiIcUW>@80019W>@03001W>FLi06eW>@03001W>FLi051W
>@03001W>FLi02UW>@03001oogoo02eooc9W>AAoo`003Woo26Li00<006Li000016Li00D006LiIcUW
>@00019W>@03001W>FLi06eW>@03001W>FLi055W>@03001W>FLi02QW>@03001oogoo02mooc9W>A=o
o`003Woo26Li00<006Li000016Li00D006LiIcUW>@00015W>@03001W>FLi06eW>@03001W>FLi059W
>@03001W>FLi02QW>@03001oogoo03=ooc1W>A5oo`003Woo26Li00<006Li000016Li00D006LiIcUW
>@00011W>@03001W>FLi06eW>@03001W>FLi05=W>@03001W>FLi02MW>@03001oogoo03MoobiW>A1o
o`003Woo26Li00<006Li000016Li00<006LiIcT00P0046Li00<006LiIcT0K6Li00<006LiIcT0DfLi
0V@O:FLi00<007ooOol0>Woo;6Li3goo000>Ool8IcT00`00IcT00004IcT01000IcUW>@0046Li00<0
06LiIcT0KFLi00<006LiIcT0DVLi16@O:6Li00<007ooOol0?Goo:VLi3Woo000>Ool8IcT00`00IcT0
0004IcT01000IcUW>@003fLi00<006LiIcT0KFLi00<006LiIcT0DfLi16@O9fLi00<007ooOol0@Goo
:6Li3Goo000>Ool8IcT00`00IcT00004IcT01000IcUW>@003fLi00<006LiIcT0K6Li00<006LiIcT0
EFLi0V@O:6Li00<007ooOol0Cgoo6fLi37oo000>Ool8IcT00`00IcT00003IcT01@00IcUW>FLi0000
3VLi00<006LiIcT0K6Li00<006LiIcT0OfLi00<007ooOol0DGoo6fLi2goo000>Ool9IcT20003IcT0
0`00IcUW>@02000=IcT00`00IcUW>@1]IcT00`00IcUW>@1oIcT00`00Oomoo`1BOolJIcT;Ool000io
o`UW>@8000=W>@04001W>FLi000=IcT00`00IcUW>@1]IcT00`00IcUW>@20IcT00`00Oomoo`1COolH
IcT<Ool000ioo`UW>@8000=W>@04001W>FLi000=IcT00`00IcUW>@1/IcT00`00IcUW>@20IcT00`00
Oomoo`1EOolGIcT<Ool000ioo`UW>@8000=W>@04001W>FLi000<IcT00`00IcUW>@1/IcT00`00IcUW
>@21IcT00`00Oomoo`1EOolFIcT=Ool000ioo`UW>@8000=W>@04001W>FLi000;IcT00`00IcUW>@1]
IcT00`00IcUW>@20IcT00`00Oomoo`1GOolDIcT>Ool000ioo`UW>@03001W>@00009W>@04001W>@00
000:IcT00`00IcUW>@1]IcT00`00IcUW>@21IcT00`00Oomoo`1GOolDIcT>Ool000ioo`UW>@03001W
>@00009W>@03001W>@0000]W>@03001W>FLi06aW>@03001W>FLi085W>@03001W>Goo05Uooa9W>@mo
o`003Woo2FLi00<006Li00000VLi00<006Li00002VLi00<006LiIcT0K6Li00<006LiIcT0PVLi00<0
07ooOol0FGoo4VLi3goo000>Ool:IcT20002IcT00`00IcT00009IcT00`00IcUW>@1/IcT00`00IcUW
>@23IcT00`00Oomoo`1JOol@IcT@Ool000ioo`YW>@80009W>@03001W>@0000QW>@03001W>FLi06eW
>@03001W>FLi089W>@03001W>Goo05]oo`mW>A5oo`003Woo2VLi0P0000=W>@00IcT00P0026Li00<0
06LiIcT0K6Li00<006LiIcT0PFLi0V@O00<007ooOol0G7oo3VLi4Goo000>Ool:IcT2000016Li001W
>@0026Li00<006LiIcT0K6Li00<006LiIcT0PFLi16@OGWoo3FLi4Woo000>Ool:IcT2000016Li001W
>@001fLi00<006LiIcT0K6Li00<006LiIcT0PVLi16@OGgoo36Li4Woo000>Ool:IcT2000016Li001W
>@001VLi00<006LiIcT0KFLi00<006LiIcT0PfLi0V@OHGoo2VLi4goo000>Ool:IcT2000016Li001W
>@001VLi00<006LiIcT0K6Li00<006LiIcT0Q6LiHgoo2FLi57oo000>Ool:IcT2000016Li00000000
1FLi00<006LiIcT0K6Li00<006LiIcT0PVLiIgoo26Li57oo000=Ool<IcT01000IcT000001FLi00<0
06LiIcT0K6Li00<006LiIcT0PFLiJGoo1fLi5Goo000=Ool<IcT01000IcT0000016Li00<006LiIcT0
KFLi00<006LiIcT0OVLiKGoo1VLi5Goo000=Ool;IcT2I1l00fLi00000004IcT00`00IcUW>@1/IcT0
0`00IcUW>@1lIcU`Ool5IcTFOol000eoo`YW>@AT7`8000=W>@03001W>FLi06aW>@03001W>FLi07]W
>G=oo`=W>AMoo`003Goo2VLi16@O00D006LiIcUW>@0006iW>@03001W>FLi07UW>GIoo`=W>AMoo`00
37oo36Li0V@O0P000VLi00<006LiIcT0K6Li00<006LiIcT0MfLiNWoo00=W>GooOol05Woo000<Ool=
IcT30002IcT00`00IcUW>@1/IcT00`00IcUW>@1eIcVEOol000aoo`eW>@<00003IcT006Li06eW>@03
001W>FLi07=W>IQoo`0037oo3VLi0`00KVLi00<006LiIcT0LFLiVgoo000<Ool=IcT36n1^IcT00`00
IcUW>@1`IcVMOol000]oo`eW>@DKh6eW>@03001W>FLi06eW>J1oo`002goo3FLi1A_PK6Li00<006Li
IcT0JfLiXgoo000;Ool=IcT56n1[IcT00`00IcUW>@1WIcVXOol000]oo`iW>@<Kh6]W>@03001W>FLi
06=W>Jeoo`002goo1VLi1WooKFLi0V@O00=W>@00IcT0GfLi/Woo000GOom/IcT4I1mLIcVgOol001Mo
ofaW>@AT7eMW>Kaoo`005gooKFLi0V@ODfLi`Goo000GOonmIcW6Ool001MookQW>L]oo`005goo/fLi
d7oo000GOon]IcWFOol00?mooi]oo`00ogooVgoo003oOonKOol00?mooi]oo`00ogooVgoo003oOonK
Ool00001\
\>"],
  ImageRangeCache->{{{0, 409.563}, {252.75, 0}} -> {-126.199, 24.5195, \
0.147674, 0.0992178}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowSize->{707, 624},
WindowMargins->{{Automatic, 24}, {Automatic, 7}},
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Transport"->{
    Cell[1828, 55, 52, 1, 62, "Section",
      CellTags->"Transport"],
    Cell[1883, 58, 477, 12, 67, "Text",
      CellTags->"Transport"],
    Cell[2397, 75, 49, 1, 62, "Section",
      CellTags->"Transport"],
    Cell[2508, 81, 95, 2, 50, "Input",
      CellTags->"Transport"],
    Cell[2640, 88, 49, 1, 62, "Section",
      CellTags->"Transport"],
    Cell[2714, 93, 127, 3, 50, "Input",
      CellTags->"Transport"],
    Cell[63888, 1032, 58, 1, 52, "Subsection",
      CellTags->"Transport"],
    Cell[63949, 1035, 172, 4, 50, "Input",
      CellTags->"Transport"],
    Cell[64124, 1041, 138, 3, 50, "Input",
      CellTags->"Transport"],
    Cell[64265, 1046, 251, 5, 110, "Input",
      CellTags->"Transport"],
    Cell[64541, 1055, 88, 2, 50, "Input",
      CellTags->"Transport"],
    Cell[101025, 2179, 56, 1, 36, "Subsection",
      CellTags->"Transport"],
    Cell[101084, 2182, 129, 3, 50, "Input",
      CellTags->"Transport"],
    Cell[101216, 2187, 129, 3, 50, "Input",
      CellTags->"Transport"],
    Cell[101370, 2194, 102, 2, 50, "Input",
      CellTags->"Transport"],
    Cell[101532, 2202, 259, 5, 110, "Input",
      CellTags->"Transport"],
    Cell[101816, 2211, 244, 5, 110, "Input",
      CellTags->"Transport"],
    Cell[102230, 2226, 104, 2, 50, "Input",
      CellTags->"Transport"],
    Cell[113711, 2532, 56, 1, 52, "Subsection",
      CellTags->"Transport"],
    Cell[113770, 2535, 78, 2, 50, "Input",
      CellTags->"Transport"],
    Cell[113851, 2539, 946, 18, 290, "Input",
      CellTags->"Transport"],
    Cell[114800, 2559, 288, 6, 90, "Input",
      CellTags->"Transport"],
    Cell[115091, 2567, 468, 8, 190, "Input",
      CellTags->"Transport"],
    Cell[115562, 2577, 142, 3, 50, "Input",
      CellTags->"Transport"],
    Cell[115707, 2582, 873, 15, 230, "Input",
      CellTags->"Transport"],
    Cell[116605, 2601, 127, 3, 50, "Input",
      CellTags->"Transport"],
    Cell[116926, 2616, 51, 1, 42, "Section",
      CellTags->"Transport"],
    Cell[117002, 2621, 113, 2, 50, "Input",
      CellTags->"Transport"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Transport", 151798, 3370}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 49, 0, 67, "Title"],

Cell[CellGroupData[{
Cell[1828, 55, 52, 1, 62, "Section",
  CellTags->"Transport"],
Cell[1883, 58, 477, 12, 67, "Text",
  CellTags->"Transport"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2397, 75, 49, 1, 62, "Section",
  CellTags->"Transport"],
Cell[2449, 78, 56, 1, 50, "Input"],
Cell[2508, 81, 95, 2, 50, "Input",
  CellTags->"Transport"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2640, 88, 49, 1, 62, "Section",
  CellTags->"Transport"],

Cell[CellGroupData[{
Cell[2714, 93, 127, 3, 50, "Input",
  CellTags->"Transport"],
Cell[2844, 98, 60709, 911, 12646, "Output"]
}, Closed]],
Cell[63568, 1012, 101, 2, 46, "Input"],

Cell[CellGroupData[{
Cell[63694, 1018, 49, 1, 50, "Input"],
Cell[63746, 1021, 37, 1, 49, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63832, 1028, 31, 0, 62, "Section"],

Cell[CellGroupData[{
Cell[63888, 1032, 58, 1, 52, "Subsection",
  CellTags->"Transport"],
Cell[63949, 1035, 172, 4, 50, "Input",
  CellTags->"Transport"],
Cell[64124, 1041, 138, 3, 50, "Input",
  CellTags->"Transport"],
Cell[64265, 1046, 251, 5, 110, "Input",
  CellTags->"Transport"],

Cell[CellGroupData[{
Cell[64541, 1055, 88, 2, 50, "Input",
  CellTags->"Transport"],
Cell[64632, 1059, 36211, 1109, 70, 15590, 850, "GraphicsData", "PostScript", \
"Graphics"],
Cell[100846, 2170, 130, 3, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[101025, 2179, 56, 1, 36, "Subsection",
  CellTags->"Transport"],
Cell[101084, 2182, 129, 3, 50, "Input",
  CellTags->"Transport"],
Cell[101216, 2187, 129, 3, 50, "Input",
  CellTags->"Transport"],

Cell[CellGroupData[{
Cell[101370, 2194, 102, 2, 50, "Input",
  CellTags->"Transport"],
Cell[101475, 2198, 42, 1, 70, "Output"]
}, Open  ]],
Cell[101532, 2202, 259, 5, 110, "Input",
  CellTags->"Transport"],

Cell[CellGroupData[{
Cell[101816, 2211, 244, 5, 110, "Input",
  CellTags->"Transport"],
Cell[102063, 2218, 130, 3, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102230, 2226, 104, 2, 50, "Input",
  CellTags->"Transport"],
Cell[102337, 2230, 11192, 291, 70, 3089, 186, "GraphicsData", "PostScript", \
"Graphics"],
Cell[113532, 2523, 130, 3, 70, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[113711, 2532, 56, 1, 52, "Subsection",
  CellTags->"Transport"],
Cell[113770, 2535, 78, 2, 50, "Input",
  CellTags->"Transport"],
Cell[113851, 2539, 946, 18, 290, "Input",
  CellTags->"Transport"],
Cell[114800, 2559, 288, 6, 90, "Input",
  CellTags->"Transport"],
Cell[115091, 2567, 468, 8, 190, "Input",
  CellTags->"Transport"],
Cell[115562, 2577, 142, 3, 50, "Input",
  CellTags->"Transport"],
Cell[115707, 2582, 873, 15, 230, "Input",
  CellTags->"Transport"],

Cell[CellGroupData[{
Cell[116605, 2601, 127, 3, 50, "Input",
  CellTags->"Transport"],
Cell[116735, 2606, 130, 3, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[116926, 2616, 51, 1, 42, "Section",
  CellTags->"Transport"],

Cell[CellGroupData[{
Cell[117002, 2621, 113, 2, 50, "Input",
  CellTags->"Transport"],
Cell[117118, 2625, 33836, 718, 262, 4989, 357, "GraphicsData", "PostScript", \
"Graphics"],
Cell[150957, 3345, 130, 3, 49, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

